@@ -49,20 +49,19 @@ from buildbot.util import service as util_service
 # Make use of the resource module if we can
 try:
     import resource
+
     assert resource
 except ImportError:
-    resource = None
+    resource = None  # type: ignore[assignment]
 
 
 class MetricEvent:
-
     @classmethod
     def log(cls, *args, **kwargs):
         log.msg(metric=cls(*args, **kwargs))
 
 
 class MetricCountEvent(MetricEvent):
-
     def __init__(self, counter, count=1, absolute=False):
         self.counter = counter
         self.count = count
@@ -70,7 +69,6 @@ class MetricCountEvent(MetricEvent):
 
 
 class MetricTimeEvent(MetricEvent):
-
     def __init__(self, timer, elapsed):
         self.timer = timer
         self.elapsed = elapsed
@@ -81,7 +79,6 @@ ALARM_TEXT = ["OK", "WARN", "CRIT"]
 
 
 class MetricAlarmEvent(MetricEvent):
-
     def __init__(self, alarm, msg=None, level=ALARM_OK):
         self.alarm = alarm
         self.level = level
@@ -93,7 +90,9 @@ def countMethod(counter):
         def wrapper(*args, **kwargs):
             MetricCountEvent.log(counter=counter)
             return func(*args, **kwargs)
+
         return wrapper
+
     return decorator
 
 
@@ -109,6 +108,7 @@ class Timer:
         def wrapper(*args, **kwargs):
             self.start()
             return func(*args, **kwargs)
+
         return wrapper
 
     def stopTimer(self, func):
@@ -117,6 +117,7 @@ class Timer:
                 return func(*args, **kwargs)
             finally:
                 self.stop()
+
         return wrapper
 
     def start(self):
@@ -140,12 +141,13 @@ def timeMethod(name, _reactor=None):
                 return func(*args, **kwargs)
             finally:
                 t.stop()
+
         return wrapper
+
     return decorator
 
 
 class FiniteList(deque):
-
     def __init__(self, maxlen=10):
         self._maxlen = maxlen
         super().__init__()
@@ -157,7 +159,6 @@ class FiniteList(deque):
 
 
 class AveragingFiniteList(FiniteList):
-
     def __init__(self, maxlen=10):
         super().__init__(maxlen)
         self.average = 0
@@ -176,7 +177,6 @@ class AveragingFiniteList(FiniteList):
 
 
 class MetricHandler:
-
     def __init__(self, metrics):
         self.metrics = metrics
         self.watchers = []
@@ -294,7 +294,6 @@ class MetricAlarmHandler(MetricHandler):
 
 
 class AttachedWorkersWatcher:
-
     def __init__(self, metrics):
         self.metrics = metrics
 
@@ -304,9 +303,11 @@ class AttachedWorkersWatcher:
         h = self.metrics.getHandler(MetricCountEvent)
         if not h:
             log.msg("Couldn't get MetricCountEvent handler")
-            MetricAlarmEvent.log('AttachedWorkersWatcher',
-                                 msg="Coudln't get MetricCountEvent handler",
-                                 level=ALARM_WARN)
+            MetricAlarmEvent.log(
+                'AttachedWorkersWatcher',
+                msg="Coudln't get MetricCountEvent handler",
+                level=ALARM_WARN,
+            )
             return
         botmaster_count = h.get('BotMaster.attached_workers')
         worker_count = h.get('AbstractWorker.attached_workers')
@@ -318,8 +319,9 @@ class AttachedWorkersWatcher:
         else:
             level = ALARM_OK
 
-        MetricAlarmEvent.log('attached_workers', msg=f'{botmaster_count} {worker_count}',
-                             level=level)
+        MetricAlarmEvent.log(
+            'attached_workers', msg=f'{botmaster_count} {worker_count}', level=level
+        )
 
 
 def _get_rss():
@@ -345,10 +347,24 @@ def periodicCheck(_reactor=reactor):
 
         if resource:
             r = resource.getrusage(resource.RUSAGE_SELF)
-            attrs = ['ru_utime', 'ru_stime', 'ru_maxrss', 'ru_ixrss', 'ru_idrss',
-                     'ru_isrss', 'ru_minflt', 'ru_majflt', 'ru_nswap',
-                     'ru_inblock', 'ru_oublock', 'ru_msgsnd', 'ru_msgrcv',
-                     'ru_nsignals', 'ru_nvcsw', 'ru_nivcsw']
+            attrs = [
+                'ru_utime',
+                'ru_stime',
+                'ru_maxrss',
+                'ru_ixrss',
+                'ru_idrss',
+                'ru_isrss',
+                'ru_minflt',
+                'ru_majflt',
+                'ru_nswap',
+                'ru_inblock',
+                'ru_oublock',
+                'ru_msgsnd',
+                'ru_msgrcv',
+                'ru_nsignals',
+                'ru_nvcsw',
+                'ru_nivcsw',
+            ]
             for i, a in enumerate(attrs):
                 # Linux versions prior to 2.6.32 didn't report this value, but we
                 # can calculate it from /proc/<pid>/statm
@@ -356,8 +372,7 @@ def periodicCheck(_reactor=reactor):
                 if a == 'ru_maxrss' and v == 0:
                     v = _get_rss() * resource.getpagesize() / 1024
                 MetricCountEvent.log(f'resource.{a}', v, absolute=True)
-            MetricCountEvent.log(
-                'resource.pagesize', resource.getpagesize(), absolute=True)
+            MetricCountEvent.log('resource.pagesize', resource.getpagesize(), absolute=True)
         # Measure the reactor delay
         then = util.now(_reactor)
         dt = 0.1
@@ -366,13 +381,13 @@ def periodicCheck(_reactor=reactor):
             now = util.now(_reactor)
             delay = (now - then) - dt
             MetricTimeEvent.log("reactorDelay", delay)
+
         _reactor.callLater(dt, cb)
     except Exception:
         log.err(None, "while collecting VM metrics")
 
 
-class MetricLogObserver(util_service.ReconfigurableServiceMixin,
-                        service.MultiService):
+class MetricLogObserver(util_service.ReconfigurableServiceMixin, service.MultiService):
     _reactor = reactor
 
     def __init__(self):
@@ -393,8 +408,7 @@ class MetricLogObserver(util_service.ReconfigurableServiceMixin,
         self.registerHandler(MetricTimeEvent, MetricTimeHandler(self))
         self.registerHandler(MetricAlarmEvent, MetricAlarmHandler(self))
 
-        self.getHandler(MetricCountEvent).addWatcher(
-            AttachedWorkersWatcher(self))
+        self.getHandler(MetricCountEvent).addWatcher(AttachedWorkersWatcher(self))
 
     def reconfigServiceWithBuildbotConfig(self, new_config):
         # first, enable or disable
@@ -423,8 +437,7 @@ class MetricLogObserver(util_service.ReconfigurableServiceMixin,
                     self.periodic_task.stop()
                     self.periodic_task = None
                 if periodic_interval:
-                    self.periodic_task = LoopingCall(periodicCheck,
-                                                     self._reactor)
+                    self.periodic_task = LoopingCall(periodicCheck, self._reactor)
                     self.periodic_task.clock = self._reactor
                     self.periodic_task.start(periodic_interval)
 
