@@ -17,6 +17,8 @@ import collections
 import json
 import re
 import weakref
+from typing import ClassVar
+from typing import Sequence
 
 from twisted.internet import defer
 from twisted.python.components import registerAdapter
@@ -31,7 +33,6 @@ from buildbot.util import flatten
 
 @implementer(IProperties)
 class Properties(util.ComparableMixin):
-
     """
     I represent a set of properties that can be interpolated into various
     strings in buildsteps.
@@ -47,7 +48,7 @@ class Properties(util.ComparableMixin):
     string when used as a mapping.
     """
 
-    compare_attrs = ('properties',)
+    compare_attrs: ClassVar[Sequence[str]] = ('properties',)
 
     def __init__(self, **kwargs):
         """
@@ -157,9 +158,7 @@ class Properties(util.ComparableMixin):
         return self.properties.copy()
 
     def __repr__(self):
-        return ('Properties(**' +
-                repr(dict((k, v[0]) for k, v in self.properties.items())) +
-                ')')
+        return 'Properties(**' + repr(dict((k, v[0]) for k, v in self.properties.items())) + ')'
 
     def update(self, dict, source, runtime=False):
         """Update this object from a dictionary, with an explicit source specified."""
@@ -167,7 +166,7 @@ class Properties(util.ComparableMixin):
             self.setProperty(k, v, source, runtime=runtime)
 
     def updateFromProperties(self, other):
-        """Update this object based on another object; the other object's """
+        """Update this object based on another object; the other object's"""
         self.properties.update(other.properties)
         self.runtime.update(other.runtime)
 
@@ -226,13 +225,12 @@ class Properties(util.ComparableMixin):
 
 
 class PropertiesMixin:
-
     """
     A mixin to add L{IProperties} methods to a class which does not implement
     the full interface, only getProperties() function.
 
     This is useful because L{IProperties} methods are often called on L{Build}
-    and L{BuildStatus} objects without first coercing them.
+    objects without first coercing them.
 
     @ivar set_runtime_properties: the default value for the C{runtime}
     parameter of L{setProperty}.
@@ -262,7 +260,6 @@ class PropertiesMixin:
 
 @implementer(IRenderable)
 class RenderableOperatorsMixin:
-
     """
     Properties and Interpolate instances can be manipulated with standard operators.
     """
@@ -309,6 +306,9 @@ class RenderableOperatorsMixin:
     def in_(self, other):
         return _OperatorRenderer(self, other, "in", lambda v1, v2: v1 in v2)
 
+    def getRenderingFor(self, iprops: IProperties) -> defer.Deferred:
+        raise NotImplementedError
+
 
 @implementer(IRenderable)
 class _OperatorRenderer(RenderableOperatorsMixin, util.ComparableMixin):
@@ -318,10 +318,13 @@ class _OperatorRenderer(RenderableOperatorsMixin, util.ComparableMixin):
 
     """
 
-    compare_attrs = ('fn',)
+    compare_attrs: ClassVar[Sequence[str]] = ('fn',)
 
     def __init__(self, v1, v2, cstr, comparator):
-        self.v1, self.v2, self.comparator, self.cstr = v1, v2, comparator, cstr
+        self.v1 = v1
+        self.v2 = v2
+        self.comparator = comparator
+        self.cstr = cstr
 
     @defer.inlineCallbacks
     def getRenderingFor(self, props):
@@ -329,15 +332,15 @@ class _OperatorRenderer(RenderableOperatorsMixin, util.ComparableMixin):
         return self.comparator(v1, v2)
 
     def __repr__(self):
-        return '%r %s %r' % (self.v1, self.cstr, self.v2)
+        return f'{self.v1!r} {self.cstr!s} {self.v2!r}'
 
 
 class _PropertyMap:
-
     """
     Privately-used mapping object to implement WithProperties' substitutions,
     including the rendering of None as ''.
     """
+
     colon_minus_re = re.compile(r"(.*):-(.*)")
     colon_tilde_re = re.compile(r"(.*):~(.*)")
     colon_plus_re = re.compile(r"(.*):\+(.*)")
@@ -366,9 +369,9 @@ class _PropertyMap:
             # if prop exists and is true (nonempty), use it; otherwise, use
             # repl
             prop, repl = mo.group(1, 2)
-            if prop in self.temp_vals and self.temp_vals[prop]:
+            if self.temp_vals.get(prop):
                 return self.temp_vals[prop]
-            elif prop in properties and properties[prop]:
+            elif prop in properties and properties[prop]:  # noqa: RUF019
                 return properties[prop]
             return repl
 
@@ -403,19 +406,18 @@ class _PropertyMap:
         return rv
 
     def add_temporary_value(self, key, val):
-        'Add a temporary value (to support keyword arguments to WithProperties)'
+        "Add a temporary value (to support keyword arguments to WithProperties)"
         self.temp_vals[key] = val
 
 
 @implementer(IRenderable)
 class WithProperties(util.ComparableMixin):
-
     """
     This is a marker class, used fairly widely to indicate that we
     want to interpolate build properties.
     """
 
-    compare_attrs = ('fmtstring', 'args', 'lambda_subs')
+    compare_attrs: ClassVar[Sequence[str]] = ('fmtstring', 'args', 'lambda_subs')
 
     def __init__(self, fmtstring, *args, **lambda_subs):
         self.fmtstring = fmtstring
@@ -424,11 +426,11 @@ class WithProperties(util.ComparableMixin):
             self.lambda_subs = lambda_subs
             for key, val in self.lambda_subs.items():
                 if not callable(val):
-                    raise ValueError(
-                        'Value for lambda substitution "{}" must be callable.'.format(key))
+                    raise ValueError(f'Value for lambda substitution "{key}" must be callable.')
         elif lambda_subs:
             raise ValueError(
-                'WithProperties takes either positional or keyword substitutions, not both.')
+                'WithProperties takes either positional or keyword substitutions, not both.'
+            )
 
     def getRenderingFor(self, build):
         pmap = _PropertyMap(build.getProperties())
@@ -445,13 +447,13 @@ class WithProperties(util.ComparableMixin):
 
 
 class _NotHasKey(util.ComparableMixin):
-
     """A marker for missing ``hasKey`` parameter.
 
     To withstand ``deepcopy``, ``reload`` and pickle serialization round trips,
     check it with ``==`` or ``!=``.
     """
-    compare_attrs = ()
+
+    compare_attrs: ClassVar[Sequence[str]] = ()
 
 
 # any instance of _NotHasKey would do, yet we don't want to create and delete
@@ -461,13 +463,18 @@ _notHasKey = _NotHasKey()
 
 @implementer(IRenderable)
 class _Lookup(util.ComparableMixin):
+    compare_attrs: ClassVar[Sequence[str]] = (
+        'value',
+        'index',
+        'default',
+        'defaultWhenFalse',
+        'hasKey',
+        'elideNoneAs',
+    )
 
-    compare_attrs = (
-        'value', 'index', 'default', 'defaultWhenFalse', 'hasKey', 'elideNoneAs')
-
-    def __init__(self, value, index, default=None,
-                 defaultWhenFalse=True, hasKey=_notHasKey,
-                 elideNoneAs=None):
+    def __init__(
+        self, value, index, default=None, defaultWhenFalse=True, hasKey=_notHasKey, elideNoneAs=None
+    ):
         self.value = value
         self.index = index
         self.default = default
@@ -476,15 +483,19 @@ class _Lookup(util.ComparableMixin):
         self.elideNoneAs = elideNoneAs
 
     def __repr__(self):
-        return '_Lookup({}, {}{}{}{}{})'.format(
-            repr(self.value),
-            repr(self.index),
-            ', default={}'.format(repr(self.default)) if self.default is not None else '',
-            ', defaultWhenFalse=False' if not self.defaultWhenFalse else '',
-            ', hasKey={}'.format(repr(self.hasKey)) if self.hasKey != _notHasKey else '',
-            ', elideNoneAs={}'.format(repr(self.elideNoneAs))
-            if self.elideNoneAs is not None else ''
-            )
+        parts = [repr(self.index)]
+        if self.default is not None:
+            parts.append(f', default={self.default!r}')
+        if not self.defaultWhenFalse:
+            parts.append(', defaultWhenFalse=False')
+        if self.hasKey != _notHasKey:
+            parts.append(f', hasKey={self.hasKey!r}')
+        if self.elideNoneAs is not None:
+            parts.append(f', elideNoneAs={self.elideNoneAs!r}')
+
+        parts_str = ''.join(parts)
+
+        return f'_Lookup({self.value!r}, {parts_str})'
 
     @defer.inlineCallbacks
     def getRenderingFor(self, build):
@@ -518,7 +529,6 @@ def _getInterpolationList(fmtstring):
 
 @implementer(IRenderable)
 class _PropertyDict:
-
     def getRenderingFor(self, build):
         return build.getProperties()
 
@@ -528,7 +538,6 @@ _thePropertyDict = _PropertyDict()
 
 @implementer(IRenderable)
 class _WorkerPropertyDict:
-
     def getRenderingFor(self, build):
         return build.getBuild().getWorkerInfo()
 
@@ -538,7 +547,6 @@ _theWorkerPropertyDict = _WorkerPropertyDict()
 
 @implementer(IRenderable)
 class _SecretRenderer:
-
     def __init__(self, secret_name):
         self.secret_name = secret_name
 
@@ -546,26 +554,26 @@ class _SecretRenderer:
     def getRenderingFor(self, properties):
         secretsSrv = properties.master.namedServices.get("secrets")
         if not secretsSrv:
-            error_message = "secrets service not started, need to configure" \
-                            " SecretManager in c['services'] to use 'secrets'" \
-                            "in Interpolate"
+            error_message = (
+                "secrets service not started, need to configure"
+                " SecretManager in c['services'] to use 'secrets'"
+                "in Interpolate"
+            )
             raise KeyError(error_message)
         credsservice = properties.master.namedServices['secrets']
         secret_detail = yield credsservice.get(self.secret_name)
         if secret_detail is None:
-            raise KeyError("secret key {} is not found in any provider".format(self.secret_name))
+            raise KeyError(f"secret key {self.secret_name} is not found in any provider")
         properties.useSecret(secret_detail.value, self.secret_name)
         return secret_detail.value
 
 
 class Secret(_SecretRenderer):
-
     def __repr__(self):
-        return "Secret({0})".format(self.secret_name)
+        return f"Secret({self.secret_name})"
 
 
 class _SecretIndexer:
-
     def __contains__(self, password):
         return True
 
@@ -575,8 +583,7 @@ class _SecretIndexer:
 
 @implementer(IRenderable)
 class _SourceStampDict(util.ComparableMixin):
-
-    compare_attrs = ('codebase',)
+    compare_attrs: ClassVar[Sequence[str]] = ('codebase',)
 
     def __init__(self, codebase):
         self.codebase = codebase
@@ -590,8 +597,7 @@ class _SourceStampDict(util.ComparableMixin):
 
 @implementer(IRenderable)
 class _Lazy(util.ComparableMixin):
-
-    compare_attrs = ('value',)
+    compare_attrs: ClassVar[Sequence[str]] = ('value',)
 
     def __init__(self, value):
         self.value = value
@@ -600,18 +606,17 @@ class _Lazy(util.ComparableMixin):
         return self.value
 
     def __repr__(self):
-        return '_Lazy(%r)' % self.value
+        return f'_Lazy({self.value!r})'
 
 
 @implementer(IRenderable)
 class Interpolate(RenderableOperatorsMixin, util.ComparableMixin):
-
     """
     This is a marker class, used fairly widely to indicate that we
     want to interpolate build properties.
     """
 
-    compare_attrs = ('fmtstring', 'args', 'kwargs')
+    compare_attrs: ClassVar[Sequence[str]] = ('fmtstring', 'args', 'kwargs')
 
     identifier_re = re.compile(r'^[\w._-]*$')
 
@@ -620,42 +625,40 @@ class Interpolate(RenderableOperatorsMixin, util.ComparableMixin):
         self.args = args
         self.kwargs = kwargs
         if self.args and self.kwargs:
-            config.error("Interpolate takes either positional or keyword "
-                         "substitutions, not both.")
+            config.error("Interpolate takes either positional or keyword substitutions, not both.")
         if not self.args:
             self.interpolations = {}
             self._parse(fmtstring)
 
     def __repr__(self):
         if self.args:
-            return 'Interpolate(%r, *%r)' % (self.fmtstring, self.args)
+            return f'Interpolate({self.fmtstring!r}, *{self.args!r})'
         elif self.kwargs:
-            return 'Interpolate(%r, **%r)' % (self.fmtstring, self.kwargs)
-        return 'Interpolate(%r)' % (self.fmtstring,)
+            return f'Interpolate({self.fmtstring!r}, **{self.kwargs!r})'
+        return f'Interpolate({self.fmtstring!r})'
 
-    @staticmethod
-    def _parse_prop(arg):
+    def _parse_substitution_prop(self, arg):
         try:
             prop, repl = arg.split(":", 1)
         except ValueError:
-            prop, repl = arg, None
+            prop = arg
+            repl = None
         if not Interpolate.identifier_re.match(prop):
-            config.error(
-                "Property name must be alphanumeric for prop Interpolation '{}'".format(arg))
-            prop = repl = None
+            config.error(f"Property name must be alphanumeric for prop Interpolation '{arg}'")
+            prop = None
+            repl = None
 
         return _thePropertyDict, prop, repl
 
-    @staticmethod
-    def _parse_secret(arg):
+    def _parse_substitution_secret(self, arg):
         try:
             secret, repl = arg.split(":", 1)
         except ValueError:
-            secret, repl = arg, None
+            secret = arg
+            repl = None
         return _SecretIndexer(), secret, repl
 
-    @staticmethod
-    def _parse_src(arg):
+    def _parse_substitution_src(self, arg):
         # TODO: Handle changes
         try:
             codebase, attr, repl = arg.split(":", 2)
@@ -664,84 +667,92 @@ class Interpolate(RenderableOperatorsMixin, util.ComparableMixin):
                 codebase, attr = arg.split(":", 1)
                 repl = None
             except ValueError:
-                config.error(("Must specify both codebase and attribute for "
-                              "src Interpolation '{}'").format(arg))
+                config.error(
+                    "Must specify both codebase and attribute for " f"src Interpolation '{arg}'"
+                )
                 return {}, None, None
 
         if not Interpolate.identifier_re.match(codebase):
-            config.error(
-                "Codebase must be alphanumeric for src Interpolation '{}'".format(arg))
+            config.error(f"Codebase must be alphanumeric for src Interpolation '{arg}'")
             codebase = attr = repl = None
         if not Interpolate.identifier_re.match(attr):
-            config.error(
-                "Attribute must be alphanumeric for src Interpolation '{}'".format(arg))
+            config.error(f"Attribute must be alphanumeric for src Interpolation '{arg}'")
             codebase = attr = repl = None
         return _SourceStampDict(codebase), attr, repl
 
-    def _parse_worker(self, arg):
+    def _parse_substitution_worker(self, arg):
         try:
             prop, repl = arg.split(":", 1)
         except ValueError:
-            prop, repl = arg, None
+            prop = arg
+            repl = None
         return _theWorkerPropertyDict, prop, repl
 
-    def _parse_kw(self, arg):
+    def _parse_substitution_kw(self, arg):
         try:
             kw, repl = arg.split(":", 1)
         except ValueError:
-            kw, repl = arg, None
+            kw = arg
+            repl = None
         if not Interpolate.identifier_re.match(kw):
-            config.error(
-                "Keyword must be alphanumeric for kw Interpolation '{}'".format(arg))
+            config.error(f"Keyword must be alphanumeric for kw Interpolation '{arg}'")
             kw = repl = None
         return _Lazy(self.kwargs), kw, repl
 
+    _substitutions = {
+        "prop": _parse_substitution_prop,
+        "secret": _parse_substitution_secret,
+        "src": _parse_substitution_src,
+        "worker": _parse_substitution_worker,
+        "kw": _parse_substitution_kw,
+    }
+
     def _parseSubstitution(self, fmt):
         try:
             key, arg = fmt.split(":", 1)
         except ValueError:
-            config.error(
-                "invalid Interpolate substitution without selector '{}'".format(fmt))
+            config.error(f"invalid Interpolate substitution without selector '{fmt}'")
             return None
 
-        fn = getattr(self, "_parse_" + key, None)
+        fn = self._substitutions.get(key, None)
         if not fn:
-            config.error("invalid Interpolate selector '{}'".format(key))
+            config.error(f"invalid Interpolate selector '{key}'")
             return None
-        return fn(arg)
+        return fn(self, arg)
 
     @staticmethod
     def _splitBalancedParen(delim, arg):
         parenCount = 0
         for i, val in enumerate(arg):
-            if arg[i] == "(":
+            if val == "(":
                 parenCount += 1
-            if arg[i] == ")":
+            if val == ")":
                 parenCount -= 1
                 if parenCount < 0:
                     raise ValueError
-            if parenCount == 0 and arg[i] == delim:
-                return arg[0:i], arg[i + 1:]
+            if parenCount == 0 and val == delim:
+                return arg[0:i], arg[i + 1 :]
         return arg
 
     def _parseColon_minus(self, d, kw, repl):
-        return _Lookup(d, kw,
-                       default=Interpolate(repl, **self.kwargs),
-                       defaultWhenFalse=False,
-                       elideNoneAs='')
+        return _Lookup(
+            d, kw, default=Interpolate(repl, **self.kwargs), defaultWhenFalse=False, elideNoneAs=''
+        )
 
     def _parseColon_tilde(self, d, kw, repl):
-        return _Lookup(d, kw,
-                       default=Interpolate(repl, **self.kwargs),
-                       defaultWhenFalse=True,
-                       elideNoneAs='')
+        return _Lookup(
+            d, kw, default=Interpolate(repl, **self.kwargs), defaultWhenFalse=True, elideNoneAs=''
+        )
 
     def _parseColon_plus(self, d, kw, repl):
-        return _Lookup(d, kw,
-                       hasKey=Interpolate(repl, **self.kwargs),
-                       default='',
-                       defaultWhenFalse=False,
-                       elideNoneAs='')
+        return _Lookup(
+            d,
+            kw,
+            hasKey=Interpolate(repl, **self.kwargs),
+            default='',
+            defaultWhenFalse=False,
+            elideNoneAs='',
+        )
 
     def _parseColon_ternary(self, d, kw, repl, defaultWhenFalse=False):
         delim = repl[0]
@@ -751,14 +762,19 @@ class Interpolate(RenderableOperatorsMixin, util.ComparableMixin):
         try:
             truePart, falsePart = self._splitBalancedParen(delim, repl[1:])
         except ValueError:
-            config.error("invalid Interpolate ternary expression '{}' with delimiter '{}'".format(
-                repl[1:], repl[0]))
+            config.error(
+                f"invalid Interpolate ternary expression '{repl[1:]}' "
+                f"with delimiter '{repl[0]}'"
+            )
             return None
-        return _Lookup(d, kw,
-                       hasKey=Interpolate(truePart, **self.kwargs),
-                       default=Interpolate(falsePart, **self.kwargs),
-                       defaultWhenFalse=defaultWhenFalse,
-                       elideNoneAs='')
+        return _Lookup(
+            d,
+            kw,
+            hasKey=Interpolate(truePart, **self.kwargs),
+            default=Interpolate(falsePart, **self.kwargs),
+            defaultWhenFalse=defaultWhenFalse,
+            elideNoneAs='',
+        )
 
     def _parseColon_ternary_hash(self, d, kw, repl):
         return self._parseColon_ternary(d, kw, repl, defaultWhenFalse=True)
@@ -775,36 +791,33 @@ class Interpolate(RenderableOperatorsMixin, util.ComparableMixin):
                     ("~", self._parseColon_tilde),
                     ("+", self._parseColon_plus),
                     ("?", self._parseColon_ternary),
-                    ("#?", self._parseColon_ternary_hash)
+                    ("#?", self._parseColon_ternary_hash),
                 ]:
                     junk, matches, tail = repl.partition(pattern)
                     if not junk and matches:
                         self.interpolations[key] = fn(d, kw, tail)
                         break
                 if key not in self.interpolations:
-                    config.error("invalid Interpolate default type '{}'".format(repl[0]))
+                    config.error(f"invalid Interpolate default type '{repl[0]}'")
 
     def getRenderingFor(self, build):
         props = build.getProperties()
         if self.args:
             d = props.render(self.args)
-            d.addCallback(lambda args:
-                          self.fmtstring % tuple(args))
+            d.addCallback(lambda args: self.fmtstring % tuple(args))
         else:
             d = props.render(self.interpolations)
-            d.addCallback(lambda res:
-                          self.fmtstring % res)
+            d.addCallback(lambda res: self.fmtstring % res)
         return d
 
 
 @implementer(IRenderable)
 class Property(RenderableOperatorsMixin, util.ComparableMixin):
-
     """
     An instance of this class renders a property of a build.
     """
 
-    compare_attrs = ('key', 'default', 'defaultWhenFalse')
+    compare_attrs: ClassVar[Sequence[str]] = ('key', 'default', 'defaultWhenFalse')
 
     def __init__(self, key, default=None, defaultWhenFalse=True):
         """
@@ -819,7 +832,7 @@ class Property(RenderableOperatorsMixin, util.ComparableMixin):
         self.defaultWhenFalse = defaultWhenFalse
 
     def __repr__(self):
-        return "Property({0})".format(self.key)
+        return f"Property({self.key})"
 
     def getRenderingFor(self, props):
         if self.defaultWhenFalse:
@@ -830,6 +843,7 @@ class Property(RenderableOperatorsMixin, util.ComparableMixin):
                 if rv:
                     return rv
                 return props.render(self.default)
+
             return d
 
         if props.hasProperty(self.key):
@@ -839,12 +853,11 @@ class Property(RenderableOperatorsMixin, util.ComparableMixin):
 
 @implementer(IRenderable)
 class FlattenList(RenderableOperatorsMixin, util.ComparableMixin):
-
     """
     An instance of this class flattens all nested lists in a list
     """
 
-    compare_attrs = ('nestedlist')
+    compare_attrs: ClassVar[Sequence[str]] = ('nestedlist',)
 
     def __init__(self, nestedlist, types=(list, tuple)):
         """
@@ -860,6 +873,7 @@ class FlattenList(RenderableOperatorsMixin, util.ComparableMixin):
         @d.addCallback
         def flat(r):
             return flatten(r, self.types)
+
         return d
 
     def __add__(self, b):
@@ -870,8 +884,7 @@ class FlattenList(RenderableOperatorsMixin, util.ComparableMixin):
 
 @implementer(IRenderable)
 class _Renderer(util.ComparableMixin):
-
-    compare_attrs = ('fn',)
+    compare_attrs: ClassVar[Sequence[str]] = ('fn',)
 
     def __init__(self, fn):
         self.fn = fn
@@ -897,9 +910,8 @@ class _Renderer(util.ComparableMixin):
 
     def __repr__(self):
         if self.args or self.kwargs:
-            return 'renderer(%r, args=%r, kwargs=%r)' % (self.fn, self.args,
-                                                         self.kwargs)
-        return 'renderer(%r)' % (self.fn,)
+            return f'renderer({self.fn!r}, args={self.args!r}, kwargs={self.kwargs!r})'
+        return f'renderer({self.fn!r})'
 
 
 def renderer(fn):
@@ -908,7 +920,6 @@ def renderer(fn):
 
 @implementer(IRenderable)
 class _DefaultRenderer:
-
     """
     Default IRenderable adaptor. Calls .getRenderingFor if available, otherwise
     returns argument unchanged.
@@ -929,7 +940,6 @@ registerAdapter(_DefaultRenderer, object, IRenderable)
 
 @implementer(IRenderable)
 class _ListRenderer:
-
     """
     List IRenderable adaptor. Maps Build.render over the list.
     """
@@ -946,7 +956,6 @@ registerAdapter(_ListRenderer, list, IRenderable)
 
 @implementer(IRenderable)
 class _TupleRenderer:
-
     """
     Tuple IRenderable adaptor. Maps Build.render over the tuple.
     """
@@ -965,14 +974,12 @@ registerAdapter(_TupleRenderer, tuple, IRenderable)
 
 @implementer(IRenderable)
 class _DictRenderer:
-
     """
     Dict IRenderable adaptor. Maps Build.render over the keys and values in the dict.
     """
 
     def __init__(self, value):
-        self.value = _ListRenderer(
-            [_TupleRenderer((k, v)) for k, v in value.items()])
+        self.value = _ListRenderer([_TupleRenderer((k, v)) for k, v in value.items()])
 
     def getRenderingFor(self, build):
         d = self.value.getRenderingFor(build)
@@ -985,15 +992,13 @@ registerAdapter(_DictRenderer, dict, IRenderable)
 
 @implementer(IRenderable)
 class Transform:
-
     """
     A renderable that combines other renderables' results using an arbitrary function.
     """
 
     def __init__(self, function, *args, **kwargs):
         if not callable(function) and not IRenderable.providedBy(function):
-            config.error(
-                "function given to Transform neither callable nor renderable")
+            config.error("function given to Transform neither callable nor renderable")
 
         self._function = function
         self._args = args
