@@ -13,30 +13,15 @@
 #
 # Copyright Buildbot Team Members
 
+from twisted.internet import defer
+from twisted.python import log
+
+from buildbot import pbutil
+from buildbot.util import service
+
 # this class is known to contain cruft and will be looked at later, so
 # no current implementation utilizes it aside from scripts.runner.
 
-from twisted.python import log
-from twisted.internet import defer
-from twisted.application import service
-from buildbot import pbutil
-
-class UsersBase(service.MultiService):
-    """
-    Base class for services that manage users manually. This takes care
-    of the service.MultiService work needed by all the services that
-    subclass it.
-    """
-
-    def __init__(self):
-        service.MultiService.__init__(self)
-        self.master = None
-
-    def startService(self):
-        service.MultiService.startService(self)
-
-    def stopService(self):
-        return service.MultiService.stopService(self)
 
 class CommandlineUserManagerPerspective(pbutil.NewCredPerspective):
     """
@@ -67,31 +52,38 @@ class CommandlineUserManagerPerspective(pbutil.NewCredPerspective):
             # list, alternating ident, uid
             formatted_results += "user(s) added:\n"
             for user in results:
-                if isinstance(user, basestring):
-                    formatted_results += "identifier: %s\n" % user
+                if isinstance(user, str):
+                    formatted_results += f"identifier: {user}\n"
                 else:
-                    formatted_results += "uid: %d\n\n" % user
+                    formatted_results += f"uid: {user}\n\n"
         elif op == 'remove':
             # list of dictionaries
             formatted_results += "user(s) removed:\n"
             for user in results:
                 if user:
-                    formatted_results += "identifier: %s\n" % (user)
+                    formatted_results += f"identifier: {user}\n"
         elif op == 'update':
             # list, alternating ident, None
             formatted_results += "user(s) updated:\n"
             for user in results:
                 if user:
-                    formatted_results += "identifier: %s\n" % (user)
+                    formatted_results += f"identifier: {user}\n"
         elif op == 'get':
             # list of dictionaries
             formatted_results += "user(s) found:\n"
             for user in results:
                 if user:
-                    for key in user:
-                        if key != 'bb_password':
-                            formatted_results += "%s: %s\n" % (key, user[key])
-                    formatted_results += "\n"
+                    formatted_results += (
+                        f"uid: {user.uid}\n"
+                        f"identifier: {user.identifier}\n"
+                        f"bb_username: {user.bb_username}\n"
+                    )
+                    if user.attributes:
+                        formatted_results += "attributes:\n"
+                        formatted_results += (
+                            ''.join(f"\t{key}: {value}\n" for key, value in user.attributes.items())
+                            + '\n'
+                        )
                 else:
                     formatted_results += "no match found\n"
         return formatted_results
@@ -125,12 +117,12 @@ class CommandlineUserManagerPerspective(pbutil.NewCredPerspective):
         log.msg("perspective_commandline called")
         results = []
 
+        # pylint: disable=too-many-nested-blocks
         if ids:
             for user in ids:
                 # get identifier, guaranteed to be in user from checks
                 # done in C{scripts.runner}
-                uid = yield self.master.db.users.identifierToUid(
-                                            identifier=user)
+                uid = yield self.master.db.users.identifierToUid(identifier=user)
 
                 result = None
                 if op == 'remove':
@@ -138,12 +130,12 @@ class CommandlineUserManagerPerspective(pbutil.NewCredPerspective):
                         yield self.master.db.users.removeUser(uid)
                         result = user
                     else:
-                        log.msg("Unable to find uid for identifier %s" % user)
+                        log.msg(f"Unable to find uid for identifier {user}")
                 elif op == 'get':
                     if uid:
                         result = yield self.master.db.users.getUser(uid)
                     else:
-                        log.msg("Unable to find uid for identifier %s" % user)
+                        log.msg(f"Unable to find uid for identifier {user}")
 
                 results.append(result)
         else:
@@ -151,43 +143,42 @@ class CommandlineUserManagerPerspective(pbutil.NewCredPerspective):
                 # get identifier, guaranteed to be in user from checks
                 # done in C{scripts.runner}
                 ident = user.pop('identifier')
-                uid = yield self.master.db.users.identifierToUid(
-                                                 identifier=ident)
+                uid = yield self.master.db.users.identifierToUid(identifier=ident)
 
                 # if only an identifier was in user, we're updating only
                 # the bb_username and bb_password.
                 if not user:
                     if uid:
                         result = yield self.master.db.users.updateUser(
-                                                       uid=uid,
-                                                       identifier=ident,
-                                                       bb_username=bb_username,
-                                                       bb_password=bb_password)
+                            uid=uid,
+                            identifier=ident,
+                            bb_username=bb_username,
+                            bb_password=bb_password,
+                        )
                         results.append(ident)
                     else:
-                        log.msg("Unable to find uid for identifier %s"
-                                % user)
+                        log.msg(f"Unable to find uid for identifier {user}")
                 else:
                     # when adding, we update the user after the first attr
                     once_through = False
                     for attr in user:
+                        result = None
                         if op == 'update' or once_through:
                             if uid:
                                 result = yield self.master.db.users.updateUser(
-                                                      uid=uid,
-                                                      identifier=ident,
-                                                      bb_username=bb_username,
-                                                      bb_password=bb_password,
-                                                      attr_type=attr,
-                                                      attr_data=user[attr])
+                                    uid=uid,
+                                    identifier=ident,
+                                    bb_username=bb_username,
+                                    bb_password=bb_password,
+                                    attr_type=attr,
+                                    attr_data=user[attr],
+                                )
                             else:
-                                log.msg("Unable to find uid for identifier %s"
-                                        % user)
+                                log.msg(f"Unable to find uid for identifier {user}")
                         elif op == 'add':
                             result = yield self.master.db.users.findUserByAttr(
-                                                      identifier=ident,
-                                                      attr_type=attr,
-                                                      attr_data=user[attr])
+                                identifier=ident, attr_type=attr, attr_data=user[attr]
+                            )
                             once_through = True
                         results.append(ident)
 
@@ -196,18 +187,20 @@ class CommandlineUserManagerPerspective(pbutil.NewCredPerspective):
                             results.append(result)
                             uid = result
         results = self.formatResults(op, results)
-        defer.returnValue(results)
+        return results
 
-class CommandlineUserManager(UsersBase):
+
+class CommandlineUserManager(service.AsyncMultiService):
     """
     Service that runs to set up and register CommandlineUserManagerPerspective
     so `buildbot user` calls get to perspective_commandline.
     """
 
     def __init__(self, username=None, passwd=None, port=None):
-        UsersBase.__init__(self)
-        assert username and passwd, ("A username and password pair must be given "
-                                     "to connect and use `buildbot user`")
+        super().__init__()
+        assert (
+            username and passwd
+        ), "A username and password pair must be given to connect and use `buildbot user`"
         self.username = username
         self.passwd = passwd
 
@@ -215,20 +208,24 @@ class CommandlineUserManager(UsersBase):
         self.port = port
         self.registration = None
 
+    @defer.inlineCallbacks
     def startService(self):
-        UsersBase.startService(self)
         # set up factory and register with buildbot.pbmanager
         def factory(mind, username):
             return CommandlineUserManagerPerspective(self.master)
-        self.registration = self.master.pbmanager.register(self.port,
-                                                           self.username,
-                                                           self.passwd,
-                                                           factory)
+
+        self.registration = yield self.master.pbmanager.register(
+            self.port, self.username, self.passwd, factory
+        )
+        yield super().startService()
 
     def stopService(self):
-        d = defer.maybeDeferred(UsersBase.stopService, self)
+        d = defer.maybeDeferred(service.AsyncMultiService.stopService, self)
+
+        @d.addCallback
         def unreg(_):
             if self.registration:
                 return self.registration.unregister()
-        d.addCallback(unreg)
+            return None
+
         return d
