@@ -15,6 +15,7 @@
 # Portions Copyright 2013 Bad Dog Consulting
 
 import re
+from typing import Optional
 
 from twisted.internet import defer
 from twisted.python import log
@@ -40,31 +41,46 @@ from buildbot.steps.source import Source
 
 
 class P4(Source):
-
     """Perform Perforce checkout/update operations."""
 
     name = 'p4'
 
-    renderables = ['mode', 'p4base', 'p4client', 'p4viewspec', 'p4branch', 'p4passwd', 'p4port',
-            'p4user']
+    renderables = [
+        'mode',
+        'p4base',
+        'p4client',
+        'p4viewspec',
+        'p4branch',
+        'p4passwd',
+        'p4port',
+        'p4user',
+    ]
     possible_modes = ('incremental', 'full')
     possible_client_types = (None, 'readonly', 'partitioned')
 
-    def __init__(self, mode='incremental',
-                 method=None, p4base=None, p4branch=None,
-                 p4port=None, p4user=None,
-                 p4passwd=None, p4extra_views=(), p4line_end='local',
-                 p4viewspec=None, p4viewspec_suffix='...',
-                 p4client=Interpolate(
-                     'buildbot_%(prop:workername)s_%(prop:buildername)s'),
-                 p4client_spec_options='allwrite rmdir',
-                 p4client_type=None,
-                 p4extra_args=None,
-                 p4bin='p4',
-                 use_tickets=False,
-                 stream=False,
-                 debug=False,
-                 **kwargs):
+    def __init__(
+        self,
+        mode='incremental',
+        method=None,
+        p4base=None,
+        p4branch=None,
+        p4port=None,
+        p4user=None,
+        p4passwd=None,
+        p4extra_views=(),
+        p4line_end='local',
+        p4viewspec=None,
+        p4viewspec_suffix='...',
+        p4client: Optional[Interpolate] = None,
+        p4client_spec_options='allwrite rmdir',
+        p4client_type=None,
+        p4extra_args=None,
+        p4bin='p4',
+        use_tickets=False,
+        stream=False,
+        debug=False,
+        **kwargs,
+    ):
         self.method = method
         self.mode = mode
         self.p4branch = p4branch
@@ -77,6 +93,8 @@ class P4(Source):
         self.p4viewspec = p4viewspec
         self.p4viewspec_suffix = p4viewspec_suffix
         self.p4line_end = p4line_end
+        if p4client is None:
+            p4client = Interpolate('buildbot_%(prop:workername)s_%(prop:buildername)s')
         self.p4client = p4client
         self.p4client_spec_options = p4client_spec_options
         self.p4client_type = p4client_type
@@ -87,8 +105,9 @@ class P4(Source):
 
         super().__init__(**kwargs)
 
-        if self.mode not in self.possible_modes and \
-                not interfaces.IRenderable.providedBy(self.mode):
+        if self.mode not in self.possible_modes and not interfaces.IRenderable.providedBy(
+            self.mode
+        ):
             config.error(f"mode {self.mode} is not an IRenderable, or one of {self.possible_modes}")
 
         if not p4viewspec and p4base is None:
@@ -96,11 +115,13 @@ class P4(Source):
 
         if p4viewspec and (p4base or p4branch or p4extra_views):
             config.error(
-                "Either provide p4viewspec or p4base and p4branch (and optionally p4extra_views)")
+                "Either provide p4viewspec or p4base and p4branch (and optionally p4extra_views)"
+            )
 
         if p4viewspec and isinstance(p4viewspec, str):
             config.error(
-                "p4viewspec must not be a string, and should be a sequence of 2 element sequences")
+                "p4viewspec must not be a string, and should be a sequence of 2 element sequences"
+            )
 
         if not interfaces.IRenderable.providedBy(p4base) and p4base and not p4base.startswith('/'):
             config.error(f'p4base should start with // [p4base = {p4base}]')
@@ -112,7 +133,7 @@ class P4(Source):
             config.error(f'p4branch should not end with a trailing / [p4branch = {p4branch}]')
 
         if stream:
-            if (p4extra_views or p4viewspec):
+            if p4extra_views or p4viewspec:
                 config.error('You can\'t use p4extra_views not p4viewspec with stream')
             if not p4base or not p4branch:
                 config.error('You must specify both p4base and p4branch when using stream')
@@ -124,11 +145,14 @@ class P4(Source):
         if self.p4client_spec_options is None:
             self.p4client_spec_options = ''
 
-        if self.p4client_type not in self.possible_client_types and \
-                not interfaces.IRenderable.providedBy(self.p4client_type):
+        if (
+            self.p4client_type not in self.possible_client_types
+            and not interfaces.IRenderable.providedBy(self.p4client_type)
+        ):
             config.error(
                 f"p4client_type {self.p4client_type} is not an IRenderable, "
-                "or one of {self.possible_client_types}")
+                "or one of {self.possible_client_types}"
+            )
 
     @defer.inlineCallbacks
     def run_vc(self, branch, revision, patch):
@@ -148,8 +172,7 @@ class P4(Source):
                 self.p4passwd_arg = ('obfuscated', self.p4passwd, 'XXXXXX')
             else:
                 self.p4passwd_arg = self.p4passwd
-                log.msg("Worker does not understand obfuscation; "
-                        "p4 password will be logged")
+                log.msg("Worker does not understand obfuscation; p4 password will be logged")
 
         if self.use_tickets and self.p4passwd:
             yield self._acquireTicket()
@@ -178,14 +201,17 @@ class P4(Source):
         # Then we need to sync the client
         if self.revision:
             if self.debug:
-                log.msg("P4: full() sync command based on :client:%s changeset:%d",
-                        self.p4client, int(self.revision))
-            yield self._dovccmd(['sync', f'//{self.p4client}/...@{int(self.revision)}'],
-                                collectStdout=True)
+                log.msg(
+                    "P4: full() sync command based on :client:%s changeset:%d",
+                    self.p4client,
+                    int(self.revision),
+                )
+            yield self._dovccmd(
+                ['sync', f'//{self.p4client}/...@{int(self.revision)}'], collectStdout=True
+            )
         else:
             if self.debug:
-                log.msg("P4: full() sync command based on :client:%s no revision",
-                        self.p4client)
+                log.msg("P4: full() sync command based on :client:%s no revision", self.p4client)
             yield self._dovccmd(['sync'], collectStdout=True)
 
         if self.debug:
@@ -197,20 +223,23 @@ class P4(Source):
             log.msg("P4:incremental()")
 
         # and plan to do a checkout
-        command = ['sync', ]
+        command = [
+            'sync',
+        ]
 
         if self.revision:
             command.extend([f'//{self.p4client}/...@{int(self.revision)}'])
 
         if self.debug:
-            log.msg(
-                "P4:incremental() command:%s revision:%s", command, self.revision)
+            log.msg("P4:incremental() command:%s revision:%s", command, self.revision)
         yield self._dovccmd(command)
 
     def _buildVCCommand(self, doCommand):
         assert doCommand, "No command specified"
 
-        command = [self.p4bin, ]
+        command = [
+            self.p4bin,
+        ]
 
         if self.p4port:
             command.extend(['-p', self.p4port])
@@ -235,12 +264,15 @@ class P4(Source):
         if self.debug:
             log.msg(f"P4:_dovccmd():workdir->{self.workdir}")
 
-        cmd = remotecommand.RemoteShellCommand(self.workdir, command,
-                                               env=self.env,
-                                               logEnviron=self.logEnviron,
-                                               timeout=self.timeout,
-                                               collectStdout=collectStdout,
-                                               initialStdin=initialStdin,)
+        cmd = remotecommand.RemoteShellCommand(
+            self.workdir,
+            command,
+            env=self.env,
+            logEnviron=self.logEnviron,
+            timeout=self.timeout,
+            collectStdout=collectStdout,
+            initialStdin=initialStdin,
+        )
         cmd.useLog(self.stdio_log, False)
         if self.debug:
             log.msg(f'Starting p4 command : p4 {" ".join(command)}')
@@ -359,15 +391,19 @@ class P4(Source):
         changes_command_args = ['-ztag', 'changes', '-m1', f"//{self.p4client}/...{revision}"]
         command = self._buildVCCommand(changes_command_args)
 
-        cmd = remotecommand.RemoteShellCommand(self.workdir, command,
-                                               env=self.env,
-                                               timeout=self.timeout,
-                                               logEnviron=self.logEnviron,
-                                               collectStdout=True)
+        cmd = remotecommand.RemoteShellCommand(
+            self.workdir,
+            command,
+            env=self.env,
+            timeout=self.timeout,
+            logEnviron=self.logEnviron,
+            collectStdout=True,
+        )
         cmd.useLog(self.stdio_log, False)
         yield self.runCommand(cmd)
 
         stdout = cmd.stdout.splitlines(keepends=False)
+        # pylint: disable=wrong-spelling-in-comment
         # Example output from p4 -ztag changes -m1
         # ... change 212798
         # ... time 1694770219
@@ -380,18 +416,18 @@ class P4(Source):
         change_identifier = "... change "
         revision = next(
             (
-                line[len(change_identifier):]
+                line[len(change_identifier) :]
                 for line in stdout
                 if line.startswith(change_identifier)
             ),
-            None
+            None,
         )
         try:
             int(revision)
         except ValueError as error:
             log.msg(
                 "p4.get_sync_revision unable to parse output of %s: %s",
-                ['p4'] + changes_command_args,
+                ['p4', *changes_command_args],
                 stdout,
             )
             raise buildstep.BuildStepFailed() from error
@@ -411,9 +447,9 @@ class P4(Source):
 
     @defer.inlineCallbacks
     def checkP4(self):
-        cmd = remotecommand.RemoteShellCommand(self.workdir, [self.p4bin, '-V'],
-                                               env=self.env,
-                                               logEnviron=self.logEnviron)
+        cmd = remotecommand.RemoteShellCommand(
+            self.workdir, [self.p4bin, '-V'], env=self.env, logEnviron=self.logEnviron
+        )
         cmd.useLog(self.stdio_log, False)
         yield self.runCommand(cmd)
         return cmd.rc == 0
