@@ -31,12 +31,12 @@ class WorkerBuildStep(buildstep.BuildStep):
 
 
 class SetPropertiesFromEnv(WorkerBuildStep):
-
     """
     Sets properties from environment variables on the worker.
 
     Note this is transferred when the worker first connects
     """
+
     name = 'SetPropertiesFromEnv'
     description = ['Setting']
     descriptionDone = ['Set']
@@ -52,7 +52,7 @@ class SetPropertiesFromEnv(WorkerBuildStep):
         # a case-sensitive dictionary in worker_environ.  Fortunately, that
         # dictionary is also folded to uppercase, so we can simply fold the
         # variable names to uppercase to duplicate the case-insensitivity.
-        fold_to_uppercase = (self.worker.worker_system == 'win32')
+        fold_to_uppercase = self.worker.worker_system == 'win32'
 
         properties = self.build.getProperties()
         environ = self.worker.worker_environ
@@ -67,18 +67,17 @@ class SetPropertiesFromEnv(WorkerBuildStep):
             value = environ.get(key, None)
             if value:
                 # note that the property is not uppercased
-                properties.setProperty(variable, value, self.source,
-                                       runtime=True)
-                log.append("{} = {}".format(variable, repr(value)))
+                properties.setProperty(variable, value, self.source, runtime=True)
+                log.append(f"{variable} = {value!r}")
         yield self.addCompleteLog("properties", "\n".join(log))
         return SUCCESS
 
 
 class FileExists(WorkerBuildStep):
-
     """
     Check for the existence of a file on the worker.
     """
+
     name = 'FileExists'
     renderables = ['file']
     haltOnFailure = True
@@ -109,10 +108,10 @@ class FileExists(WorkerBuildStep):
 
 
 class CopyDirectory(WorkerBuildStep):
-
     """
     Copy a directory tree on the worker.
     """
+
     name = 'CopyDirectory'
     description = ['Copying']
     descriptionDone = ['Copied']
@@ -151,10 +150,10 @@ class CopyDirectory(WorkerBuildStep):
 
 
 class RemoveDirectory(WorkerBuildStep):
-
     """
     Remove a directory tree on the worker.
     """
+
     name = 'RemoveDirectory'
     description = ['Deleting']
     descriptionDone = ['Deleted']
@@ -183,10 +182,10 @@ class RemoveDirectory(WorkerBuildStep):
 
 
 class MakeDirectory(WorkerBuildStep):
-
     """
     Create a directory on the worker.
     """
+
     name = 'MakeDirectory'
     description = ['Creating']
     descriptionDone = ['Created']
@@ -213,8 +212,7 @@ class MakeDirectory(WorkerBuildStep):
         return SUCCESS
 
 
-class CompositeStepMixin():
-
+class CompositeStepMixin:
     def workerPathToMasterPath(self, path):
         return os.path.join(*self.worker.path_module.split(path))
 
@@ -227,8 +225,9 @@ class CompositeStepMixin():
         self.rc_log = yield self.addLog(logname)
         return self.rc_log
 
-    def runRemoteCommand(self, cmd, args, abandonOnFailure=True,
-                         evaluateCommand=lambda cmd: cmd.didFail()):
+    def runRemoteCommand(
+        self, cmd, args, abandonOnFailure=True, evaluateCommand=lambda cmd: cmd.didFail()
+    ):
         """generic RemoteCommand boilerplate"""
         cmd = remotecommand.RemoteCommand(cmd, args)
         if hasattr(self, "rc_log"):
@@ -244,14 +243,14 @@ class CompositeStepMixin():
         return d
 
     def runRmdir(self, dir, timeout=None, **kwargs):
-        """ remove a directory from the worker """
+        """remove a directory from the worker"""
         cmd_args = {'dir': dir, 'logEnviron': self.logEnviron}
         if timeout:
             cmd_args['timeout'] = timeout
         return self.runRemoteCommand('rmdir', cmd_args, **kwargs)
 
     def runRmFile(self, path, timeout=None, **kwargs):
-        """ remove a file from the worker """
+        """remove a file from the worker"""
         cmd_args = {'path': path, 'logEnviron': self.logEnviron}
         if timeout:
             cmd_args['timeout'] = timeout
@@ -261,29 +260,47 @@ class CompositeStepMixin():
         return self.runRemoteCommand('rmfile', cmd_args, **kwargs)
 
     def pathExists(self, path):
-        """ test whether path exists"""
+        """test whether path exists"""
+
         def commandComplete(cmd):
             return not cmd.didFail()
 
-        return self.runRemoteCommand('stat', {'file': path,
-                                              'logEnviron': self.logEnviron, },
-                                     abandonOnFailure=False,
-                                     evaluateCommand=commandComplete)
+        return self.runRemoteCommand(
+            'stat',
+            {
+                'file': path,
+                'logEnviron': self.logEnviron,
+            },
+            abandonOnFailure=False,
+            evaluateCommand=commandComplete,
+        )
 
     def runMkdir(self, _dir, **kwargs):
-        """ create a directory and its parents"""
-        return self.runRemoteCommand('mkdir', {'dir': _dir,
-                                               'logEnviron': self.logEnviron, },
-                                     **kwargs)
+        """create a directory and its parents"""
+        return self.runRemoteCommand(
+            'mkdir',
+            {
+                'dir': _dir,
+                'logEnviron': self.logEnviron,
+            },
+            **kwargs,
+        )
 
     def runGlob(self, path, **kwargs):
-        """ find files matching a shell-style pattern"""
+        """find files matching a shell-style pattern"""
+
         def commandComplete(cmd):
             return cmd.updates['files'][-1]
 
-        return self.runRemoteCommand('glob', {'path': path,
-                                              'logEnviron': self.logEnviron, },
-                                     evaluateCommand=commandComplete, **kwargs)
+        return self.runRemoteCommand(
+            'glob',
+            {
+                'path': path,
+                'logEnviron': self.logEnviron,
+            },
+            evaluateCommand=commandComplete,
+            **kwargs,
+        )
 
     def getFileContentFromWorker(self, filename, abandonOnFailure=False):
         self.checkWorkerHasCommand("uploadFile")
@@ -306,13 +323,13 @@ class CompositeStepMixin():
                 return None
             return fileWriter.buffer
 
-        return self.runRemoteCommand('uploadFile', args,
-                                     abandonOnFailure=abandonOnFailure,
-                                     evaluateCommand=commandComplete)
+        return self.runRemoteCommand(
+            'uploadFile', args, abandonOnFailure=abandonOnFailure, evaluateCommand=commandComplete
+        )
 
-    def downloadFileContentToWorker(self, workerdest, strfile,
-                                    abandonOnFailure=False, mode=None,
-                                    workdir=None):
+    def downloadFileContentToWorker(
+        self, workerdest, strfile, abandonOnFailure=False, mode=None, workdir=None
+    ):
         if workdir is None:
             workdir = self.workdir
 
@@ -336,6 +353,7 @@ class CompositeStepMixin():
             if cmd.didFail():
                 return None
             return fileReader
-        return self.runRemoteCommand('downloadFile', args,
-                                     abandonOnFailure=abandonOnFailure,
-                                     evaluateCommand=commandComplete)
+
+        return self.runRemoteCommand(
+            'downloadFile', args, abandonOnFailure=abandonOnFailure, evaluateCommand=commandComplete
+        )
