@@ -13,21 +13,22 @@
 #
 # Copyright Buildbot Team Members
 
+from typing import Union
+
 from buildbot.process.properties import Properties
 from buildbot.test.fake.state import State
 
 
 class Change(State):
-
     project = ''
     repository = ''
     branch = ''
     category = ''
     codebase = ''
-    properties = {}
+    properties: Union[dict, Properties] = {}
 
     def __init__(self, **kw):
-        State.__init__(self, **kw)
+        super().__init__(**kw)
         # change.properties is a IProperties
         props = Properties()
         props.update(self.properties, "test")
