@@ -26,7 +26,6 @@ from buildbot.util import service
 
 
 class FakeUpdates(service.AsyncService):
-
     # unlike "real" update methods, all of the fake methods are here in a
     # single class.
 
@@ -72,10 +71,23 @@ class FakeUpdates(service.AsyncService):
 
     # update methods
 
-    def addChange(self, files=None, comments=None, author=None, committer=None,
-                  revision=None, when_timestamp=None, branch=None, category=None,
-                  revlink='', properties=None, repository='', codebase=None,
-                  project='', src=None):
+    def addChange(
+        self,
+        files=None,
+        comments=None,
+        author=None,
+        committer=None,
+        revision=None,
+        when_timestamp=None,
+        branch=None,
+        category=None,
+        revlink='',
+        properties=None,
+        repository='',
+        codebase=None,
+        project='',
+        src=None,
+    ):
         if properties is None:
             properties = {}
 
@@ -91,17 +103,19 @@ class FakeUpdates(service.AsyncService):
         self.testcase.assertIsInstance(branch, (type(None), str))
 
         if callable(category):
-            pre_change = self.master.config.preChangeGenerator(author=author,
-                                                               committer=committer,
-                                                               files=files,
-                                                               comments=comments,
-                                                               revision=revision,
-                                                               when_timestamp=when_timestamp,
-                                                               branch=branch,
-                                                               revlink=revlink,
-                                                               properties=properties,
-                                                               repository=repository,
-                                                               project=project)
+            pre_change = self.master.config.preChangeGenerator(
+                author=author,
+                committer=committer,
+                files=files,
+                comments=comments,
+                revision=revision,
+                when_timestamp=when_timestamp,
+                branch=branch,
+                revlink=revlink,
+                properties=properties,
+                repository=repository,
+                project=project,
+            )
             category = category(pre_change)
 
         self.testcase.assertIsInstance(category, (type(None), str))
@@ -136,9 +150,20 @@ class FakeUpdates(service.AsyncService):
         return defer.succeed(None)
 
     @defer.inlineCallbacks
-    def addBuildset(self, waited_for, scheduler=None, sourcestamps=None, reason='',
-                    properties=None, builderids=None, external_idstring=None,
-                    parent_buildid=None, parent_relationship=None, priority=0):
+    def addBuildset(
+        self,
+        waited_for,
+        scheduler=None,
+        sourcestamps=None,
+        reason='',
+        properties=None,
+        builderids=None,
+        external_idstring=None,
+        rebuilt_buildid=None,
+        parent_buildid=None,
+        parent_relationship=None,
+        priority=0,
+    ):
         if sourcestamps is None:
             sourcestamps = []
         if properties is None:
@@ -155,8 +180,7 @@ class FakeUpdates(service.AsyncService):
         self.testcase.assertIsInstance(reason, str)
         self.assertProperties(sourced=True, properties=properties)
         self.testcase.assertIsInstance(builderids, list)
-        self.testcase.assertIsInstance(external_idstring,
-                                       (type(None), str))
+        self.testcase.assertIsInstance(external_idstring, (type(None), str))
 
         self.buildsetsAdded.append(locals())
         self.buildsetsAdded[-1].pop('self')
@@ -164,10 +188,16 @@ class FakeUpdates(service.AsyncService):
         # call through to the db layer, since many scheduler tests expect to
         # find the buildset in the db later - TODO fix this!
         bsid, brids = yield self.master.db.buildsets.addBuildset(
-            sourcestamps=sourcestamps, reason=reason,
-            properties=properties, builderids=builderids,
-            waited_for=waited_for, external_idstring=external_idstring,
-            parent_buildid=parent_buildid, parent_relationship=parent_relationship)
+            sourcestamps=sourcestamps,
+            reason=reason,
+            properties=properties,
+            builderids=builderids,
+            waited_for=waited_for,
+            external_idstring=external_idstring,
+            rebuilt_buildid=rebuilt_buildid,
+            parent_buildid=parent_buildid,
+            parent_relationship=parent_relationship,
+        )
         return (bsid, brids)
 
     def maybeBuildsetComplete(self, bsid):
@@ -176,15 +206,21 @@ class FakeUpdates(service.AsyncService):
 
     @defer.inlineCallbacks
     def claimBuildRequests(self, brids, claimed_at=None):
-        validation.verifyType(self.testcase, 'brids', brids,
-                              validation.ListValidator(validation.IntValidator()))
-        validation.verifyType(self.testcase, 'claimed_at', claimed_at,
-                              validation.NoneOk(validation.DateTimeValidator()))
+        validation.verifyType(
+            self.testcase, 'brids', brids, validation.ListValidator(validation.IntValidator())
+        )
+        validation.verifyType(
+            self.testcase,
+            'claimed_at',
+            claimed_at,
+            validation.NoneOk(validation.DateTimeValidator()),
+        )
         if not brids:
             return True
         try:
             yield self.master.db.buildrequests.claimBuildRequests(
-                brids=brids, claimed_at=claimed_at)
+                brids=brids, claimed_at=claimed_at
+            )
         except AlreadyClaimedError:
             return False
         self.claimedBuildRequests.update(set(brids))
@@ -192,19 +228,24 @@ class FakeUpdates(service.AsyncService):
 
     @defer.inlineCallbacks
     def unclaimBuildRequests(self, brids):
-        validation.verifyType(self.testcase, 'brids', brids,
-                              validation.ListValidator(validation.IntValidator()))
+        validation.verifyType(
+            self.testcase, 'brids', brids, validation.ListValidator(validation.IntValidator())
+        )
         self.claimedBuildRequests.difference_update(set(brids))
         if brids:
             yield self.master.db.buildrequests.unclaimBuildRequests(brids)
 
     def completeBuildRequests(self, brids, results, complete_at=None):
-        validation.verifyType(self.testcase, 'brids', brids,
-                              validation.ListValidator(validation.IntValidator()))
-        validation.verifyType(self.testcase, 'results', results,
-                              validation.IntValidator())
-        validation.verifyType(self.testcase, 'complete_at', complete_at,
-                              validation.NoneOk(validation.DateTimeValidator()))
+        validation.verifyType(
+            self.testcase, 'brids', brids, validation.ListValidator(validation.IntValidator())
+        )
+        validation.verifyType(self.testcase, 'results', results, validation.IntValidator())
+        validation.verifyType(
+            self.testcase,
+            'complete_at',
+            complete_at,
+            validation.NoneOk(validation.DateTimeValidator()),
+        )
         return defer.succeed(True)
 
     def rebuildBuildrequest(self, buildrequest):
@@ -220,16 +261,11 @@ class FakeUpdates(service.AsyncService):
         description_html,
     ):
         yield self.master.db.projects.update_project_info(
-            projectid,
-            slug,
-            description,
-            description_format,
-            description_html
+            projectid, slug, description, description_format, description_html
         )
 
     def find_project_id(self, name):
-        validation.verifyType(self.testcase, 'project name', name,
-                              validation.StringValidator())
+        validation.verifyType(self.testcase, 'project name', name, validation.StringValidator())
         return self.master.db.projects.find_project_id(name)
 
     def updateBuilderList(self, masterid, builderNames):
@@ -240,10 +276,12 @@ class FakeUpdates(service.AsyncService):
         return defer.succeed(None)
 
     @defer.inlineCallbacks
-    def updateBuilderInfo(self, builderid, description, description_format, description_html,
-                          projectid, tags):
-        yield self.master.db.builders.updateBuilderInfo(builderid, description, description_format,
-                                                        description_html, projectid, tags)
+    def updateBuilderInfo(
+        self, builderid, description, description_format, description_html, projectid, tags
+    ):
+        yield self.master.db.builders.updateBuilderInfo(
+            builderid, description, description_format, description_html, projectid, tags
+        )
 
     def masterDeactivated(self, masterid):
         return defer.succeed(None)
@@ -252,31 +290,27 @@ class FakeUpdates(service.AsyncService):
         return self.master.db.schedulers.findSchedulerId(name)
 
     def forget_about_it(self, name):
-        validation.verifyType(self.testcase, 'scheduler name', name,
-                              validation.StringValidator())
+        validation.verifyType(self.testcase, 'scheduler name', name, validation.StringValidator())
         if name not in self.schedulerIds:
-            self.schedulerIds[name] = max(
-                [0] + list(self.schedulerIds.values())) + 1
+            self.schedulerIds[name] = max([0, *list(self.schedulerIds.values())]) + 1
         return defer.succeed(self.schedulerIds[name])
 
     def findChangeSourceId(self, name):
-        validation.verifyType(self.testcase, 'changesource name', name,
-                              validation.StringValidator())
+        validation.verifyType(
+            self.testcase, 'changesource name', name, validation.StringValidator()
+        )
         if name not in self.changesourceIds:
-            self.changesourceIds[name] = max(
-                [0] + list(self.changesourceIds.values())) + 1
+            self.changesourceIds[name] = max([0, *list(self.changesourceIds.values())]) + 1
         return defer.succeed(self.changesourceIds[name])
 
     def findBuilderId(self, name):
-        validation.verifyType(self.testcase, 'builder name', name,
-                              validation.StringValidator())
+        validation.verifyType(self.testcase, 'builder name', name, validation.StringValidator())
         return self.master.db.builders.findBuilderId(name)
 
     def trySetSchedulerMaster(self, schedulerid, masterid):
         currentMasterid = self.schedulerMasters.get(schedulerid)
         if isinstance(currentMasterid, Exception):
-            return defer.fail(failure.Failure(
-                currentMasterid))
+            return defer.fail(failure.Failure(currentMasterid))
         if currentMasterid and masterid is not None:
             return defer.succeed(False)
         self.schedulerMasters[schedulerid] = masterid
@@ -285,52 +319,49 @@ class FakeUpdates(service.AsyncService):
     def trySetChangeSourceMaster(self, changesourceid, masterid):
         currentMasterid = self.changesourceMasters.get(changesourceid)
         if isinstance(currentMasterid, Exception):
-            return defer.fail(failure.Failure(
-                currentMasterid))
+            return defer.fail(failure.Failure(currentMasterid))
         if currentMasterid and masterid is not None:
             return defer.succeed(False)
         self.changesourceMasters[changesourceid] = masterid
         return defer.succeed(True)
 
     def addBuild(self, builderid, buildrequestid, workerid):
-        validation.verifyType(self.testcase, 'builderid', builderid,
-                              validation.IntValidator())
-        validation.verifyType(self.testcase, 'buildrequestid', buildrequestid,
-                              validation.IntValidator())
-        validation.verifyType(self.testcase, 'workerid', workerid,
-                              validation.IntValidator())
+        validation.verifyType(self.testcase, 'builderid', builderid, validation.IntValidator())
+        validation.verifyType(
+            self.testcase, 'buildrequestid', buildrequestid, validation.IntValidator()
+        )
+        validation.verifyType(self.testcase, 'workerid', workerid, validation.IntValidator())
         return defer.succeed((10, 1))
 
     def generateNewBuildEvent(self, buildid):
-        validation.verifyType(self.testcase, 'buildid', buildid,
-                              validation.IntValidator())
+        validation.verifyType(self.testcase, 'buildid', buildid, validation.IntValidator())
         return defer.succeed(None)
 
     def setBuildStateString(self, buildid, state_string):
-        validation.verifyType(self.testcase, 'buildid', buildid,
-                              validation.IntValidator())
-        validation.verifyType(self.testcase, 'state_string', state_string,
-                              validation.StringValidator())
+        validation.verifyType(self.testcase, 'buildid', buildid, validation.IntValidator())
+        validation.verifyType(
+            self.testcase, 'state_string', state_string, validation.StringValidator()
+        )
+        return defer.succeed(None)
+
+    def add_build_locks_duration(self, buildid, duration_s):
+        validation.verifyType(self.testcase, 'buildid', buildid, validation.IntValidator())
+        validation.verifyType(self.testcase, 'duration_s', duration_s, validation.IntValidator())
         return defer.succeed(None)
 
     def finishBuild(self, buildid, results):
-        validation.verifyType(self.testcase, 'buildid', buildid,
-                              validation.IntValidator())
-        validation.verifyType(self.testcase, 'results', results,
-                              validation.IntValidator())
+        validation.verifyType(self.testcase, 'buildid', buildid, validation.IntValidator())
+        validation.verifyType(self.testcase, 'results', results, validation.IntValidator())
         return defer.succeed(None)
 
     def setBuildProperty(self, buildid, name, value, source):
-        validation.verifyType(self.testcase, 'buildid', buildid,
-                              validation.IntValidator())
-        validation.verifyType(self.testcase, 'name', name,
-                              validation.StringValidator())
+        validation.verifyType(self.testcase, 'buildid', buildid, validation.IntValidator())
+        validation.verifyType(self.testcase, 'name', name, validation.StringValidator())
         try:
             json.dumps(value)
         except (TypeError, ValueError):
             self.testcase.fail(f"Value for {name} is not JSON-able")
-        validation.verifyType(self.testcase, 'source', source,
-                              validation.StringValidator())
+        validation.verifyType(self.testcase, 'source', source, validation.StringValidator())
         return defer.succeed(None)
 
     @defer.inlineCallbacks
@@ -340,102 +371,98 @@ class FakeUpdates(service.AsyncService):
             yield self.setBuildProperty(buildid, k, v, s)
 
     def addStep(self, buildid, name):
-        validation.verifyType(self.testcase, 'buildid', buildid,
-                              validation.IntValidator())
-        validation.verifyType(self.testcase, 'name', name,
-                              validation.IdentifierValidator(50))
+        validation.verifyType(self.testcase, 'buildid', buildid, validation.IntValidator())
+        validation.verifyType(self.testcase, 'name', name, validation.IdentifierValidator(50))
         return defer.succeed((10, 1, name))
 
     def addStepURL(self, stepid, name, url):
-        validation.verifyType(self.testcase, 'stepid', stepid,
-                              validation.IntValidator())
-        validation.verifyType(self.testcase, 'name', name,
-                              validation.StringValidator())
-        validation.verifyType(self.testcase, 'url', url,
-                              validation.StringValidator())
+        validation.verifyType(self.testcase, 'stepid', stepid, validation.IntValidator())
+        validation.verifyType(self.testcase, 'name', name, validation.StringValidator())
+        validation.verifyType(self.testcase, 'url', url, validation.StringValidator())
         self.stepUrls.setdefault(stepid, []).append((name, url))
         return defer.succeed(None)
 
-    def startStep(self, stepid):
-        validation.verifyType(self.testcase, 'stepid', stepid,
-                              validation.IntValidator())
+    def startStep(self, stepid, started_at=None, locks_acquired=False):
+        validation.verifyType(self.testcase, 'stepid', stepid, validation.IntValidator())
+        validation.verifyType(
+            self.testcase, "started_at", started_at, validation.NoneOk(validation.IntValidator())
+        )
+        validation.verifyType(
+            self.testcase, "locks_acquired", locks_acquired, validation.BooleanValidator()
+        )
+        return defer.succeed(None)
+
+    def set_step_locks_acquired_at(self, stepid, locks_acquired_at=None):
+        validation.verifyType(self.testcase, 'stepid', stepid, validation.IntValidator())
+        validation.verifyType(
+            self.testcase,
+            "locks_acquired_at",
+            locks_acquired_at,
+            validation.NoneOk(validation.IntValidator()),
+        )
         return defer.succeed(None)
 
     def setStepStateString(self, stepid, state_string):
-        validation.verifyType(self.testcase, 'stepid', stepid,
-                              validation.IntValidator())
-        validation.verifyType(self.testcase, 'state_string', state_string,
-                              validation.StringValidator())
+        validation.verifyType(self.testcase, 'stepid', stepid, validation.IntValidator())
+        validation.verifyType(
+            self.testcase, 'state_string', state_string, validation.StringValidator()
+        )
         self.stepStateString[stepid] = state_string
         return defer.succeed(None)
 
     def finishStep(self, stepid, results, hidden):
-        validation.verifyType(self.testcase, 'stepid', stepid,
-                              validation.IntValidator())
-        validation.verifyType(self.testcase, 'results', results,
-                              validation.IntValidator())
-        validation.verifyType(self.testcase, 'hidden', hidden,
-                              validation.BooleanValidator())
+        validation.verifyType(self.testcase, 'stepid', stepid, validation.IntValidator())
+        validation.verifyType(self.testcase, 'results', results, validation.IntValidator())
+        validation.verifyType(self.testcase, 'hidden', hidden, validation.BooleanValidator())
         return defer.succeed(None)
 
     def addLog(self, stepid, name, type):
-        validation.verifyType(self.testcase, 'stepid', stepid,
-                              validation.IntValidator())
-        validation.verifyType(self.testcase, 'name', name,
-                              validation.StringValidator())
-        validation.verifyType(self.testcase, 'type', type,
-                              validation.IdentifierValidator(1))
-        logid = max([0] + list(self.logs)) + 1
+        validation.verifyType(self.testcase, 'stepid', stepid, validation.IntValidator())
+        validation.verifyType(self.testcase, 'name', name, validation.StringValidator())
+        validation.verifyType(self.testcase, 'type', type, validation.IdentifierValidator(1))
+        logid = max([0, *list(self.logs)]) + 1
         self.logs[logid] = {"name": name, "type": type, "content": [], "finished": False}
         return defer.succeed(logid)
 
     def finishLog(self, logid):
-        validation.verifyType(self.testcase, 'logid', logid,
-                              validation.IntValidator())
+        validation.verifyType(self.testcase, 'logid', logid, validation.IntValidator())
         self.logs[logid]['finished'] = True
         return defer.succeed(None)
 
     def compressLog(self, logid):
-        validation.verifyType(self.testcase, 'logid', logid,
-                              validation.IntValidator())
+        validation.verifyType(self.testcase, 'logid', logid, validation.IntValidator())
         return defer.succeed(None)
 
     def appendLog(self, logid, content):
-        validation.verifyType(self.testcase, 'logid', logid,
-                              validation.IntValidator())
-        validation.verifyType(self.testcase, 'content', content,
-                              validation.StringValidator())
+        validation.verifyType(self.testcase, 'logid', logid, validation.IntValidator())
+        validation.verifyType(self.testcase, 'content', content, validation.StringValidator())
         self.testcase.assertEqual(content[-1], '\n')
         self.logs[logid]['content'].append(content)
         return defer.succeed(None)
 
     def findWorkerId(self, name):
-        validation.verifyType(self.testcase, 'worker name', name,
-                              validation.IdentifierValidator(50))
+        validation.verifyType(
+            self.testcase, 'worker name', name, validation.IdentifierValidator(50)
+        )
         # this needs to actually get inserted into the db (fake or real) since
         # getWorker will get called later
         return self.master.db.workers.findWorkerId(name)
 
     def workerConnected(self, workerid, masterid, workerinfo):
         return self.master.db.workers.workerConnected(
-            workerid=workerid,
-            masterid=masterid,
-            workerinfo=workerinfo)
+            workerid=workerid, masterid=masterid, workerinfo=workerinfo
+        )
 
     def workerConfigured(self, workerid, masterid, builderids):
         return self.master.db.workers.workerConfigured(
-            workerid=workerid,
-            masterid=masterid,
-            builderids=builderids)
+            workerid=workerid, masterid=masterid, builderids=builderids
+        )
 
     def workerDisconnected(self, workerid, masterid):
-        return self.master.db.workers.workerDisconnected(
-            workerid=workerid,
-            masterid=masterid)
+        return self.master.db.workers.workerDisconnected(workerid=workerid, masterid=masterid)
 
     def deconfigureAllWorkersForMaster(self, masterid):
-        return self.master.db.workers.deconfigureAllWorkersForMaster(
-            masterid=masterid)
+        return self.master.db.workers.deconfigureAllWorkersForMaster(masterid=masterid)
 
     def workerMissing(self, workerid, masterid, last_connection, notify):
         self.missingWorkers.append((workerid, masterid, last_connection, notify))
@@ -443,11 +470,11 @@ class FakeUpdates(service.AsyncService):
     def schedulerEnable(self, schedulerid, v):
         return self.master.db.schedulers.enable(schedulerid, v)
 
-    def setWorkerState(self, workerid, paused, graceful):
-        return self.master.db.workers.setWorkerState(
-            workerid=workerid,
-            paused=paused,
-            graceful=graceful)
+    def set_worker_paused(self, workerid, paused, pause_reason=None):
+        return self.master.db.workers.set_worker_paused(workerid, paused, pause_reason=pause_reason)
+
+    def set_worker_graceful(self, workerid, graceful):
+        return self.master.db.workers.set_worker_graceful(workerid, graceful)
 
     # methods form BuildData resource
     @defer.inlineCallbacks
@@ -464,34 +491,45 @@ class FakeUpdates(service.AsyncService):
         validation.verifyType(self.testcase, 'builderid', builderid, validation.IntValidator())
         validation.verifyType(self.testcase, 'buildid', buildid, validation.IntValidator())
         validation.verifyType(self.testcase, 'stepid', stepid, validation.IntValidator())
-        validation.verifyType(self.testcase, 'description', description,
-                              validation.StringValidator())
+        validation.verifyType(
+            self.testcase, 'description', description, validation.StringValidator()
+        )
         validation.verifyType(self.testcase, 'category', category, validation.StringValidator())
         validation.verifyType(self.testcase, 'value_unit', value_unit, validation.StringValidator())
 
-        test_result_setid = \
-            yield self.master.db.test_result_sets.addTestResultSet(builderid, buildid, stepid,
-                                                                   description, category,
-                                                                   value_unit)
+        test_result_setid = yield self.master.db.test_result_sets.addTestResultSet(
+            builderid, buildid, stepid, description, category, value_unit
+        )
         return test_result_setid
 
     @defer.inlineCallbacks
     def completeTestResultSet(self, test_result_setid, tests_passed=None, tests_failed=None):
-        validation.verifyType(self.testcase, 'test_result_setid', test_result_setid,
-                              validation.IntValidator())
-        validation.verifyType(self.testcase, 'tests_passed', tests_passed,
-                              validation.NoneOk(validation.IntValidator()))
-        validation.verifyType(self.testcase, 'tests_failed', tests_failed,
-                              validation.NoneOk(validation.IntValidator()))
+        validation.verifyType(
+            self.testcase, 'test_result_setid', test_result_setid, validation.IntValidator()
+        )
+        validation.verifyType(
+            self.testcase,
+            'tests_passed',
+            tests_passed,
+            validation.NoneOk(validation.IntValidator()),
+        )
+        validation.verifyType(
+            self.testcase,
+            'tests_failed',
+            tests_failed,
+            validation.NoneOk(validation.IntValidator()),
+        )
 
-        yield self.master.db.test_result_sets.completeTestResultSet(test_result_setid,
-                                                                    tests_passed, tests_failed)
+        yield self.master.db.test_result_sets.completeTestResultSet(
+            test_result_setid, tests_passed, tests_failed
+        )
 
     # methods from TestResult resource
     @defer.inlineCallbacks
     def addTestResults(self, builderid, test_result_setid, result_values):
-        yield self.master.db.test_results.addTestResults(builderid, test_result_setid,
-                                                         result_values)
+        yield self.master.db.test_results.addTestResults(
+            builderid, test_result_setid, result_values
+        )
 
 
 class FakeDataConnector(service.AsyncMultiService):
@@ -523,12 +561,12 @@ class FakeDataConnector(service.AsyncMultiService):
     def getResourceType(self, name):
         return getattr(self.rtypes, name)
 
-    def get(self, path, filters=None, fields=None,
-            order=None, limit=None, offset=None):
+    def get(self, path, filters=None, fields=None, order=None, limit=None, offset=None):
         if not isinstance(path, tuple):
             raise TypeError('path must be a tuple')
-        return self.realConnector.get(path, filters=filters, fields=fields,
-                                      order=order, limit=limit, offset=offset)
+        return self.realConnector.get(
+            path, filters=filters, fields=fields, order=order, limit=limit, offset=offset
+        )
 
     def get_with_resultspec(self, path, rspec):
         if not isinstance(path, tuple):
