@@ -40,7 +40,7 @@ from buildbot.www import service as wwwservice
 
 
 @implementer(IBodyProducer)
-class BytesProducer():
+class BytesProducer:
     def __init__(self, body):
         self.body = body
         self.length = len(body)
@@ -57,43 +57,56 @@ class BytesProducer():
 
 
 class TelegramBot(db.RealDatabaseWithConnectorMixin, www.RequiresWwwMixin, unittest.TestCase):
-
     master = None
 
-    _commands = [{'command': command, 'description': doc}
-                 for command, doc in telegram.TelegramContact.get_commands()]
+    _commands = [
+        {'command': command, 'description': doc}
+        for command, doc in telegram.TelegramContact.get_commands()
+    ]
 
     @defer.inlineCallbacks
-    def get_http(self, bot_token):
-        base_url = "https://api.telegram.org/telegram" + bot_token
-        http = yield fakehttpclientservice.HTTPClientService.getService(
-            self.master, self, base_url)
-        # This is necessary as Telegram will make requests in the reconfig
-        http.expect("post", "/getMe",
-                    content_json={'ok': 1, 'result': {'username': 'testbot'}})
-        http.expect("post", "/setMyCommands", json={'commands': self._commands},
-                    content_json={'ok': 1})
+    def setup_http_service(self, bot_token):
+        base_url = "https://api.telegram.org/bot" + bot_token
+        self.http = yield fakehttpclientservice.HTTPClientService.getService(
+            self.master, self, base_url
+        )
+
+    def expect_telegram_requests(self, bot_token):
+        self.http.expect(
+            "post", "/getMe", content_json={'ok': 1, 'result': {'username': 'testbot'}}
+        )
+        self.http.expect(
+            "post", "/setMyCommands", json={'commands': self._commands}, content_json={'ok': 1}
+        )
         if bot_token == 'poll':
-            http.expect("post", "/deleteWebhook",
-                        content_json={'ok': 1})
+            self.http.expect("post", "/deleteWebhook", content_json={'ok': 1})
         else:
-            http.expect("post", "/setWebhook",
-                        json={'url': bytes2unicode(self.bot_url)},
-                        content_json={'ok': 1})
-        return http
+            self.http.expect(
+                "post",
+                "/setWebhook",
+                json={'url': bytes2unicode(self.bot_url)},
+                content_json={'ok': 1},
+            )
 
     @defer.inlineCallbacks
     def setUp(self):
         table_names = [
-            'objects', 'object_state', 'masters',
-            'workers', 'configured_workers', 'connected_workers',
-            'builder_masters', 'builders', 'projects',
+            'objects',
+            'object_state',
+            'masters',
+            'workers',
+            'configured_workers',
+            'connected_workers',
+            'builder_masters',
+            'builders',
+            'projects',
         ]
 
         master = fakemaster.make_master(self, wantRealReactor=True)
 
-        yield self.setUpRealDatabaseWithConnector(master, table_names=table_names,
-                                                  sqlite_memory=False)
+        yield self.setUpRealDatabaseWithConnector(
+            master, table_names=table_names, sqlite_memory=False
+        )
 
         master.data = dataconnector.DataConnector()
         yield master.data.setServiceParent(master)
@@ -110,7 +123,7 @@ class TelegramBot(db.RealDatabaseWithConnectorMixin, www.RequiresWwwMixin, unitt
             "auth": auth.NoAuth(),
             "authz": authz.Authz(),
             "avatar_methods": [],
-            "logfileName": 'http.log'
+            "logfileName": 'http.log',
         }
         master.www = wwwservice.WWWService()
         yield master.www.setServiceParent(master)
@@ -132,14 +145,15 @@ class TelegramBot(db.RealDatabaseWithConnectorMixin, www.RequiresWwwMixin, unitt
 
         self.agent = client.Agent(reactor)
 
+        self.bot_url = self.url + b"telegram12345:secret"
+        yield self.setup_http_service('12345:secret')
+        self.expect_telegram_requests('12345:secret')
+
         # create a telegram bot service
         tb = master.config.services['TelegramBot'] = telegram.TelegramBot(
-            bot_token='12345:secret', useWebhook=True,
-            chat_ids=[-123456], notify_events=['worker']
+            bot_token='12345:secret', useWebhook=True, chat_ids=[-123456], notify_events=['worker']
         )
-        tb._get_http = self.get_http
         yield tb.setServiceParent(self.master)
-        self.bot_url = self.url + b"telegram12345:secret"
 
         yield tb.startService()
 
@@ -147,6 +161,7 @@ class TelegramBot(db.RealDatabaseWithConnectorMixin, www.RequiresWwwMixin, unitt
 
         def send_message(chat, message, **kwargs):
             self.sent_messages.append((chat, message))
+
         tb.bot.send_message = send_message
 
     @defer.inlineCallbacks
@@ -158,62 +173,72 @@ class TelegramBot(db.RealDatabaseWithConnectorMixin, www.RequiresWwwMixin, unitt
 
     @defer.inlineCallbacks
     def testWebhook(self):
-        payload = unicode2bytes(json.dumps({
-            "update_id": 12345,
-            "message": {
-                "message_id": 123,
-                "from": {
-                    "id": 123456789,
-                    "first_name": "Alice",
+        payload = unicode2bytes(
+            json.dumps({
+                "update_id": 12345,
+                "message": {
+                    "message_id": 123,
+                    "from": {
+                        "id": 123456789,
+                        "first_name": "Alice",
+                    },
+                    "chat": {"id": -12345678, "title": "Wonderlands", "type": "group"},
+                    "date": 1566688888,
+                    "text": "/getid",
                 },
-                "chat": {
-                    "id": -12345678,
-                    "title": "Wonderlands",
-                    "type": "group"
-                },
-                "date": 1566688888,
-                "text": "/getid",
-            }
-        }))
+            })
+        )
 
-        pg = yield self.agent.request(b'POST', self.bot_url,
-                                      Headers({'Content-Type': ['application/json']}),
-                                      BytesProducer(payload))
-        self.assertEqual(pg.code, 202,
-                         f"did not get 202 response for '{bytes2unicode(self.bot_url)}'")
+        pg = yield self.agent.request(
+            b'POST',
+            self.bot_url,
+            Headers({'Content-Type': ['application/json']}),
+            BytesProducer(payload),
+        )
+        self.assertEqual(
+            pg.code, 202, f"did not get 202 response for '{bytes2unicode(self.bot_url)}'"
+        )
         self.assertIn('123456789', self.sent_messages[0][1])
         self.assertIn('-12345678', self.sent_messages[1][1])
 
     @defer.inlineCallbacks
     def testReconfig(self):
+        # initial config and reconfig will issue requests twice
+        self.expect_telegram_requests('12345:secret')
+
         tb = self.master.config.services['TelegramBot']
         yield tb.reconfigService(
-            bot_token='12345:secret', useWebhook=True,
-            chat_ids=[-123456], notify_events=['problem']
+            bot_token='12345:secret', useWebhook=True, chat_ids=[-123456], notify_events=['problem']
         )
 
     @defer.inlineCallbacks
     def testLoadState(self):
         tboid = yield self.master.db.state.getObjectId(
-            'testbot', 'buildbot.reporters.telegram.TelegramWebhookBot')
+            'testbot', 'buildbot.reporters.telegram.TelegramWebhookBot'
+        )
         yield self.insert_test_data([
-            fakedb.ObjectState(objectid=tboid, name='notify_events',
-                               value_json='[[123456789, ["started", "finished"]]]'),
-            fakedb.ObjectState(objectid=tboid, name='missing_workers',
-                               value_json='[[123456789, [12]]]'),
+            fakedb.ObjectState(
+                objectid=tboid,
+                name='notify_events',
+                value_json='[[123456789, ["started", "finished"]]]',
+            ),
+            fakedb.ObjectState(
+                objectid=tboid, name='missing_workers', value_json='[[123456789, [12]]]'
+            ),
         ])
 
         tb = self.master.config.services['TelegramBot']
         yield tb.bot.loadState()
         c = tb.bot.getContact({'id': 123456789}, {'id': 123456789})
-        self.assertEquals(c.channel.notify_events, {'started', 'finished'})
-        self.assertEquals(c.channel.missing_workers, {12})
+        self.assertEqual(c.channel.notify_events, {'started', 'finished'})
+        self.assertEqual(c.channel.missing_workers, {12})
 
     @defer.inlineCallbacks
     def testSaveState(self):
         tb = self.master.config.services['TelegramBot']
         tboid = yield self.master.db.state.getObjectId(
-            'testbot', 'buildbot.reporters.telegram.TelegramWebhookBot')
+            'testbot', 'buildbot.reporters.telegram.TelegramWebhookBot'
+        )
 
         notify_events = yield self.master.db.state.getState(tboid, 'notify_events', ())
         missing_workers = yield self.master.db.state.getState(tboid, 'missing_workers', ())
@@ -242,7 +267,7 @@ class TelegramBot(db.RealDatabaseWithConnectorMixin, www.RequiresWwwMixin, unitt
 
         tb = self.master.config.services['TelegramBot']
         channel = tb.bot.getChannel(-123456)
-        self.assertEquals(channel.notify_events, {'worker'})
+        self.assertEqual(channel.notify_events, {'worker'})
 
         yield self.master.data.updates.workerMissing(
             workerid=1,
@@ -250,13 +275,14 @@ class TelegramBot(db.RealDatabaseWithConnectorMixin, www.RequiresWwwMixin, unitt
             last_connection='long time ago',
             notify=['admin@worker.org'],
         )
-        self.assertEquals(self.sent_messages[0][1],
-                          "Worker `local1` is missing. It was seen last on long time ago.")
+        self.assertEqual(
+            self.sent_messages[0][1],
+            "Worker `local1` is missing. It was seen last on long time ago.",
+        )
 
         yield self.master.data.updates.workerConnected(
             workerid=1,
             masterid=self.master.masterid,
             workerinfo={},
         )
-        self.assertEquals(self.sent_messages[1][1],
-                          "Worker `local1` is back online.")
+        self.assertEqual(self.sent_messages[1][1], "Worker `local1` is back online.")
