@@ -22,8 +22,7 @@ from buildbot.test import fakedb
 from buildbot.test.util import connector_component
 
 
-class TestBadRows(connector_component.ConnectorComponentMixin,
-                  unittest.TestCase):
+class TestBadRows(connector_component.ConnectorComponentMixin, unittest.TestCase):
     # See bug #1952 for details.  This checks that users who used a development
     # version between 0.8.3 and 0.8.4 get reasonable behavior even though some
     # rows in the change_properties database do not contain a proper [value,
@@ -32,8 +31,8 @@ class TestBadRows(connector_component.ConnectorComponentMixin,
     @defer.inlineCallbacks
     def setUp(self):
         yield self.setUpConnectorComponent(
-            table_names=['patches', 'sourcestamps', 'changes',
-                         'change_properties', 'change_files'])
+            table_names=['patches', 'sourcestamps', 'changes', 'change_properties', 'change_files']
+        )
 
         self.db.changes = changes.ChangesConnectorComponent(self.db)
 
@@ -44,32 +43,22 @@ class TestBadRows(connector_component.ConnectorComponentMixin,
     def test_bogus_row_no_source(self):
         yield self.insert_test_data([
             fakedb.SourceStamp(id=10),
-            fakedb.ChangeProperty(changeid=13, property_name='devel',
-                                  property_value='"no source"'),
+            fakedb.ChangeProperty(changeid=13, property_name='devel', property_value='"no source"'),
             fakedb.Change(changeid=13, sourcestampid=10),
         ])
 
         c = yield self.db.changes.getChange(13)
 
-        self.assertEqual(c['properties'],
-            {
-            "devel": ('no source', 'Change')
-            }
-        )
+        self.assertEqual(c.properties, {"devel": ('no source', 'Change')})
 
     @defer.inlineCallbacks
     def test_bogus_row_jsoned_list(self):
         yield self.insert_test_data([
             fakedb.SourceStamp(id=10),
-            fakedb.ChangeProperty(changeid=13, property_name='devel',
-                                  property_value='[1, 2]'),
+            fakedb.ChangeProperty(changeid=13, property_name='devel', property_value='[1, 2]'),
             fakedb.Change(changeid=13, sourcestampid=10),
         ])
 
         c = yield self.db.changes.getChange(13)
 
-        self.assertEqual(c['properties'],
-            {
-            "devel": ([1, 2], 'Change')
-            }
-        )
+        self.assertEqual(c.properties, {"devel": ([1, 2], 'Change')})
