@@ -18,7 +18,6 @@ import re
 import sys
 from io import StringIO
 from unittest import mock
-from unittest.case import SkipTest
 
 from twisted.internet import defer
 from twisted.internet import reactor
@@ -47,7 +46,6 @@ except ImportError:
 
 @implementer(IConfigLoader)
 class DictLoader:
-
     def __init__(self, config_dict):
         self.config_dict = config_dict
 
@@ -63,8 +61,7 @@ def getMaster(case, reactor, config_dict):
     basedir = FilePath(case.mktemp())
     basedir.createDirectory()
     config_dict['buildbotNetUsageData'] = None
-    master = BuildMaster(
-        basedir.path, reactor=reactor, config_loader=DictLoader(config_dict))
+    master = BuildMaster(basedir.path, reactor=reactor, config_loader=DictLoader(config_dict))
 
     if 'db_url' not in config_dict:
         config_dict['db_url'] = 'sqlite://'
@@ -84,9 +81,7 @@ def getMaster(case, reactor, config_dict):
     return master
 
 
-class RunFakeMasterTestCase(unittest.TestCase, TestReactorMixin,
-                            DebugIntegrationLogsMixin):
-
+class RunFakeMasterTestCase(unittest.TestCase, TestReactorMixin, DebugIntegrationLogsMixin):
     def setUp(self):
         self.setup_test_reactor()
         self.setupDebugIntegrationLogs()
@@ -116,7 +111,7 @@ class RunFakeMasterTestCase(unittest.TestCase, TestReactorMixin,
     @defer.inlineCallbacks
     def assertBuildResults(self, build_id, result):
         dbdict = yield self.master.db.builds.getBuild(build_id)
-        self.assertEqual(result, dbdict['results'])
+        self.assertEqual(result, dbdict.results)
 
     @defer.inlineCallbacks
     def assertStepStateString(self, step_id, state_string):
@@ -129,8 +124,15 @@ class RunFakeMasterTestCase(unittest.TestCase, TestReactorMixin,
         data_logs = yield self.master.data.get(('builds', build_id, 'steps', 1, 'logs'))
         for log in data_logs:
             self.assertTrue(log['complete'])
-            log_contents = yield self.master.data.get(('builds', build_id, 'steps', 1, 'logs',
-                                                       log['slug'], 'contents'))
+            log_contents = yield self.master.data.get((
+                'builds',
+                build_id,
+                'steps',
+                1,
+                'logs',
+                log['slug'],
+                'contents',
+            ))
 
             got_logs[log['name']] = log_contents['content']
 
@@ -143,11 +145,7 @@ class RunFakeMasterTestCase(unittest.TestCase, TestReactorMixin,
             waited_for=False,
             builderids=builder_ids,
             sourcestamps=[
-                {'codebase': '',
-                 'repository': '',
-                 'branch': None,
-                 'revision': None,
-                 'project': ''},
+                {'codebase': '', 'repository': '', 'branch': None, 'revision': None, 'project': ''},
             ],
             properties=properties,
         )
@@ -160,13 +158,13 @@ class RunFakeMasterTestCase(unittest.TestCase, TestReactorMixin,
 
     @defer.inlineCallbacks
     def do_test_build(self, builder_id):
-
         # setup waiting for build to finish
         d_finished = defer.Deferred()
 
         def on_finished(_, __):
             if not d_finished.called:
                 d_finished.callback(None)
+
         consumer = yield self.master.mq.startConsuming(on_finished, ('builds', None, 'finished'))
 
         # start the builder
@@ -182,7 +180,7 @@ class RunMasterBase(unittest.TestCase):
 
     # All tests that start master need higher timeout due to test runtime variability on
     # oversubscribed hosts.
-    timeout = 40
+    timeout = 60
 
     if Worker is None:
         skip = "buildbot-worker package is not installed"
@@ -212,33 +210,27 @@ class RunMasterBase(unittest.TestCase):
                 workerclass = worker.LocalWorker
             else:
                 raise RuntimeError(f"{self.proto} protocol is not supported.")
-            config_dict['workers'] = [workerclass("local1", password=Interpolate("localpw"),
-                                                  missing_timeout=0)]
+            config_dict['workers'] = [
+                workerclass("local1", password=Interpolate("localpw"), missing_timeout=0)
+            ]
             config_dict['protocols'] = proto
 
         m = yield getMaster(self, reactor, config_dict)
         self.master_config_dict = config_dict
         self.master = m
-        self.assertFalse(stop.called,
-                         "startService tried to stop the reactor; check logs")
+        self.assertFalse(stop.called, "startService tried to stop the reactor; check logs")
 
         if not startWorker:
             return
 
         if self.proto in ('pb', 'msgpack'):
             sandboxed_worker_path = os.environ.get("SANDBOXED_WORKER_PATH", None)
-            worker_python_version = os.environ.get("WORKER_PYTHON", None)
             if self.proto == 'pb':
                 protocol = 'pb'
-                dispatcher = list(m.pbmanager.dispatchers.values())[0]
+                dispatcher = next(iter(m.pbmanager.dispatchers.values()))
             else:
                 protocol = 'msgpack_experimental_v7'
-                dispatcher = list(m.msgmanager.dispatchers.values())[0]
-
-                unsupported_python_versions = ['2.7', '3.4', '3.5']
-                if sandboxed_worker_path is not None and \
-                        worker_python_version in unsupported_python_versions:
-                    raise SkipTest('MessagePack protocol requires worker python >= 3.6')
+                dispatcher = next(iter(m.msgmanager.dispatchers.values()))
 
                 # We currently don't handle connection closing cleanly.
                 dispatcher.serverFactory.setProtocolOptions(closeHandshakeTimeout=0)
@@ -251,12 +243,26 @@ class RunMasterBase(unittest.TestCase):
             worker_dir.createDirectory()
             if sandboxed_worker_path is None:
                 self.w = Worker(
-                    "127.0.0.1", workerPort, "local1", "localpw", worker_dir.path,
-                    False, protocol=protocol, **worker_kwargs)
+                    "127.0.0.1",
+                    workerPort,
+                    "local1",
+                    "localpw",
+                    worker_dir.path,
+                    False,
+                    protocol=protocol,
+                    **worker_kwargs,
+                )
             else:
                 self.w = SandboxedWorker(
-                    "127.0.0.1", workerPort, "local1", "localpw", worker_dir.path,
-                    sandboxed_worker_path, protocol=protocol, **worker_kwargs)
+                    "127.0.0.1",
+                    workerPort,
+                    "local1",
+                    "localpw",
+                    worker_dir.path,
+                    sandboxed_worker_path,
+                    protocol=protocol,
+                    **worker_kwargs,
+                )
                 self.addCleanup(self.w.shutdownWorker)
 
         elif self.proto == 'null':
@@ -275,12 +281,19 @@ class RunMasterBase(unittest.TestCase):
                     yield self.printBuild(build, dump, withLogs=True)
 
                 raise self.failureException(dump.getvalue())
+
         self.addCleanup(dump)
 
     @defer.inlineCallbacks
-    def doForceBuild(self, wantSteps=False, wantProperties=False,
-                     wantLogs=False, useChange=False, forceParams=None, triggerCallback=None):
-
+    def doForceBuild(
+        self,
+        wantSteps=False,
+        wantProperties=False,
+        wantLogs=False,
+        useChange=False,
+        forceParams=None,
+        triggerCallback=None,
+    ):
         if forceParams is None:
             forceParams = {}
         # force a build, and wait until it is finished
@@ -299,13 +312,11 @@ class RunMasterBase(unittest.TestCase):
             if self.firstbsid == data['bsid']:
                 d.callback(data)
 
-        newConsumer = yield self.master.mq.startConsuming(
-            newCallback,
-            ('buildsets', None, 'new'))
+        newConsumer = yield self.master.mq.startConsuming(newCallback, ('buildsets', None, 'new'))
 
         finishedConsumer = yield self.master.mq.startConsuming(
-            finishedCallback,
-            ('buildsets', None, 'complete'))
+            finishedCallback, ('buildsets', None, 'complete')
+        )
 
         if triggerCallback is not None:
             yield triggerCallback()
@@ -319,12 +330,13 @@ class RunMasterBase(unittest.TestCase):
         # wait until we receive the build finished event
         buildset = yield d
         buildrequests = yield self.master.data.get(
-            ('buildrequests',),
-            filters=[resultspec.Filter('buildsetid', 'eq', [buildset['bsid']])])
+            ('buildrequests',), filters=[resultspec.Filter('buildsetid', 'eq', [buildset['bsid']])]
+        )
         buildrequest = buildrequests[-1]
         builds = yield self.master.data.get(
             ('builds',),
-            filters=[resultspec.Filter('buildrequestid', 'eq', [buildrequest['buildrequestid']])])
+            filters=[resultspec.Filter('buildrequestid', 'eq', [buildrequest['buildrequestid']])],
+        )
         # if the build has been retried, there will be several matching builds.
         # We return the last build
         build = builds[-1]
@@ -344,22 +356,34 @@ class RunMasterBase(unittest.TestCase):
                     step['logs'] = yield self.master.data.get(("steps", step['stepid'], "logs"))
                     step["logs"] = list(step['logs'])
                     for log in step["logs"]:
-                        log['contents'] = yield self.master.data.get(("logs", log['logid'],
-                                                                      "contents"))
+                        log['contents'] = yield self.master.data.get((
+                            "logs",
+                            log['logid'],
+                            "contents",
+                        ))
 
         if wantProperties:
-            build["properties"] = yield self.master.data.get(("builds", build['buildid'],
-                                                              "properties"))
+            build["properties"] = yield self.master.data.get((
+                "builds",
+                build['buildid'],
+                "properties",
+            ))
 
     @defer.inlineCallbacks
     def printBuild(self, build, out=sys.stdout, withLogs=False):
         # helper for debugging: print a build
         yield self.enrichBuild(build, wantSteps=True, wantProperties=True, wantLogs=True)
-        print(f"*** BUILD {build['buildid']} *** ==> {build['state_string']} "
-              f"({statusToString(build['results'])})", file=out)
+        print(
+            f"*** BUILD {build['buildid']} *** ==> {build['state_string']} "
+            f"({statusToString(build['results'])})",
+            file=out,
+        )
         for step in build['steps']:
-            print(f"    *** STEP {step['name']} *** ==> {step['state_string']} "
-                  f"({statusToString(step['results'])})", file=out)
+            print(
+                f"    *** STEP {step['name']} *** ==> {step['state_string']} "
+                f"({statusToString(step['results'])})",
+                file=out,
+            )
             for url in step['urls']:
                 print(f"       url:{url['name']} ({url['url']})", file=out)
             for log in step['logs']:
@@ -382,8 +406,9 @@ class RunMasterBase(unittest.TestCase):
         if isinstance(expectedLog, str):
             expectedLog = [expectedLog]
         if not isinstance(expectedLog, list):
-            raise RuntimeError('The expectedLog argument must be either string or a list of '
-                               'strings')
+            raise RuntimeError(
+                'The expectedLog argument must be either string or a list of strings'
+            )
 
         yield self.enrichBuild(build, wantSteps=True, wantProperties=True, wantLogs=True)
         for step in build['steps']:
