@@ -16,7 +16,6 @@
 import abc
 import base64
 import os
-import time
 
 from twisted.internet import defer
 from twisted.internet import reactor
@@ -25,17 +24,15 @@ from twisted.logger import Logger
 from twisted.python.failure import Failure
 
 from buildbot import config
-from buildbot.util import asyncSleep
-from buildbot.util.httpclientservice import HTTPClientService
+from buildbot.util import service
 from buildbot.util.protocol import LineProcessProtocol
-from buildbot.util.service import BuildbotService
 
 log = Logger()
 
 
 # this is a BuildbotService, so that it can be started and destroyed.
 # this is needed to implement kubectl proxy lifecycle
-class KubeConfigLoaderBase(BuildbotService):
+class KubeConfigLoaderBase(service.BuildbotService):
     name = "KubeConfig"
 
     @abc.abstractmethod
@@ -54,6 +51,11 @@ class KubeConfigLoaderBase(BuildbotService):
         }
         """
 
+    def get_master_url(self):
+        # This function may be called before reconfigService() is called.
+        # The function must be overridden in case getConfig() is not fully setup in such situation.
+        return self.getConfig()["master_url"]
+
     def getAuthorization(self):
         return None
 
@@ -64,14 +66,16 @@ class KubeConfigLoaderBase(BuildbotService):
 
 
 class KubeHardcodedConfig(KubeConfigLoaderBase):
-    def reconfigService(self,
-                        master_url=None,
-                        bearerToken=None,
-                        basicAuth=None,
-                        headers=None,
-                        cert=None,
-                        verify=None,
-                        namespace="default"):
+    def reconfigService(
+        self,
+        master_url=None,
+        bearerToken=None,
+        basicAuth=None,
+        headers=None,
+        cert=None,
+        verify=None,
+        namespace="default",
+    ):
         self.config = {'master_url': master_url, 'namespace': namespace, 'headers': {}}
         if headers is not None:
             self.config['headers'] = headers
@@ -90,7 +94,7 @@ class KubeHardcodedConfig(KubeConfigLoaderBase):
     def getAuthorization(self):
         if self.basicAuth is not None:
             basicAuth = yield self.renderSecrets(self.basicAuth)
-            authstring = f"{basicAuth['user']}:{basicAuth['password']}".encode('utf-8')
+            authstring = f"{basicAuth['user']}:{basicAuth['password']}".encode()
             encoded = base64.b64encode(authstring)
             return f"Basic {encoded}"
 
@@ -105,12 +109,13 @@ class KubeHardcodedConfig(KubeConfigLoaderBase):
 
 
 class KubeCtlProxyConfigLoader(KubeConfigLoaderBase):
-    """ We use kubectl proxy to connect to kube master.
+    """We use kubectl proxy to connect to kube master.
     Parsing the config and setting up SSL is complex.
     So for now, we use kubectl proxy to load the config and connect to master.
     This will run the kube proxy as a subprocess, and return configuration with
     http://localhost:PORT
     """
+
     kube_ctl_proxy_cmd = ['kubectl', 'proxy']  # for tests override
 
     class LocalPP(LineProcessProtocol):
@@ -133,11 +138,13 @@ class KubeCtlProxyConfigLoader(KubeConfigLoaderBase):
             self.terminated_deferred.callback(None)
 
     def checkConfig(self, proxy_port=8001, namespace="default"):
+        self.proxy_port = proxy_port
+        self.namespace = namespace
         self.pp = None
         self.process = None
 
     @defer.inlineCallbacks
-    def ensureSubprocessKilled(self):
+    def ensure_subprocess_killed(self):
         if self.pp is not None:
             try:
                 self.process.signalProcess("TERM")
@@ -149,23 +156,38 @@ class KubeCtlProxyConfigLoader(KubeConfigLoaderBase):
     def reconfigService(self, proxy_port=8001, namespace="default"):
         self.proxy_port = proxy_port
         self.namespace = namespace
-        yield self.ensureSubprocessKilled()
+
+        if self.running:
+            yield self.ensure_subprocess_killed()
+            yield self.start_subprocess()
+
+    @defer.inlineCallbacks
+    def start_subprocess(self):
         self.pp = self.LocalPP()
         self.process = reactor.spawnProcess(
             self.pp,
             self.kube_ctl_proxy_cmd[0],
-            self.kube_ctl_proxy_cmd + ["-p", str(self.proxy_port)],
-            env=None)
+            [*self.kube_ctl_proxy_cmd, "-p", str(self.proxy_port)],
+            env=os.environ,
+        )
         self.kube_proxy_output = yield self.pp.got_output_deferred
 
+    @defer.inlineCallbacks
+    def startService(self):
+        try:
+            yield self.start_subprocess()
+        except Exception:
+            yield self.ensure_subprocess_killed()
+            raise
+        yield super().startService()
+
+    @defer.inlineCallbacks
     def stopService(self):
-        return self.ensureSubprocessKilled()
+        yield self.ensure_subprocess_killed()
+        yield super().stopService()
 
     def getConfig(self):
-        return {
-            'master_url': f"http://localhost:{self.proxy_port}",
-            'namespace': self.namespace
-        }
+        return {'master_url': f"http://localhost:{self.proxy_port}", 'namespace': self.namespace}
 
 
 class KubeInClusterConfigLoader(KubeConfigLoaderBase):
@@ -181,93 +203,74 @@ class KubeInClusterConfigLoader(KubeConfigLoaderBase):
 
     def reconfigService(self):
         self.config = {}
-        self.config['master_url'] = os.environ['KUBERNETES_PORT'].replace(
-            'tcp', 'https')
+        self.config['master_url'] = self.get_master_url()
         self.config['verify'] = self.kube_cert_file
         with open(self.kube_token_file, encoding="utf-8") as token_content:
             token = token_content.read().strip()
-            self.config['headers'] = {
-                'Authorization': f'Bearer {token}'.format(token)
-            }
+            self.config['headers'] = {'Authorization': f'Bearer {token}'.format(token)}
         with open(self.kube_namespace_file, encoding="utf-8") as namespace_content:
             self.config['namespace'] = namespace_content.read().strip()
 
     def getConfig(self):
         return self.config
 
-
-class KubeError(RuntimeError):
-    def __init__(self, response_json):
-        super().__init__(response_json['message'])
-        self.json = response_json
-        self.reason = response_json.get('reason')
+    def get_master_url(self):
+        return os.environ["KUBERNETES_PORT"].replace("tcp", "https")
 
 
-class KubeClientService(HTTPClientService):
-    def __init__(self, kube_config=None):
-        self.config = kube_config
-        super().__init__('')
-        self._namespace = None
-        kube_config.setServiceParent(self)
+class KubeClientService(service.SharedService):
+    name = "KubeClientService"
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self._config_id_to_workers = {}
+        self._worker_to_config = {}
+        self._lock = defer.DeferredLock()
 
     @defer.inlineCallbacks
-    def _prepareRequest(self, ep, kwargs):
-        config = self.config.getConfig()
-        self._base_url = config['master_url']
-        url, req_kwargs = super()._prepareRequest(ep, kwargs)
-
-        if 'headers' not in req_kwargs:
-            req_kwargs['headers'] = {}
-        if 'headers' in config:
-            req_kwargs['headers'].update(config['headers'])
-
-        auth = yield self.config.getAuthorization()
-        if auth is not None:
-            req_kwargs['headers']['Authorization'] = auth
-
-        # warning: this only works with txrequests! not treq
-        for arg in ['cert', 'verify']:
-            if arg in config:
-                req_kwargs[arg] = config[arg]
-
-        return (url, req_kwargs)
+    def register(self, worker, config):
+        yield self._lock.acquire()
+        try:
+            if worker.name in self._worker_to_config:
+                raise ValueError(f"Worker {worker.name} registered multiple times")
+            self._worker_to_config[worker.name] = config
+            config_id = id(config)
+            if config_id in self._config_id_to_workers:
+                self._config_id_to_workers[config_id].append(worker.name)
+            else:
+                self._config_id_to_workers[config_id] = [worker.name]
+                yield config.setServiceParent(self)
+        finally:
+            self._lock.release()
 
     @defer.inlineCallbacks
-    def createPod(self, namespace, spec):
-        url = f'/api/v1/namespaces/{namespace}/pods'
-        res = yield self.post(url, json=spec)
-        res_json = yield res.json()
-        if res.code not in (200, 201, 202):
-            raise KubeError(res_json)
-        return res_json
+    def unregister(self, worker):
+        yield self._lock.acquire()
+        try:
+            if worker.name not in self._worker_to_config:
+                raise ValueError(f"Worker {worker.name} was not registered")
+            config = self._worker_to_config.pop(worker.name)
+            config_id = id(config)
+            worker_list = self._config_id_to_workers[config_id]
+            worker_list.remove(worker.name)
+            if not worker_list:
+                del self._config_id_to_workers[config_id]
+                yield config.disownServiceParent()
+        finally:
+            self._lock.release()
 
     @defer.inlineCallbacks
-    def deletePod(self, namespace, name, graceperiod=0):
-        url = f'/api/v1/namespaces/{namespace}/pods/{name}'
-        res = yield self.delete(url, params={'graceperiod': graceperiod})
-        res_json = yield res.json()
-        if res.code != 200:
-            raise KubeError(res_json)
-        return res_json
+    def startService(self):
+        yield self._lock.acquire()
+        try:
+            yield super().startService()
+        finally:
+            self._lock.release()
 
     @defer.inlineCallbacks
-    def waitForPodDeletion(self, namespace, name, timeout):
-        t1 = time.time()
-        url = f'/api/v1/namespaces/{namespace}/pods/{name}/status'
-        while True:
-            if time.time() - t1 > timeout:
-                raise TimeoutError(f"Did not see pod {name} terminate after {timeout}s")
-            res = yield self.get(url)
-            res_json = yield res.json()
-            if res.code == 404:
-                break  # 404 means the pod has terminated
-            if res.code != 200:
-                raise KubeError(res_json)
-            yield asyncSleep(1)
-        return res_json
-
-    @property
-    def namespace(self):
-        if self._namespace is None:
-            self._namespace = self.config.getConfig()['namespace']
-        return self._namespace
+    def stopService(self):
+        yield self._lock.acquire()
+        try:
+            yield super().stopService()
+        finally:
+            self._lock.release()
