@@ -12,25 +12,30 @@
 # Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 # Copyright Buildbot Team Members
-
-
-# This is a class which watches a maildir for new messages. It uses the
-# linux dirwatcher API (if available) to look for new files. The
-# .messageReceived method is invoked with the filename of the new message,
-# relative to the top of the maildir (so it will look like "new/blahblah").
+"""
+This is a class which watches a maildir for new messages. It uses the
+linux dirwatcher API (if available) to look for new files. The
+.messageReceived method is invoked with the filename of the new message,
+relative to the top of the maildir (so it will look like "new/blahblah").
+"""
 
 import os
+from typing import Optional
 
 from twisted.application import internet
-from twisted.application import service
 from twisted.internet import defer
 from twisted.internet import reactor
+
+# We have to put it here, since we use it to provide feedback
 from twisted.python import log
 from twisted.python import runtime
+
+from buildbot.util import service
+
 dnotify = None
 try:
     import dnotify
-except:
+except ImportError:
     log.msg("unable to import dnotify, so Maildir will use polling instead")
 
 
@@ -38,11 +43,12 @@ class NoSuchMaildir(Exception):
     pass
 
 
-class MaildirService(service.MultiService):
-    pollinterval = 10  # only used if we don't have DNotify
+class MaildirService(service.BuildbotService):
+    pollInterval = 10  # only used if we don't have DNotify
+    name: Optional[str] = 'MaildirService'  # type: ignore
 
     def __init__(self, basedir=None):
-        service.MultiService.__init__(self)
+        super().__init__()
         if basedir:
             self.setBasedir(basedir)
         self.files = []
@@ -58,26 +64,27 @@ class MaildirService(service.MultiService):
         self.newdir = os.path.join(self.basedir, "new")
         self.curdir = os.path.join(self.basedir, "cur")
 
+    @defer.inlineCallbacks
     def startService(self):
-        service.MultiService.startService(self)
         if not os.path.isdir(self.newdir) or not os.path.isdir(self.curdir):
-            raise NoSuchMaildir("invalid maildir '%s'" % self.basedir)
+            raise NoSuchMaildir(f"invalid maildir '{self.basedir}'")
         try:
             if dnotify:
                 # we must hold an fd open on the directory, so we can get
                 # notified when it changes.
-                self.dnotify = dnotify.DNotify(self.newdir,
-                                               self.dnotify_callback,
-                                               [dnotify.DNotify.DN_CREATE])
-        except (IOError, OverflowError):
+                self.dnotify = dnotify.DNotify(
+                    self.newdir, self.dnotify_callback, [dnotify.DNotify.DN_CREATE]
+                )
+        except (OSError, OverflowError):
             # IOError is probably linux<2.4.19, which doesn't support
             # dnotify. OverflowError will occur on some 64-bit machines
             # because of a python bug
             log.msg("DNotify failed, falling back to polling")
         if not self.dnotify:
-            self.timerService = internet.TimerService(self.pollinterval, self.poll)
-            self.timerService.setServiceParent(self)
+            self.timerService = internet.TimerService(self.pollInterval, self.poll)
+            yield self.timerService.setServiceParent(self)
         self.poll()
+        yield super().startService()
 
     def dnotify_callback(self):
         log.msg("dnotify noticed something, now polling")
@@ -100,7 +107,7 @@ class MaildirService(service.MultiService):
         if self.timerService is not None:
             self.timerService.disownServiceParent()
             self.timerService = None
-        return service.MultiService.stopService(self)
+        return super().stopService()
 
     @defer.inlineCallbacks
     def poll(self):
@@ -112,33 +119,32 @@ class MaildirService(service.MultiService):
                     self.files.remove(f)
             newfiles = []
             for f in os.listdir(self.newdir):
-                if not f in self.files:
+                if f not in self.files:
                     newfiles.append(f)
             self.files.extend(newfiles)
             for n in newfiles:
                 try:
                     yield self.messageReceived(n)
-                except:
-                    log.err(None, "while reading '%s' from maildir '%s':" % (n, self.basedir))
+                except Exception:
+                    log.err(None, f"while reading '{n}' from maildir '{self.basedir}':")
         except Exception:
-            log.err(None, "while polling maildir '%s':" % (self.basedir,))
+            log.err(None, f"while polling maildir '{self.basedir}':")
 
     def moveToCurDir(self, filename):
+        f = None
         if runtime.platformType == "posix":
             # open the file before moving it, because I'm afraid that once
             # it's in cur/, someone might delete it at any moment
             path = os.path.join(self.newdir, filename)
-            f = open(path, "r")
-            os.rename(os.path.join(self.newdir, filename),
-                      os.path.join(self.curdir, filename))
+            f = open(path, encoding='utf-8')
+            os.rename(os.path.join(self.newdir, filename), os.path.join(self.curdir, filename))
         elif runtime.platformType == "win32":
             # do this backwards under windows, because you can't move a file
             # that somebody is holding open. This was causing a Permission
-            # Denied error on bear's win32-twisted1.3 buildslave.
-            os.rename(os.path.join(self.newdir, filename),
-                      os.path.join(self.curdir, filename))
+            # Denied error on bear's win32-twisted1.3 worker.
+            os.rename(os.path.join(self.newdir, filename), os.path.join(self.curdir, filename))
             path = os.path.join(self.curdir, filename)
-            f = open(path, "r")
+            f = open(path, encoding='utf-8')
 
         return f
 
