@@ -13,14 +13,28 @@
 #
 # Copyright Buildbot Team Members
 
+from __future__ import annotations
+
 from functools import wraps
+from typing import TYPE_CHECKING
 
 from twisted.internet import defer
 
+if TYPE_CHECKING:
+    from typing import Any
+    from typing import Callable
+    from typing import Coroutine
+    from typing import TypeVar
 
-def async_to_deferred(fn):
+    from typing_extensions import ParamSpec
+
+    _T = TypeVar('_T')
+    _P = ParamSpec('_P')
+
+
+def async_to_deferred(fn: Callable[_P, Coroutine[Any, Any, _T]]):
     @wraps(fn)
-    def wrapper(*args, **kwargs):
+    def wrapper(*args: _P.args, **kwargs: _P.kwargs) -> defer.Deferred[_T]:
         try:
             return defer.ensureDeferred(fn(*args, **kwargs))
         except Exception as e:
