@@ -27,7 +27,6 @@ from buildbot.util import service
 
 
 class MasterService(ApplicationSession, service.AsyncMultiService):
-
     """
     concatenation of all the wamp services of buildbot
     """
@@ -43,7 +42,7 @@ class MasterService(ApplicationSession, service.AsyncMultiService):
     @defer.inlineCallbacks
     def onJoin(self, details):
         log.msg("Wamp connection succeed!")
-        for handler in [self] + self.services:
+        for handler in [self, *self.services]:
             yield self.register(handler)
             yield self.subscribe(handler)
         yield self.publish(f"org.buildbot.{self.master.masterid}.connected")
@@ -62,8 +61,7 @@ class MasterService(ApplicationSession, service.AsyncMultiService):
         # It is possible that such failure is practically non-existent
         # so for now, we just crash the master
         log.msg("Guru meditation! We have been disconnected from wamp server")
-        log.msg(
-            "We don't know how to recover this without restarting the whole system")
+        log.msg("We don't know how to recover this without restarting the whole system")
         log.msg(str(details))
         yield self.master.stopService()
 
@@ -75,8 +73,10 @@ def make(config):
     if config:
         return MasterService(config)
     # if no config given, return a description of this WAMPlet ..
-    return {'label': 'Buildbot master wamplet',
-            'description': 'This contains all the wamp methods provided by a buildbot master'}
+    return {
+        'label': 'Buildbot master wamplet',
+        'description': 'This contains all the wamp methods provided by a buildbot master',
+    }
 
 
 class WampConnector(service.ReconfigurableServiceMixin, service.AsyncMultiService):
@@ -101,6 +101,7 @@ class WampConnector(service.ReconfigurableServiceMixin, service.AsyncMultiServic
         def gotService(service):
             d.callback(service)
             return service
+
         return d
 
     def stopService(self):
@@ -143,8 +144,11 @@ class WampConnector(service.ReconfigurableServiceMixin, service.AsyncMultiServic
         # Implementing reconfiguration just for wamp_debug_level does not seem like a good
         # investment.
         if self.app is not None:
-            if self.router_url != router_url or self.realm != realm or \
-                    self.wamp_debug_level != wamp_debug_level:
+            if (
+                self.router_url != router_url
+                or self.realm != realm
+                or self.wamp_debug_level != wamp_debug_level
+            ):
                 raise ValueError("Cannot use different wamp settings when reconfiguring")
             return
 
@@ -157,9 +161,9 @@ class WampConnector(service.ReconfigurableServiceMixin, service.AsyncMultiServic
 
         self.app = self.serviceClass(
             url=self.router_url,
-            extra=dict(master=self.master, parent=self),
+            extra={"master": self.master, "parent": self},
             realm=realm,
-            make=make
+            make=make,
         )
         txaio.set_global_log_level(wamp_debug_level)
         yield self.app.setServiceParent(self)
