@@ -61,10 +61,13 @@ class States(enum.Enum):
     # When in this state self.substantiation_build is not None.
     INSUBSTANTIATING_SUBSTANTIATING = 5
 
+    # This state represents a worker that is shut down. Effectively, it's NOT_SUBSTANTIATED
+    # plus that we will abort if anyone tries to substantiate it.
+    SHUT_DOWN = 6
+
 
 @implementer(ILatentWorker)
 class AbstractLatentWorker(AbstractWorker):
-
     """A worker that will start up a worker instance when needed.
 
     To use, subclass and implement start_instance and stop_instance.
@@ -109,7 +112,7 @@ class AbstractLatentWorker(AbstractWorker):
 
     state = States.NOT_SUBSTANTIATED
 
-    '''
+    """
     state transitions:
 
     substantiate(): either of
@@ -148,48 +151,73 @@ class AbstractLatentWorker(AbstractWorker):
         then either of:
             INSUBSTANTIATING_SUBSTANTIATING -> SUBSTANTIATING
             INSUBSTANTIATING -> NOT_SUBSTANTIATED
-        """
-    '''
 
-    def checkConfig(self, name, password,
-                    build_wait_timeout=60 * 10,
-                    **kwargs):
-        super().checkConfig(name, password, **kwargs)
+    stopService():
+        NOT_SUBSTANTIATED -> SHUT_DOWN
+    """
 
-    def reconfigService(self, name, password,
-                        build_wait_timeout=60 * 10,
-                        **kwargs):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
         self._substantiation_notifier = Notifier()
         self._start_stop_lock = defer.DeferredLock()
+        self._check_instance_timer = None
+
+    def checkConfig(
+        self, name, password, build_wait_timeout=60 * 10, check_instance_interval=10, **kwargs
+    ):
+        super().checkConfig(name, password, **kwargs)
+
+    def reconfigService(
+        self, name, password, build_wait_timeout=60 * 10, check_instance_interval=10, **kwargs
+    ):
         self.build_wait_timeout = build_wait_timeout
+        self.check_instance_interval = check_instance_interval
         return super().reconfigService(name, password, **kwargs)
 
+    def _generate_random_password(self):
+        return ''.join(random.choice(string.ascii_letters + string.digits) for _ in range(20))
+
     def getRandomPass(self):
         """
-        compute a random password
-        There is no point to configure a password for a LatentWorker, as it is created by the master.
-        For supporting backend, a password can be generated by this API
+        Compute a random password. Latent workers are started by the master, so master can setup
+        the password too. Backends should prefer to use this API as it handles edge cases.
         """
-        return ''.join(
-            random.choice(string.ascii_letters + string.digits)
-            for _ in range(20))
+
+        # We should return an existing password if we're reconfiguring a substantiated worker.
+        # Otherwise the worker may be rejected if its password was changed during substantiation.
+        # To simplify, we only allow changing passwords for workers that aren't substantiated.
+        if self.state not in [States.NOT_SUBSTANTIATED, States.SHUT_DOWN]:
+            if self.password is not None:
+                return self.password
+
+            # pragma: no cover
+            log.err(
+                '{}: could not reuse password of substantiated worker (password == None)',
+                repr(self),
+            )
+
+        return self._generate_random_password()
 
     @property
     def building(self):
         # A LatentWorkerForBuilder will only be busy if it is building.
-        return {wfb for wfb in self.workerforbuilders.values()
-                if wfb.isBusy()}
+        return {wfb for wfb in self.workerforbuilders.values() if wfb.isBusy()}
 
     def failed_to_start(self, instance_id, instance_state):
-        log.msg('%s %s failed to start instance %s (%s)' %
-                (self.__class__.__name__, self.workername,
-                    instance_id, instance_state))
+        log.msg(
+            f'{self.__class__.__name__} {self.workername} failed to start instance '
+            f'{instance_id} ({instance_state})'
+        )
         raise LatentWorkerFailedToSubstantiate(instance_id, instance_state)
 
     def _log_start_stop_locked(self, action_str):
         if self._start_stop_lock.locked:
-            log.msg(('while {} worker {}: waiting until previous ' +
-                     'start_instance/stop_instance finishes').format(action_str, self))
+            log.msg(
+                (
+                    'while {} worker {}: waiting until previous '
+                    + 'start_instance/stop_instance finishes'
+                ).format(action_str, self)
+            )
 
     def start_instance(self, build):
         # responsible for starting instance that will try to connect with this
@@ -202,20 +230,27 @@ class AbstractLatentWorker(AbstractWorker):
         # responsible for shutting down instance.
         raise NotImplementedError
 
+    def check_instance(self):
+        return (True, "")
+
     @property
     def substantiated(self):
         return self.state == States.SUBSTANTIATED and self.conn is not None
 
     def substantiate(self, wfb, build):
-        log.msg("substantiating worker %s" % (wfb,))
+        log.msg(f"substantiating worker {wfb}")
+
+        if self.state == States.SHUT_DOWN:
+            return defer.succeed(False)
 
         if self.state == States.SUBSTANTIATED and self.conn is not None:
-            self._setBuildWaitTimer()
             return defer.succeed(True)
 
-        if self.state in [States.SUBSTANTIATING,
-                          States.SUBSTANTIATING_STARTING,
-                          States.INSUBSTANTIATING_SUBSTANTIATING]:
+        if self.state in [
+            States.SUBSTANTIATING,
+            States.SUBSTANTIATING_STARTING,
+            States.INSUBSTANTIATING_SUBSTANTIATING,
+        ]:
             return self._substantiation_notifier.wait()
 
         self.startMissingTimer()
@@ -231,8 +266,7 @@ class AbstractLatentWorker(AbstractWorker):
             d_ins.addErrback(log.err, 'while insubstantiating')
             return d
 
-        assert self.state in [States.NOT_SUBSTANTIATED,
-                              States.INSUBSTANTIATING]
+        assert self.state in [States.NOT_SUBSTANTIATED, States.INSUBSTANTIATING]
 
         if self.state == States.NOT_SUBSTANTIATED:
             self.state = States.SUBSTANTIATING
@@ -249,8 +283,7 @@ class AbstractLatentWorker(AbstractWorker):
             # if build_wait_timeout is negative we don't ever disconnect the
             # worker ourselves, so we don't need to wait for it to attach
             # to declare it as substantiated.
-            dont_wait_to_attach = \
-                self.build_wait_timeout < 0 and self.conn is not None
+            dont_wait_to_attach = self.build_wait_timeout < 0 and self.conn is not None
 
             start_success = True
             if ILatentMachine.providedBy(self.machine):
@@ -272,13 +305,16 @@ class AbstractLatentWorker(AbstractWorker):
                 msg = "Worker does not want to substantiate at this time"
                 raise LatentWorkerFailedToSubstantiate(self.name, msg)
 
-            if dont_wait_to_attach and \
-                    self.state == States.SUBSTANTIATING_STARTING and \
-                    self.conn is not None:
-                log.msg(r"Worker %s substantiated (already attached)" %
-                    (self.name,))
+            if (
+                dont_wait_to_attach
+                and self.state == States.SUBSTANTIATING_STARTING
+                and self.conn is not None
+            ):
+                log.msg(f"Worker {self.name} substantiated (already attached)")
                 self.state = States.SUBSTANTIATED
                 self._fireSubstantiationNotifier(True)
+            else:
+                self._start_check_instance_timer()
 
         except Exception as e:
             self.stopMissingTimer()
@@ -287,31 +323,33 @@ class AbstractLatentWorker(AbstractWorker):
 
     def _fireSubstantiationNotifier(self, result):
         if not self._substantiation_notifier:
-            log.msg("No substantiation deferred for %s" % (self.name,))
+            log.msg(f"No substantiation deferred for {self.name}")
             return
 
         result_msg = 'success' if result is True else 'failure'
-        log.msg("Firing {} substantiation deferred with {}".format(
-            self.name, result_msg))
+        log.msg(f"Firing {self.name} substantiation deferred with {result_msg}")
 
         self._substantiation_notifier.notify(result)
 
     @defer.inlineCallbacks
-    def attached(self, bot):
-        if self.state != States.SUBSTANTIATING_STARTING and \
-                self.build_wait_timeout >= 0:
-            msg = 'Worker %s received connection while not trying to ' \
-                'substantiate.  Disconnecting.' % (self.name,)
+    def attached(self, conn):
+        self._stop_check_instance_timer()
+
+        if self.state != States.SUBSTANTIATING_STARTING and self.build_wait_timeout >= 0:
+            msg = (
+                f'Worker {self.name} received connection while not trying to substantiate.'
+                'Disconnecting.'
+            )
             log.msg(msg)
-            self._disconnect(bot)
+            self._deferwaiter.add(self._disconnect(conn))
             raise RuntimeError(msg)
 
         try:
-            yield super().attached(bot)
+            yield super().attached(conn)
         except Exception:
             self._substantiation_failed(failure.Failure())
             return
-        log.msg(r"Worker %s substantiated \o/" % (self.name,))
+        log.msg(f"Worker {self.name} substantiated \\o/")
 
         # only change state when we are actually substantiating. We could
         # end up at this point in different state than SUBSTANTIATING_STARTING
@@ -320,8 +358,7 @@ class AbstractLatentWorker(AbstractWorker):
         # without master seeing this condition.
         #
         # When build_wait_timeout is not negative, we throw an error (see above)
-        if self.state in [States.SUBSTANTIATING,
-                          States.SUBSTANTIATING_STARTING]:
+        if self.state in [States.SUBSTANTIATING, States.SUBSTANTIATING_STARTING]:
             self.state = States.SUBSTANTIATED
         self._fireSubstantiationNotifier(True)
 
@@ -334,20 +371,22 @@ class AbstractLatentWorker(AbstractWorker):
         return self._substantiation_failed(defer.TimeoutError())
 
     def _substantiation_failed(self, failure):
-        if self.state in [States.SUBSTANTIATING,
-                          States.SUBSTANTIATING_STARTING]:
+        if self.state in [States.SUBSTANTIATING, States.SUBSTANTIATING_STARTING]:
             self._fireSubstantiationNotifier(failure)
+
         d = self.insubstantiate()
         d.addErrback(log.err, 'while insubstantiating')
+        self._deferwaiter.add(d)
+
         # notify people, but only if we're still in the config
         if not self.parent or not self.notify_on_missing:
-            return
+            return None
 
         return self.master.data.updates.workerMissing(
             workerid=self.workerid,
             masterid=self.master.masterid,
             last_connection="Latent worker never connected",
-            notify=self.notify_on_missing
+            notify=self.notify_on_missing,
         )
 
     def canStartBuild(self):
@@ -393,7 +432,58 @@ class AbstractLatentWorker(AbstractWorker):
         if self.build_wait_timeout <= 0:
             return
         self.build_wait_timer = self.master.reactor.callLater(
-            self.build_wait_timeout, self._soft_disconnect)
+            self.build_wait_timeout, self._soft_disconnect
+        )
+
+    def _stop_check_instance_timer(self):
+        if self._check_instance_timer is not None:
+            if self._check_instance_timer.active():
+                self._check_instance_timer.cancel()
+            self._check_instance_timer = None
+
+    def _start_check_instance_timer(self):
+        self._stop_check_instance_timer()
+        self._check_instance_timer = self.master.reactor.callLater(
+            self.check_instance_interval, self._check_instance_timer_fired
+        )
+
+    def _check_instance_timer_fired(self):
+        self._deferwaiter.add(self._check_instance_timer_fired_impl())
+
+    @defer.inlineCallbacks
+    def _check_instance_timer_fired_impl(self):
+        self._check_instance_timer = None
+        if self.state != States.SUBSTANTIATING_STARTING:
+            # The only case when we want to recheck whether the instance has not failed is
+            # between call to start_instance() and successful attachment of the worker.
+            return
+
+        if self._start_stop_lock.locked:  # pragma: no cover
+            # This can't actually happen, because we start the timer for instance checking after
+            # start_instance() completed and in insubstantiation the state is changed from
+            # SUBSTANTIATING_STARTING as soon as the lock is acquired.
+            return
+
+        try:
+            yield self._start_stop_lock.acquire()
+            message = "latent worker crashed before connecting"
+            try:
+                is_good, message_append = yield self.check_instance()
+                message += ": " + message_append
+            except Exception as e:
+                message += ": " + str(e)
+                is_good = False
+
+            if not is_good:
+                yield self._substantiation_failed(
+                    LatentWorkerFailedToSubstantiate(self.name, message)
+                )
+                return
+        finally:
+            self._start_stop_lock.release()
+
+        # if check passes, schedule another one until worker connects
+        self._start_check_instance_timer()
 
     @defer.inlineCallbacks
     def insubstantiate(self, fast=False, force_substantiation_build=None):
@@ -401,22 +491,27 @@ class AbstractLatentWorker(AbstractWorker):
         # after insubstantiation concludes. This parameter allows to go directly to the
         # SUBSTANTIATING state without going through NOT_SUBSTANTIATED state.
 
-        log.msg("insubstantiating worker {}".format(self))
+        log.msg(f"insubstantiating worker {self}")
 
         if self.state == States.INSUBSTANTIATING_SUBSTANTIATING:
+            # there's another insubstantiation ongoing. We'll wait for it to finish by waiting
+            # on self._start_stop_lock
             self.state = States.INSUBSTANTIATING
             self.substantiation_build = None
             self._fireSubstantiationNotifier(
-                failure.Failure(LatentWorkerSubstantiatiationCancelled()))
+                failure.Failure(LatentWorkerSubstantiatiationCancelled())
+            )
 
         try:
             self._log_start_stop_locked('insubstantiating')
             yield self._start_stop_lock.acquire()
 
-            assert self.state not in [States.INSUBSTANTIATING,
-                                      States.INSUBSTANTIATING_SUBSTANTIATING]
+            assert self.state not in [
+                States.INSUBSTANTIATING,
+                States.INSUBSTANTIATING_SUBSTANTIATING,
+            ]
 
-            if self.state == States.NOT_SUBSTANTIATED:
+            if self.state in [States.NOT_SUBSTANTIATED, States.SHUT_DOWN]:
                 return
 
             prev_state = self.state
@@ -429,9 +524,11 @@ class AbstractLatentWorker(AbstractWorker):
 
             if prev_state in [States.SUBSTANTIATING, States.SUBSTANTIATING_STARTING]:
                 self._fireSubstantiationNotifier(
-                    failure.Failure(LatentWorkerSubstantiatiationCancelled()))
+                    failure.Failure(LatentWorkerSubstantiatiationCancelled())
+                )
 
             self._clearBuildWaitTimer()
+            self._stop_check_instance_timer()
 
             if prev_state in [States.SUBSTANTIATING_STARTING, States.SUBSTANTIATED]:
                 try:
@@ -443,11 +540,11 @@ class AbstractLatentWorker(AbstractWorker):
                     # reliability to the backend driver
                     log.err(e, "while insubstantiating")
 
-            assert self.state in [States.INSUBSTANTIATING,
-                                  States.INSUBSTANTIATING_SUBSTANTIATING]
+            assert self.state in [States.INSUBSTANTIATING, States.INSUBSTANTIATING_SUBSTANTIATING]
 
             if self.state == States.INSUBSTANTIATING_SUBSTANTIATING:
-                build, self.substantiation_build = self.substantiation_build, None
+                build = self.substantiation_build
+                self.substantiation_build = None
                 self.state = States.SUBSTANTIATING
                 self._substantiate(build)
             else:  # self.state == States.INSUBSTANTIATING:
@@ -460,13 +557,6 @@ class AbstractLatentWorker(AbstractWorker):
 
     @defer.inlineCallbacks
     def _soft_disconnect(self, fast=False, stopping_service=False):
-        if self.building:
-            # If there are builds running or about to start on this worker, don't disconnect.
-            # soft_disconnect happens during master reconfiguration or shutdown. It's not a good
-            # reason to kill these builds. We effectively slow down reconfig until all workers
-            # that have been unconfigured finish their builds.
-            return
-
         # a negative build_wait_timeout means the worker should never be shut
         # down, so just disconnect.
         if not stopping_service and self.build_wait_timeout < 0:
@@ -475,29 +565,53 @@ class AbstractLatentWorker(AbstractWorker):
 
         self.stopMissingTimer()
 
-        yield defer.DeferredList([
-            super().disconnect(),
-            self.insubstantiate(fast)
-        ], consumeErrors=True, fireOnOneErrback=True)
+        # we add the Deferreds to DeferWaiter because we don't wait for a Deferred if
+        # the other Deferred errbacks
+        yield defer.DeferredList(
+            [
+                self._deferwaiter.add(super().disconnect()),
+                self._deferwaiter.add(self.insubstantiate(fast)),
+            ],
+            consumeErrors=True,
+            fireOnOneErrback=True,
+        )
 
     def disconnect(self):
-        # This returns a Deferred but we don't use it
-        self._soft_disconnect()
+        self._deferwaiter.add(self._soft_disconnect())
         # this removes the worker from all builders.  It won't come back
         # without a restart (or maybe a sighup)
         self.botmaster.workerLost(self)
 
     @defer.inlineCallbacks
     def stopService(self):
-        # the worker might be insubstantiating from buildWaitTimeout
-        if self.state in [States.INSUBSTANTIATING,
-                          States.INSUBSTANTIATING_SUBSTANTIATING]:
-            yield self._insubstantiation_notifier.wait()
+        # stops the service. Waits for any pending substantiations, insubstantiations or builds
+        # that are running or about to start to complete.
+        while self.state not in [States.NOT_SUBSTANTIATED, States.SHUT_DOWN]:
+            if self.state in [
+                States.INSUBSTANTIATING,
+                States.INSUBSTANTIATING_SUBSTANTIATING,
+                States.SUBSTANTIATING,
+                States.SUBSTANTIATING_STARTING,
+            ]:
+                self._log_start_stop_locked('stopService')
+                yield self._start_stop_lock.acquire()
+                self._start_stop_lock.release()
+
+            if self.conn is not None or self.state in [
+                States.SUBSTANTIATED,
+                States.SUBSTANTIATING_STARTING,
+            ]:
+                yield self._soft_disconnect(stopping_service=True)
+
+            yield self._deferwaiter.wait()
+
+        # prevent any race conditions with any future builds that are in the process of
+        # being started.
+        if self.state == States.NOT_SUBSTANTIATED:
+            self.state = States.SHUT_DOWN
 
-        if self.conn is not None or self.state in [States.SUBSTANTIATING,
-                                                   States.SUBSTANTIATED]:
-            yield self._soft_disconnect(stopping_service=True)
         self._clearBuildWaitTimer()
+        self._stop_check_instance_timer()
         res = yield super().stopService()
         return res
 
@@ -519,12 +633,11 @@ class LocalLatentWorker(AbstractLatentWorker):
     A worker that can be suspended by shutting down or suspending the hardware
     it runs on. It is intended to be used with LatentMachines.
     """
+
     starts_without_substantiate = True
 
     def checkConfig(self, name, password, **kwargs):
-        super.checkConfig(self, name, password, build_wait_timeout=-1,
-                          **kwargs)
+        super().checkConfig(self, name, password, build_wait_timeout=-1, **kwargs)
 
     def reconfigService(self, name, password, **kwargs):
-        return super().reconfigService(name, password, build_wait_timeout=-1,
-                                       **kwargs)
+        return super().reconfigService(name, password, build_wait_timeout=-1, **kwargs)
