@@ -1,4 +1,3 @@
-# coding: utf-8
 # This file is part of Buildbot.  Buildbot is free software: you can
 # redistribute it and/or modify it under the terms of the GNU General Public
 # License as published by the Free Software Foundation, version 2.
@@ -59,7 +58,7 @@ prefix_output_2 = b"""\
 """
 
 # this is the svn info output for a local repository, svn info --xml
-# file:///home/warner/stuff/Projects/Buildbot/trees/svnpoller/_trial_temp/test_vc/repositories/SVN-Repository  # noqa pylint: disable=line-too-long
+# file:///home/warner/stuff/Projects/Buildbot/trees/svnpoller/_trial_temp/test_vc/repositories/SVN-Repository
 prefix_output_3 = b"""\
 <?xml version="1.0"?>
 <info>
@@ -81,7 +80,7 @@ prefix_output_3 = b"""\
 </info>
 """
 
-# % svn info --xml file:///home/warner/stuff/Projects/Buildbot/trees/svnpoller/_trial_temp/test_vc/repositories/SVN-Repository/sample/trunk  # noqa pylint: disable=line-too-long
+# % svn info --xml file:///home/warner/stuff/Projects/Buildbot/trees/svnpoller/_trial_temp/test_vc/repositories/SVN-Repository/sample/trunk
 
 prefix_output_4 = b"""\
 <?xml version="1.0"?>
@@ -102,7 +101,7 @@ prefix_output_4 = b"""\
 </commit>
 </entry>
 </info>
-"""  # noqa pylint: disable=line-too-long
+"""
 
 
 # output from svn log on .../SVN-Repository/sample
@@ -252,7 +251,7 @@ def split_file(path):
         return {"branch": 'branch', "path": '/'.join(pieces[1:])}
     if pieces[0] == "trunk":
         return {"path": '/'.join(pieces[1:])}
-    raise RuntimeError(f"there shouldn't be any files like {repr(path)}")
+    raise RuntimeError(f"there shouldn't be any files like {path!r}")
 
 
 class TestSVNPoller(
@@ -505,7 +504,7 @@ class TestSVNPoller(
                     'files': [''],
                     'project': '',
                     'properties': {},
-                    'repository': 'file:///usr/home/warner/stuff/Projects/Buildbot/trees/misc/_trial_temp/test_vc/repositories/SVN-Repository/sample',  # noqa pylint: disable=line-too-long
+                    'repository': 'file:///usr/home/warner/stuff/Projects/Buildbot/trees/misc/_trial_temp/test_vc/repositories/SVN-Repository/sample',
                     'revision': '2',
                     'revlink': '',
                     'src': 'svn',
@@ -532,7 +531,7 @@ class TestSVNPoller(
                     'files': ['çmain.c'],
                     'project': '',
                     'properties': {},
-                    'repository': 'file:///usr/home/warner/stuff/Projects/Buildbot/trees/misc/_trial_temp/test_vc/repositories/SVN-Repository/sample',  # noqa pylint: disable=line-too-long
+                    'repository': 'file:///usr/home/warner/stuff/Projects/Buildbot/trees/misc/_trial_temp/test_vc/repositories/SVN-Repository/sample',
                     'revision': '3',
                     'revlink': '',
                     'src': 'svn',
@@ -548,7 +547,7 @@ class TestSVNPoller(
                     'files': ['version.c'],
                     'project': '',
                     'properties': {},
-                    'repository': 'file:///usr/home/warner/stuff/Projects/Buildbot/trees/misc/_trial_temp/test_vc/repositories/SVN-Repository/sample',  # noqa pylint: disable=line-too-long
+                    'repository': 'file:///usr/home/warner/stuff/Projects/Buildbot/trees/misc/_trial_temp/test_vc/repositories/SVN-Repository/sample',
                     'revision': '4',
                     'revlink': '',
                     'src': 'svn',
