@@ -20,11 +20,13 @@ from twisted.trial import unittest
 
 from buildbot.data import builders
 from buildbot.data import resultspec
+from buildbot.db.builders import BuilderModel
 from buildbot.test import fakedb
 from buildbot.test.fake import fakemaster
 from buildbot.test.reactor import TestReactorMixin
 from buildbot.test.util import endpoint
 from buildbot.test.util import interfaces
+from buildbot.util.twisted import async_to_deferred
 
 
 class BuilderEndpoint(endpoint.EndpointMixin, unittest.TestCase):
@@ -36,6 +38,7 @@ class BuilderEndpoint(endpoint.EndpointMixin, unittest.TestCase):
         return self.db.insert_test_data([
             fakedb.Builder(id=1, name='buildera'),
             fakedb.Builder(id=2, name='builderb'),
+            fakedb.Builder(id=3, name='builder unicode \N{SNOWMAN}'),
             fakedb.Master(id=13),
             fakedb.BuilderMaster(id=1, builderid=2, masterid=13),
         ])
@@ -56,6 +59,22 @@ class BuilderEndpoint(endpoint.EndpointMixin, unittest.TestCase):
 
         self.assertEqual(builder, None)
 
+    @async_to_deferred
+    async def test_get_by_name(self):
+        builder = await self.callGet(('builders', 'builderb'))
+
+        self.validateData(builder)
+        self.assertEqual(builder['builderid'], 2)
+        self.assertEqual(builder['name'], 'builderb')
+
+    @async_to_deferred
+    async def test_get_unicode_by_name(self):
+        builder = await self.callGet(('builders', 'builder unicode \N{SNOWMAN}'))
+
+        self.validateData(builder)
+        self.assertEqual(builder['builderid'], 3)
+        self.assertEqual(builder['name'], 'builder unicode \N{SNOWMAN}')
+
     @defer.inlineCallbacks
     def test_get_missing_with_name(self):
         builder = yield self.callGet(('builders', 'builderc'))
@@ -104,6 +123,9 @@ class BuildersEndpoint(endpoint.EndpointMixin, unittest.TestCase):
             fakedb.BuildersTags(builderid=5, tagid=4),
             fakedb.Master(id=13),
             fakedb.BuilderMaster(id=1, builderid=2, masterid=13),
+            fakedb.Worker(id=1, name='zero'),
+            fakedb.ConnectedWorker(id=1, workerid=1, masterid=13),
+            fakedb.ConfiguredWorker(id=1, workerid=1, buildermasterid=1),
         ])
 
     def tearDown(self):
@@ -136,6 +158,15 @@ class BuildersEndpoint(endpoint.EndpointMixin, unittest.TestCase):
 
         self.assertEqual(sorted([b['builderid'] for b in builders]), [3, 4])
 
+    @async_to_deferred
+    async def test_get_workerid(self):
+        builders = await self.callGet(('workers', 1, 'builders'))
+
+        for b in builders:
+            self.validateData(b)
+
+        self.assertEqual(sorted([b['builderid'] for b in builders]), [2])
+
     @defer.inlineCallbacks
     def test_get_masterid_missing(self):
         builders = yield self.callGet(('masters', 14, 'builders'))
@@ -231,16 +262,11 @@ class Builder(interfaces.InterfaceTests, TestReactorMixin, unittest.TestCase):
         self.assertEqual(
             sorted((yield self.master.db.builders.getBuilders())),
             sorted([
-                {
-                    "id": 1,
-                    "masterids": [13],
-                    "name": "somebuilder",
-                    "description": None,
-                    "description_html": None,
-                    "description_format": None,
-                    "projectid": None,
-                    "tags": [],
-                },
+                BuilderModel(
+                    id=1,
+                    masterids=[13],
+                    name="somebuilder",
+                ),
             ]),
         )
         self.master.mq.assertProductions([
@@ -250,33 +276,23 @@ class Builder(interfaces.InterfaceTests, TestReactorMixin, unittest.TestCase):
         # add another
         yield self.rtype.updateBuilderList(13, ['somebuilder', 'another'])
 
-        def builderKey(builder):
-            return builder['id']
+        def builderKey(builder: BuilderModel):
+            return builder.id
 
         self.assertEqual(
             sorted((yield self.master.db.builders.getBuilders()), key=builderKey),
             sorted(
                 [
-                    {
-                        "id": 1,
-                        "masterids": [13],
-                        "name": "somebuilder",
-                        "description": None,
-                        "description_html": None,
-                        "description_format": None,
-                        "projectid": None,
-                        "tags": [],
-                    },
-                    {
-                        "id": 2,
-                        "masterids": [13],
-                        "name": "another",
-                        "description": None,
-                        "description_html": None,
-                        "description_format": None,
-                        "projectid": None,
-                        "tags": [],
-                    },
+                    BuilderModel(
+                        id=1,
+                        masterids=[13],
+                        name="somebuilder",
+                    ),
+                    BuilderModel(
+                        id=2,
+                        masterids=[13],
+                        name="another",
+                    ),
                 ],
                 key=builderKey,
             ),
@@ -291,26 +307,16 @@ class Builder(interfaces.InterfaceTests, TestReactorMixin, unittest.TestCase):
             sorted((yield self.master.db.builders.getBuilders()), key=builderKey),
             sorted(
                 [
-                    {
-                        "id": 1,
-                        "masterids": [13],
-                        "name": "somebuilder",
-                        "description": None,
-                        "description_html": None,
-                        "description_format": None,
-                        "projectid": None,
-                        "tags": [],
-                    },
-                    {
-                        "id": 2,
-                        "masterids": [13, 14],
-                        "name": "another",
-                        "description": None,
-                        "description_html": None,
-                        "description_format": None,
-                        "projectid": None,
-                        "tags": [],
-                    },
+                    BuilderModel(
+                        id=1,
+                        masterids=[13],
+                        name="somebuilder",
+                    ),
+                    BuilderModel(
+                        id=2,
+                        masterids=[13, 14],
+                        name="another",
+                    ),
                 ],
                 key=builderKey,
             ),
@@ -325,26 +331,15 @@ class Builder(interfaces.InterfaceTests, TestReactorMixin, unittest.TestCase):
             sorted((yield self.master.db.builders.getBuilders()), key=builderKey),
             sorted(
                 [
-                    {
-                        "id": 1,
-                        "masterids": [],
-                        "name": "somebuilder",
-                        "description": None,
-                        "description_html": None,
-                        "description_format": None,
-                        "projectid": None,
-                        "tags": [],
-                    },
-                    {
-                        "id": 2,
-                        "masterids": [14],
-                        "name": "another",
-                        "description": None,
-                        "description_html": None,
-                        "description_format": None,
-                        "projectid": None,
-                        "tags": [],
-                    },
+                    BuilderModel(
+                        id=1,
+                        name="somebuilder",
+                    ),
+                    BuilderModel(
+                        id=2,
+                        masterids=[14],
+                        name="another",
+                    ),
                 ],
                 key=builderKey,
             ),
