@@ -223,7 +223,7 @@ class RawLogChunkEndpoint(LogChunkEndpointBase):
         self.validateData(logchunk)
         if logid == 60:
             expContent = 'Builder: some:builder\nBuild number: 3\nWorker name: wrk\n'
-            expContent += '\n'.join([line[1:] for line in expLines])
+            expContent += ''.join([f"{line[1:]}\n" for line in expLines])
             expFilename = "some:builder_build_3_step_make_log_stdio"
         else:
             expContent = '\n'.join(expLines) + '\n'
