@@ -13,23 +13,43 @@
 #
 # Copyright Buildbot Team Members
 
+from __future__ import annotations
 
 import base64
-import bz2
 import textwrap
-import zlib
+from typing import TYPE_CHECKING
 
 import sqlalchemy as sa
 from twisted.internet import defer
 from twisted.trial import unittest
 
+from buildbot.db import compression
 from buildbot.db import logs
 from buildbot.test import fakedb
 from buildbot.test.util import connector_component
 from buildbot.test.util import interfaces
-from buildbot.test.util import validation
 from buildbot.util import bytes2unicode
 from buildbot.util import unicode2bytes
+from buildbot.util.twisted import async_to_deferred
+
+if TYPE_CHECKING:
+    from typing import Callable
+
+
+class FakeUnavailableCompressor(compression.CompressorInterface):
+    name = "fake"
+    available = False
+
+    HEADER = b"[FakeHeader]"
+
+    @staticmethod
+    def dumps(data: bytes) -> bytes:
+        return FakeUnavailableCompressor.HEADER + data
+
+    @staticmethod
+    def read(data: bytes) -> bytes:
+        assert data.startswith(FakeUnavailableCompressor.HEADER)
+        return data[len(FakeUnavailableCompressor.HEADER) :]
 
 
 class Tests(interfaces.InterfaceTests):
@@ -173,33 +193,25 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_getLog(self):
-        yield self.insert_test_data(
-            self.backgroundData
-            + [
-                fakedb.Log(
-                    id=201,
-                    stepid=101,
-                    name='stdio',
-                    slug='stdio',
-                    complete=0,
-                    num_lines=200,
-                    type='s',
-                ),
-            ]
-        )
+        yield self.insert_test_data([
+            *self.backgroundData,
+            fakedb.Log(
+                id=201, stepid=101, name="stdio", slug="stdio", complete=0, num_lines=200, type="s"
+            ),
+        ])
         logdict = yield self.db.logs.getLog(201)
-        validation.verifyDbDict(self, 'logdict', logdict)
+        self.assertIsInstance(logdict, logs.LogModel)
         self.assertEqual(
             logdict,
-            {
-                'id': 201,
-                'stepid': 101,
-                'name': 'stdio',
-                'slug': 'stdio',
-                'complete': False,
-                'num_lines': 200,
-                'type': 's',
-            },
+            logs.LogModel(
+                id=201,
+                stepid=101,
+                name='stdio',
+                slug='stdio',
+                complete=False,
+                num_lines=200,
+                type='s',
+            ),
         )
 
     @defer.inlineCallbacks
@@ -209,90 +221,60 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_getLogBySlug(self):
-        yield self.insert_test_data(
-            self.backgroundData
-            + [
-                fakedb.Log(
-                    id=201,
-                    stepid=101,
-                    name='stdio',
-                    slug='stdio',
-                    complete=0,
-                    num_lines=200,
-                    type='s',
-                ),
-                fakedb.Log(
-                    id=202,
-                    stepid=101,
-                    name='dbg.log',
-                    slug='dbg_log',
-                    complete=1,
-                    num_lines=200,
-                    type='s',
-                ),
-            ]
-        )
+        yield self.insert_test_data([
+            *self.backgroundData,
+            fakedb.Log(
+                id=201, stepid=101, name="stdio", slug="stdio", complete=0, num_lines=200, type="s"
+            ),
+            fakedb.Log(
+                id=202,
+                stepid=101,
+                name="dbg.log",
+                slug="dbg_log",
+                complete=1,
+                num_lines=200,
+                type="s",
+            ),
+        ])
         logdict = yield self.db.logs.getLogBySlug(101, 'dbg_log')
-        validation.verifyDbDict(self, 'logdict', logdict)
-        self.assertEqual(logdict['id'], 202)
+        self.assertIsInstance(logdict, logs.LogModel)
+        self.assertEqual(logdict.id, 202)
 
     @defer.inlineCallbacks
     def test_getLogBySlug_missing(self):
-        yield self.insert_test_data(
-            self.backgroundData
-            + [
-                fakedb.Log(
-                    id=201,
-                    stepid=101,
-                    name='stdio',
-                    slug='stdio',
-                    complete=0,
-                    num_lines=200,
-                    type='s',
-                ),
-            ]
-        )
+        yield self.insert_test_data([
+            *self.backgroundData,
+            fakedb.Log(
+                id=201, stepid=101, name="stdio", slug="stdio", complete=0, num_lines=200, type="s"
+            ),
+        ])
         logdict = yield self.db.logs.getLogBySlug(102, 'stdio')
         self.assertEqual(logdict, None)
 
     @defer.inlineCallbacks
     def test_getLogs(self):
-        yield self.insert_test_data(
-            self.backgroundData
-            + [
-                fakedb.Log(
-                    id=201,
-                    stepid=101,
-                    name='stdio',
-                    slug='stdio',
-                    complete=0,
-                    num_lines=200,
-                    type='s',
-                ),
-                fakedb.Log(
-                    id=202,
-                    stepid=101,
-                    name='dbg.log',
-                    slug='dbg_log',
-                    complete=1,
-                    num_lines=300,
-                    type='t',
-                ),
-                fakedb.Log(
-                    id=203,
-                    stepid=102,
-                    name='stdio',
-                    slug='stdio',
-                    complete=0,
-                    num_lines=200,
-                    type='s',
-                ),
-            ]
-        )
+        yield self.insert_test_data([
+            *self.backgroundData,
+            fakedb.Log(
+                id=201, stepid=101, name="stdio", slug="stdio", complete=0, num_lines=200, type="s"
+            ),
+            fakedb.Log(
+                id=202,
+                stepid=101,
+                name="dbg.log",
+                slug="dbg_log",
+                complete=1,
+                num_lines=300,
+                type="t",
+            ),
+            fakedb.Log(
+                id=203, stepid=102, name="stdio", slug="stdio", complete=0, num_lines=200, type="s"
+            ),
+        ])
         logdicts = yield self.db.logs.getLogs(101)
         for logdict in logdicts:
-            validation.verifyDbDict(self, 'logdict', logdict)
-        self.assertEqual(sorted([ld['id'] for ld in logdicts]), [201, 202])
+            self.assertIsInstance(logdict, logs.LogModel)
+        self.assertEqual(sorted([ld.id for ld in logdicts]), [201, 202])
 
     @defer.inlineCallbacks
     def test_getLogLines(self):
@@ -304,20 +286,12 @@ class Tests(interfaces.InterfaceTests):
 
     @defer.inlineCallbacks
     def test_getLogLines_empty(self):
-        yield self.insert_test_data(
-            self.backgroundData
-            + [
-                fakedb.Log(
-                    id=201,
-                    stepid=101,
-                    name='stdio',
-                    slug='stdio',
-                    complete=0,
-                    num_lines=200,
-                    type='s',
-                ),
-            ]
-        )
+        yield self.insert_test_data([
+            *self.backgroundData,
+            fakedb.Log(
+                id=201, stepid=101, name="stdio", slug="stdio", complete=0, num_lines=200, type="s"
+            ),
+        ])
         self.assertEqual((yield self.db.logs.getLogLines(201, 9, 99)), '')
         self.assertEqual((yield self.db.logs.getLogLines(999, 9, 99)), '')
 
@@ -340,18 +314,18 @@ class Tests(interfaces.InterfaceTests):
             stepid=101, name='config.log', slug='config_log', type='t'
         )
         logdict = yield self.db.logs.getLog(logid)
-        validation.verifyDbDict(self, 'logdict', logdict)
+        self.assertIsInstance(logdict, logs.LogModel)
         self.assertEqual(
             logdict,
-            {
-                'id': logid,
-                'stepid': 101,
-                'name': 'config.log',
-                'slug': 'config_log',
-                'complete': False,
-                'num_lines': 0,
-                'type': 't',
-            },
+            logs.LogModel(
+                id=logid,
+                stepid=101,
+                name='config.log',
+                slug='config_log',
+                complete=False,
+                num_lines=0,
+                type='t',
+            ),
         )
 
     @defer.inlineCallbacks
@@ -367,15 +341,15 @@ class Tests(interfaces.InterfaceTests):
         self.assertEqual((yield self.db.logs.getLogLines(logid, 0, 1)), "xyz\nXYZ\n")
         self.assertEqual(
             (yield self.db.logs.getLog(logid)),
-            {
-                'complete': False,
-                'id': logid,
-                'name': 'another',
-                'slug': 'another',
-                'num_lines': 2,
-                'stepid': 102,
-                'type': 's',
-            },
+            logs.LogModel(
+                complete=False,
+                id=logid,
+                name='another',
+                slug='another',
+                num_lines=2,
+                stepid=102,
+                type='s',
+            ),
         )
 
     @defer.inlineCallbacks
@@ -473,118 +447,79 @@ class RealTests(Tests):
             {'logid': 201, 'first_line': 7, 'last_line': 7, 'content': b'abc', 'compressed': 0},
         )
 
-    @defer.inlineCallbacks
-    def test_raw_compress_big_chunk(self):
-        yield self.insert_test_data(self.backgroundData + self.testLogLines)
+    async def _test_compress_big_chunk(
+        self,
+        dumps: Callable[[bytes], bytes],
+        compressed_id: int,
+    ) -> None:
+        await self.insert_test_data(self.backgroundData + self.testLogLines)
         line = 'xy' * 10000
+        self.assertEqual((await self.db.logs.appendLog(201, line + '\n')), (7, 7))
+
+        def thd(conn):
+            res = conn.execute(
+                self.db.model.logchunks.select().where(self.db.model.logchunks.c.first_line > 6)
+            ).mappings()
+            row = res.fetchone()
+            res.close()
+            return dict(row)
+
+        newRow = await self.db.pool.do(thd)
+        self.assertEqual(
+            newRow,
+            {
+                'logid': 201,
+                'first_line': 7,
+                'last_line': 7,
+                'content': dumps(unicode2bytes(line)),
+                'compressed': compressed_id,
+            },
+        )
+
+    @async_to_deferred
+    async def test_raw_compress_big_chunk(self):
         self.db.master.config.logCompressionMethod = "raw"
-        self.assertEqual((yield self.db.logs.appendLog(201, line + '\n')), (7, 7))
+        await self._test_compress_big_chunk(lambda d: d, 0)
 
-        def thd(conn):
-            res = conn.execute(
-                self.db.model.logchunks.select().where(self.db.model.logchunks.c.first_line > 6)
-            ).mappings()
-            row = res.fetchone()
-            res.close()
-            return dict(row)
-
-        newRow = yield self.db.pool.do(thd)
-        self.assertEqual(
-            newRow,
-            {
-                'logid': 201,
-                'first_line': 7,
-                'last_line': 7,
-                'content': unicode2bytes(line),
-                'compressed': 0,
-            },
-        )
-
-    @defer.inlineCallbacks
-    def test_gz_compress_big_chunk(self):
-        yield self.insert_test_data(self.backgroundData + self.testLogLines)
-        line = 'xy' * 10000
+    @async_to_deferred
+    async def test_gz_compress_big_chunk(self):
         self.db.master.config.logCompressionMethod = "gz"
-        self.assertEqual((yield self.db.logs.appendLog(201, line + '\n')), (7, 7))
+        await self._test_compress_big_chunk(compression.GZipCompressor.dumps, 1)
 
-        def thd(conn):
-            res = conn.execute(
-                self.db.model.logchunks.select().where(self.db.model.logchunks.c.first_line > 6)
-            ).mappings()
-            row = res.fetchone()
-            res.close()
-            return dict(row)
-
-        newRow = yield self.db.pool.do(thd)
-        self.assertEqual(
-            newRow,
-            {
-                'logid': 201,
-                'first_line': 7,
-                'last_line': 7,
-                'content': zlib.compress(unicode2bytes(line), 9),
-                'compressed': 1,
-            },
-        )
-
-    @defer.inlineCallbacks
-    def test_bz2_compress_big_chunk(self):
-        yield self.insert_test_data(self.backgroundData + self.testLogLines)
-        line = 'xy' * 10000
+    @async_to_deferred
+    async def test_bz2_compress_big_chunk(self):
         self.db.master.config.logCompressionMethod = "bz2"
-        self.assertEqual((yield self.db.logs.appendLog(201, line + '\n')), (7, 7))
+        await self._test_compress_big_chunk(compression.BZipCompressor.dumps, 2)
 
-        def thd(conn):
-            res = conn.execute(
-                self.db.model.logchunks.select().where(self.db.model.logchunks.c.first_line > 6)
-            ).mappings()
-            row = res.fetchone()
-            res.close()
-            return dict(row)
-
-        newRow = yield self.db.pool.do(thd)
-        self.assertEqual(
-            newRow,
-            {
-                'logid': 201,
-                'first_line': 7,
-                'last_line': 7,
-                'content': bz2.compress(unicode2bytes(line), 9),
-                'compressed': 2,
-            },
-        )
-
-    @defer.inlineCallbacks
-    def test_lz4_compress_big_chunk(self):
+    @async_to_deferred
+    async def test_lz4_compress_big_chunk(self):
         try:
-            import lz4  # noqa pylint: disable=unused-import,import-outside-toplevel
+            import lz4  # noqa: F401
         except ImportError as e:
             raise unittest.SkipTest("lz4 not installed, skip the test") from e
 
-        yield self.insert_test_data(self.backgroundData + self.testLogLines)
-        line = 'xy' * 10000
         self.db.master.config.logCompressionMethod = "lz4"
-        self.assertEqual((yield self.db.logs.appendLog(201, line + '\n')), (7, 7))
+        await self._test_compress_big_chunk(compression.LZ4Compressor.dumps, 3)
 
-        def thd(conn):
-            res = conn.execute(
-                self.db.model.logchunks.select().where(self.db.model.logchunks.c.first_line > 6)
-            ).mappings()
-            row = res.fetchone()
-            res.close()
-            return dict(row)
+    @async_to_deferred
+    async def test_zstd_compress_big_chunk(self):
+        try:
+            import zstandard  # noqa: F401
+        except ImportError as e:
+            raise unittest.SkipTest("zstandard not installed, skip the test") from e
 
-        newRow = yield self.db.pool.do(thd)
-        self.assertEqual(
-            newRow,
-            {
-                'logid': 201,
-                'first_line': 7,
-                'last_line': 7,
-                'content': logs.dumps_lz4(line.encode('utf-8')),
-                'compressed': 3,
-            },
-        )
+        self.db.master.config.logCompressionMethod = "zstd"
+        await self._test_compress_big_chunk(compression.ZStdCompressor.dumps, 4)
+
+    @async_to_deferred
+    async def test_br_compress_big_chunk(self):
+        try:
+            import brotli  # noqa: F401
+        except ImportError as e:
+            raise unittest.SkipTest("brotli not installed, skip the test") from e
+
+        self.db.master.config.logCompressionMethod = "br"
+        await self._test_compress_big_chunk(compression.BrotliCompressor.dumps, 5)
 
     @defer.inlineCallbacks
     def do_addLogLines_huge_log(self, NUM_CHUNKS=3000, chunk=('xy' * 70 + '\n') * 3):
@@ -601,21 +536,19 @@ class RealTests(Tests):
             )
             for i in range(NUM_CHUNKS)
         ]
-        yield self.insert_test_data(
-            self.backgroundData
-            + [
-                fakedb.Log(
-                    id=201,
-                    stepid=101,
-                    name='stdio',
-                    slug='stdio',
-                    complete=0,
-                    num_lines=NUM_CHUNKS * 3,
-                    type='s',
-                )
-            ]
-            + test_data
-        )
+        yield self.insert_test_data([
+            *self.backgroundData,
+            fakedb.Log(
+                id=201,
+                stepid=101,
+                name="stdio",
+                slug="stdio",
+                complete=0,
+                num_lines=NUM_CHUNKS * 3,
+                type="s",
+            ),
+            *test_data,
+        ])
         wholeLog = yield self.db.logs.getLogLines(201, 0, NUM_CHUNKS * 3)
         for i in range(10):
             yield self.db.logs.compressLog(201)
@@ -652,33 +585,25 @@ class RealTests(Tests):
 
     @defer.inlineCallbacks
     def test_compressLog_empty_log(self):
-        yield self.insert_test_data(
-            self.backgroundData
-            + [
-                fakedb.Log(
-                    id=201,
-                    stepid=101,
-                    name='stdio',
-                    slug='stdio',
-                    complete=1,
-                    num_lines=0,
-                    type='s',
-                ),
-            ]
-        )
+        yield self.insert_test_data([
+            *self.backgroundData,
+            fakedb.Log(
+                id=201, stepid=101, name="stdio", slug="stdio", complete=1, num_lines=0, type="s"
+            ),
+        ])
         yield self.db.logs.compressLog(201)
         logdict = yield self.db.logs.getLog(201)
         self.assertEqual(
             logdict,
-            {
-                'stepid': 101,
-                'num_lines': 0,
-                'name': 'stdio',
-                'id': 201,
-                'type': 's',
-                'slug': 'stdio',
-                'complete': True,
-            },
+            logs.LogModel(
+                stepid=101,
+                num_lines=0,
+                name='stdio',
+                id=201,
+                type='s',
+                slug='stdio',
+                complete=True,
+            ),
         )
 
     @defer.inlineCallbacks
@@ -709,12 +634,106 @@ class RealTests(Tests):
         self.assertEqual(deleted_chunks, 0)
         for logid in logids:
             logdict = yield self.db.logs.getLog(logid)
-            self.assertEqual(logdict['type'], 'd')
+            self.assertEqual(logdict.type, 'd')
 
             # we make sure we can still getLogLines, it will just return empty value
-            lines = yield self.db.logs.getLogLines(logid, 0, logdict['num_lines'])
+            lines = yield self.db.logs.getLogLines(logid, 0, logdict.num_lines)
             self.assertEqual(lines, '')
 
+    @async_to_deferred
+    async def test_insert_logs_non_existing_compression_method(self):
+        LOG_ID = 201
+        await self.insert_test_data([
+            *self.backgroundData,
+            fakedb.Log(
+                id=LOG_ID, stepid=101, name="stdio", slug="stdio", complete=0, num_lines=1, type="s"
+            ),
+            fakedb.LogChunk(
+                logid=LOG_ID, first_line=0, last_line=0, compressed=0, content=b"fake_log_chunk\n"
+            ),
+        ])
+
+        def _thd_get_log_chunks(conn):
+            res = conn.execute(
+                self.db.model.logchunks.select().where(self.db.model.logchunks.c.logid == LOG_ID)
+            ).mappings()
+            return [dict(row) for row in res]
+
+        self.db.master.config.logCompressionMethod = "non_existing"
+        await self.db.logs.compressLog(LOG_ID)
+
+        self.assertEqual(
+            await self.db.pool.do(_thd_get_log_chunks),
+            [
+                {
+                    'compressed': 0,
+                    'content': b'fake_log_chunk\n',
+                    'first_line': 0,
+                    'last_line': 0,
+                    'logid': LOG_ID,
+                }
+            ],
+        )
+
+        await self.db.logs.appendLog(LOG_ID, 'other_chunk\n')
+
+        self.assertEqual(
+            await self.db.pool.do(_thd_get_log_chunks),
+            [
+                {
+                    'compressed': 0,
+                    'content': b'fake_log_chunk\n',
+                    'first_line': 0,
+                    'last_line': 0,
+                    'logid': LOG_ID,
+                },
+                {
+                    'compressed': 0,
+                    'content': b'other_chunk',
+                    'first_line': 1,
+                    'last_line': 1,
+                    'logid': LOG_ID,
+                },
+            ],
+        )
+
+    @async_to_deferred
+    async def test_get_logs_non_existing_compression_method(self):
+        LOG_ID = 201
+
+        # register fake compressor
+        FAKE_COMPRESSOR_ID = max(self.db.logs.COMPRESSION_BYID.keys()) + 1
+        self.db.logs.COMPRESSION_BYID[FAKE_COMPRESSOR_ID] = FakeUnavailableCompressor
+        NON_EXISTING_COMPRESSOR_ID = max(self.db.logs.COMPRESSION_BYID.keys()) + 1
+
+        await self.insert_test_data([
+            *self.backgroundData,
+            fakedb.Log(
+                id=LOG_ID, stepid=101, name="stdio", slug="stdio", complete=0, num_lines=1, type="s"
+            ),
+            fakedb.LogChunk(
+                logid=LOG_ID,
+                first_line=0,
+                last_line=0,
+                compressed=FAKE_COMPRESSOR_ID,
+                content=b"fake_log_chunk\n",
+            ),
+            fakedb.LogChunk(
+                logid=LOG_ID,
+                first_line=1,
+                last_line=1,
+                compressed=NON_EXISTING_COMPRESSOR_ID,
+                content=b"fake_log_chunk\n",
+            ),
+        ])
+
+        with self.assertRaises(logs.LogCompressionFormatUnavailableError):
+            await self.db.logs.getLogLines(logid=LOG_ID, first_line=0, last_line=0)
+
+        with self.assertRaises(logs.LogCompressionFormatUnavailableError):
+            await self.db.logs.getLogLines(logid=LOG_ID, first_line=1, last_line=1)
+        self.flushLoggedErrors(logs.LogCompressionFormatUnavailableError)
+
 
 class TestFakeDB(unittest.TestCase, connector_component.FakeConnectorComponentMixin, Tests):
     @defer.inlineCallbacks
