@@ -42,7 +42,7 @@ class Migration(migration.MigrateTestMixin, unittest.TestCase):
             sa.Column('projectid', sa.Integer, nullable=True),
             sa.Column('name_hash', sa.String(40), nullable=False),
         )
-        builders.create()
+        builders.create(bind=conn)
 
         conn.execute(
             builders.insert(),
@@ -56,6 +56,7 @@ class Migration(migration.MigrateTestMixin, unittest.TestCase):
                 }
             ],
         )
+        conn.commit()
 
     def test_update(self):
         def setup_thd(conn):
