@@ -30,6 +30,7 @@ from buildbot.test.fake import fakemaster
 from buildbot.test.reactor import TestReactorMixin
 from buildbot.util import epoch2datetime
 from buildbot.util.eventual import fireEventually
+from buildbot.util.twisted import async_to_deferred
 
 
 def nth_worker(n):
@@ -107,6 +108,7 @@ class TestBRDBase(TestReactorMixin, unittest.TestCase):
         self.builders[name] = bldr
 
         def maybeStartBuild(worker, builds):
+            worker.isAvailable.return_value = False
             self.startedBuilds.append((worker.name, builds))
             d = defer.Deferred()
             self.reactor.callLater(0, d.callback, True)
@@ -214,11 +216,11 @@ class Test(TestBRDBase):
     def test_maybeStartBuildsOn_exception(self):
         self.addBuilders(['bldr1'])
 
-        def _maybeStartBuildsOnBuilder(n):
+        async def _maybeStartBuildsOnBuilder(n):
             # fail slowly, so that the activity loop doesn't exit too soon
             d = defer.Deferred()
             self.reactor.callLater(0, d.errback, failure.Failure(RuntimeError("oh noes")))
-            return d
+            await d
 
         self.brd._maybeStartBuildsOnBuilder = _maybeStartBuildsOnBuilder
 
@@ -413,14 +415,14 @@ class TestMaybeStartBuilds(TestBRDBase):
 
     # _maybeStartBuildsOnBuilder
 
-    @defer.inlineCallbacks
-    def do_test_maybeStartBuildsOnBuilder(self, rows=None, exp_claims=None, exp_builds=None):
+    @async_to_deferred
+    async def do_test_maybeStartBuildsOnBuilder(self, rows=None, exp_claims=None, exp_builds=None):
         rows = rows or []
         exp_claims = exp_claims or []
         exp_builds = exp_builds or []
-        yield self.master.db.insert_test_data(rows)
+        await self.master.db.insert_test_data(rows)
 
-        yield self.brd._maybeStartBuildsOnBuilder(self.bldr)
+        await self.brd._maybeStartBuildsOnBuilder(self.bldr)
 
         self.assertMyClaims(exp_claims)
         self.assertBuildsStarted(exp_builds)
@@ -441,7 +443,8 @@ class TestMaybeStartBuilds(TestBRDBase):
     @defer.inlineCallbacks
     def test_limited_by_workers(self):
         self.addWorkers({'test-worker1': 1})
-        rows = self.base_rows + [
+        rows = [
+            *self.base_rows,
             fakedb.BuildRequest(id=11, buildsetid=11, builderid=77, submitted_at=135000),
             fakedb.BuildRequest(id=10, buildsetid=11, builderid=77, submitted_at=130000),
         ]
@@ -453,7 +456,8 @@ class TestMaybeStartBuilds(TestBRDBase):
     def test_sorted_by_submit_time(self):
         # same as "limited_by_workers" but with rows swapped
         self.addWorkers({'test-worker1': 1})
-        rows = self.base_rows + [
+        rows = [
+            *self.base_rows,
             fakedb.BuildRequest(id=10, buildsetid=11, builderid=77, submitted_at=130000),
             fakedb.BuildRequest(id=11, buildsetid=11, builderid=77, submitted_at=135000),
         ]
@@ -464,7 +468,8 @@ class TestMaybeStartBuilds(TestBRDBase):
     @defer.inlineCallbacks
     def test_limited_by_available_workers(self):
         self.addWorkers({'test-worker1': 0, 'test-worker2': 1})
-        rows = self.base_rows + [
+        rows = [
+            *self.base_rows,
             fakedb.BuildRequest(id=10, buildsetid=11, builderid=77, submitted_at=130000),
             fakedb.BuildRequest(id=11, buildsetid=11, builderid=77, submitted_at=135000),
         ]
@@ -489,7 +494,8 @@ class TestMaybeStartBuilds(TestBRDBase):
 
         self.master.db.buildrequests.getBuildRequests = longGetBuildRequests
 
-        rows = self.base_rows + [
+        rows = [
+            *self.base_rows,
             fakedb.BuildRequest(id=10, buildsetid=11, builderid=77, submitted_at=130000),
             fakedb.BuildRequest(id=11, buildsetid=11, builderid=77, submitted_at=135000),
         ]
@@ -518,7 +524,8 @@ class TestMaybeStartBuilds(TestBRDBase):
         self.bldr.config.canStartBuild = _canStartBuild
 
         self.addWorkers({'test-worker1': 1, 'test-worker2': 1, 'test-worker3': 1})
-        rows = self.base_rows + [
+        rows = [
+            *self.base_rows,
             fakedb.BuildRequest(id=10, buildsetid=11, builderid=77, submitted_at=130000),
             fakedb.BuildRequest(id=11, buildsetid=11, builderid=77, submitted_at=135000),
             fakedb.BuildRequest(id=12, buildsetid=11, builderid=77, submitted_at=140000),
@@ -562,7 +569,8 @@ class TestMaybeStartBuilds(TestBRDBase):
         self.bldr.config.canStartBuild = _canStartBuild
 
         self.addWorkers({'test-worker1': 1, 'test-worker2': 1, 'test-worker3': 1})
-        rows = self.base_rows + [
+        rows = [
+            *self.base_rows,
             fakedb.BuildRequest(id=10, buildsetid=11, builderid=77, submitted_at=130000),
             fakedb.BuildRequest(id=11, buildsetid=11, builderid=77, submitted_at=135000),
             fakedb.BuildRequest(id=12, buildsetid=11, builderid=77, submitted_at=140000),
@@ -590,7 +598,8 @@ class TestMaybeStartBuilds(TestBRDBase):
     def test_unlimited(self):
         self.bldr.config.nextWorker = nth_worker(-1)
         self.addWorkers({'test-worker1': 1, 'test-worker2': 1})
-        rows = self.base_rows + [
+        rows = [
+            *self.base_rows,
             fakedb.BuildRequest(id=10, buildsetid=11, builderid=77, submitted_at=130000),
             fakedb.BuildRequest(id=11, buildsetid=11, builderid=77, submitted_at=135000),
         ]
@@ -613,7 +622,8 @@ class TestMaybeStartBuilds(TestBRDBase):
         self.bldr.maybeStartBuild = maybeStartBuild
 
         self.addWorkers({'test-worker1': 1, 'test-worker2': 1})
-        rows = self.base_rows + [
+        rows = [
+            *self.base_rows,
             fakedb.BuildRequest(id=10, buildsetid=11, builderid=77, submitted_at=130000),
             fakedb.BuildRequest(id=11, buildsetid=11, builderid=77, submitted_at=135000),
         ]
@@ -624,8 +634,8 @@ class TestMaybeStartBuilds(TestBRDBase):
             exp_builds=[('test-worker2', [10]), ('test-worker1', [11])],
         )
 
-    @defer.inlineCallbacks
-    def test_bldr_maybeStartBuild_fails_once(self):
+    @async_to_deferred
+    async def test_bldr_maybeStartBuild_fails_once(self):
         self.bldr.config.nextWorker = nth_worker(-1)
         # the builder fails to start the build; we'll see that the build
         # was requested, but the brids will get claimed again
@@ -638,21 +648,22 @@ class TestMaybeStartBuilds(TestBRDBase):
         self.bldr.maybeStartBuild = maybeStartBuild
 
         self.addWorkers({'test-worker1': 1, 'test-worker2': 1})
-        rows = self.base_rows + [
+        rows = [
+            *self.base_rows,
             fakedb.BuildRequest(id=10, buildsetid=11, builderid=77, submitted_at=130000),
             fakedb.BuildRequest(id=11, buildsetid=11, builderid=77, submitted_at=135000),
         ]
 
-        yield self.master.db.insert_test_data(rows)
+        await self.master.db.insert_test_data(rows)
 
         # first time around, only #11 stays claimed
-        yield self.brd._maybeStartBuildsOnBuilder(self.bldr)
+        await self.brd._maybeStartBuildsOnBuilder(self.bldr)
         self.assertMyClaims([11])  # claimed again so none taken!
         self.assertBuildsStarted([('test-worker2', [10]), ('test-worker1', [11])])
 
         # second time around the #10 will pass, adding another request and it
         # is claimed
-        yield self.brd._maybeStartBuildsOnBuilder(self.bldr)
+        await self.brd._maybeStartBuildsOnBuilder(self.bldr)
         self.assertMyClaims([10, 11])
         self.assertBuildsStarted([
             ('test-worker2', [10]),
@@ -664,9 +675,7 @@ class TestMaybeStartBuilds(TestBRDBase):
     def test_limited_by_requests(self):
         self.bldr.config.nextWorker = nth_worker(1)
         self.addWorkers({'test-worker1': 1, 'test-worker2': 1})
-        rows = self.base_rows + [
-            fakedb.BuildRequest(id=11, buildsetid=11, builderid=77),
-        ]
+        rows = [*self.base_rows, fakedb.BuildRequest(id=11, buildsetid=11, builderid=77)]
         yield self.do_test_maybeStartBuildsOnBuilder(
             rows=rows, exp_claims=[11], exp_builds=[('test-worker2', [11])]
         )
@@ -675,36 +684,28 @@ class TestMaybeStartBuilds(TestBRDBase):
     def test_nextWorker_None(self):
         self.bldr.config.nextWorker = lambda _1, _2, _3: defer.succeed(None)
         self.addWorkers({'test-worker1': 1, 'test-worker2': 1})
-        rows = self.base_rows + [
-            fakedb.BuildRequest(id=11, buildsetid=11, builderid=77),
-        ]
+        rows = [*self.base_rows, fakedb.BuildRequest(id=11, buildsetid=11, builderid=77)]
         yield self.do_test_maybeStartBuildsOnBuilder(rows=rows, exp_claims=[], exp_builds=[])
 
     @defer.inlineCallbacks
     def test_nextWorker_bogus(self):
         self.bldr.config.nextWorker = lambda _1, _2, _3: defer.succeed(mock.Mock())
         self.addWorkers({'test-worker1': 1, 'test-worker2': 1})
-        rows = self.base_rows + [
-            fakedb.BuildRequest(id=11, buildsetid=11, builderid=77),
-        ]
+        rows = [*self.base_rows, fakedb.BuildRequest(id=11, buildsetid=11, builderid=77)]
         yield self.do_test_maybeStartBuildsOnBuilder(rows=rows, exp_claims=[], exp_builds=[])
 
     @defer.inlineCallbacks
     def test_nextBuild_None(self):
         self.bldr.config.nextBuild = lambda _1, _2: defer.succeed(None)
         self.addWorkers({'test-worker1': 1, 'test-worker2': 1})
-        rows = self.base_rows + [
-            fakedb.BuildRequest(id=11, buildsetid=11, builderid=77),
-        ]
+        rows = [*self.base_rows, fakedb.BuildRequest(id=11, buildsetid=11, builderid=77)]
         yield self.do_test_maybeStartBuildsOnBuilder(rows=rows, exp_claims=[], exp_builds=[])
 
     @defer.inlineCallbacks
     def test_nextBuild_bogus(self):
         self.bldr.config.nextBuild = lambda _1, _2: mock.Mock()
         self.addWorkers({'test-worker1': 1, 'test-worker2': 1})
-        rows = self.base_rows + [
-            fakedb.BuildRequest(id=11, buildsetid=11, builderid=77),
-        ]
+        rows = [*self.base_rows, fakedb.BuildRequest(id=11, buildsetid=11, builderid=77)]
         yield self.do_test_maybeStartBuildsOnBuilder(rows=rows, exp_claims=[], exp_builds=[])
 
     @defer.inlineCallbacks
@@ -714,9 +715,7 @@ class TestMaybeStartBuilds(TestBRDBase):
 
         self.bldr.config.nextBuild = nextBuildRaises
         self.addWorkers({'test-worker1': 1, 'test-worker2': 1})
-        rows = self.base_rows + [
-            fakedb.BuildRequest(id=11, buildsetid=11, builderid=77),
-        ]
+        rows = [*self.base_rows, fakedb.BuildRequest(id=11, buildsetid=11, builderid=77)]
         result = self.do_test_maybeStartBuildsOnBuilder(rows=rows, exp_claims=[], exp_builds=[])
         self.assertEqual(1, len(self.flushLoggedErrors(RuntimeError)))
         yield result
@@ -742,7 +741,8 @@ class TestMaybeStartBuilds(TestBRDBase):
         self.master.db.buildrequests.claimBuildRequests = claimBuildRequests
 
         self.addWorkers({'test-worker1': 1, 'test-worker2': 1})
-        rows = self.base_rows + [
+        rows = [
+            *self.base_rows,
             fakedb.BuildRequest(
                 id=10, buildsetid=11, builderid=77, submitted_at=130000
             ),  # will turn out to be claimed!
