@@ -28,6 +28,8 @@ from buildbot.test.fake import fakemaster
 from buildbot.test.reactor import TestReactorMixin
 from buildbot.test.util.config import ConfigErrorsMixin
 from buildbot.test.util.reporter import ReporterTestMixin
+from buildbot.test.util.warnings import assertProducesWarnings
+from buildbot.warnings import DeprecatedApiWarning
 
 
 class TestBuildGenerator(ConfigErrorsMixin, TestReactorMixin, unittest.TestCase, ReporterTestMixin):
@@ -37,13 +39,29 @@ class TestBuildGenerator(ConfigErrorsMixin, TestReactorMixin, unittest.TestCase,
         self.master = fakemaster.make_master(self, wantData=True, wantDb=True, wantMq=True)
 
     @defer.inlineCallbacks
-    def insert_build_finished_get_props(self, results, **kwargs):
+    def insert_build_finished_get_props(
+        self, results, add_logs=None, want_logs_content=False, **kwargs
+    ):
         build = yield self.insert_build_finished(results, **kwargs)
-        yield utils.getDetailsForBuild(self.master, build, want_properties=True)
+        yield utils.getDetailsForBuild(
+            self.master,
+            build,
+            want_properties=True,
+            add_logs=add_logs,
+            want_logs_content=want_logs_content,
+        )
         return build
 
     @defer.inlineCallbacks
-    def setup_generator(self, results=SUCCESS, message=None, db_args=None, **kwargs):
+    def setup_generator(
+        self,
+        results=SUCCESS,
+        message=None,
+        db_args=None,
+        add_logs=None,
+        want_logs_content=False,
+        **kwargs,
+    ):
         if message is None:
             message = {
                 "body": "body",
@@ -54,12 +72,15 @@ class TestBuildGenerator(ConfigErrorsMixin, TestReactorMixin, unittest.TestCase,
         if db_args is None:
             db_args = {}
 
-        build = yield self.insert_build_finished_get_props(results, **db_args)
+        build = yield self.insert_build_finished_get_props(
+            results, want_logs_content=want_logs_content, add_logs=add_logs, **db_args
+        )
         buildset = yield self.get_inserted_buildset()
 
-        g = BuildStatusGenerator(**kwargs)
+        g = BuildStatusGenerator(add_logs=add_logs, **kwargs)
 
         g.formatter = Mock(spec=g.formatter)
+        g.formatter.want_logs_content = want_logs_content
         g.formatter.format_message_for_build.return_value = message
 
         return g, build, buildset
@@ -166,7 +187,19 @@ class TestBuildGenerator(ConfigErrorsMixin, TestReactorMixin, unittest.TestCase,
 
     @defer.inlineCallbacks
     def test_build_message_addLogs(self):
-        g, build, _ = yield self.setup_generator(mode=("change",), add_logs=True)
+        with assertProducesWarnings(
+            DeprecatedApiWarning,
+            message_pattern=".*argument add_logs have been deprecated.*",
+        ):
+            g, build, _ = yield self.setup_generator(mode=("change",), add_logs=True)
+        report = yield self.build_message(g, build)
+
+        self.assertEqual(report['logs'][0]['logid'], 60)
+        self.assertIn("log with", report['logs'][0]['content']['content'])
+
+    @defer.inlineCallbacks
+    def test_build_message_want_logs_content(self):
+        g, build, _ = yield self.setup_generator(mode=("change",), want_logs_content=True)
         report = yield self.build_message(g, build)
 
         self.assertEqual(report['logs'][0]['logid'], 60)
@@ -267,9 +300,17 @@ class TestBuildStartEndGenerator(
         self.master = fakemaster.make_master(self, wantData=True, wantDb=True, wantMq=True)
 
     @defer.inlineCallbacks
-    def insert_build_finished_get_props(self, results, **kwargs):
+    def insert_build_finished_get_props(
+        self, results, add_logs=None, want_logs_content=False, **kwargs
+    ):
         build = yield self.insert_build_finished(results, **kwargs)
-        yield utils.getDetailsForBuild(self.master, build, want_properties=True)
+        yield utils.getDetailsForBuild(
+            self.master,
+            build,
+            want_properties=True,
+            add_logs=add_logs,
+            want_logs_content=want_logs_content,
+        )
         return build
 
     @parameterized.expand([
@@ -288,7 +329,14 @@ class TestBuildStartEndGenerator(
         with self.assertRaisesConfigError('must be a list or None'):
             g.check()
 
-    def setup_generator(self, results=SUCCESS, start_message=None, end_message=None, **kwargs):
+    def setup_generator(
+        self,
+        results=SUCCESS,
+        start_message=None,
+        end_message=None,
+        want_logs_content=False,
+        **kwargs,
+    ):
         if start_message is None:
             start_message = {
                 "body": "start body",
@@ -308,8 +356,10 @@ class TestBuildStartEndGenerator(
         g = BuildStartEndStatusGenerator(**kwargs)
 
         g.start_formatter = Mock(spec=g.start_formatter)
+        g.start_formatter.want_logs_content = want_logs_content
         g.start_formatter.format_message_for_build.return_value = start_message
         g.end_formatter = Mock(spec=g.end_formatter)
+        g.end_formatter.want_logs_content = want_logs_content
         g.end_formatter.format_message_for_build.return_value = end_message
 
         return g
@@ -405,8 +455,21 @@ class TestBuildStartEndGenerator(
 
     @defer.inlineCallbacks
     def test_build_message_add_logs(self):
-        g = yield self.setup_generator(add_logs=True)
-        build = yield self.insert_build_finished_get_props(SUCCESS)
+        with assertProducesWarnings(
+            DeprecatedApiWarning,
+            message_pattern=".*argument add_logs have been deprecated.*",
+        ):
+            g = yield self.setup_generator(add_logs=True)
+        build = yield self.insert_build_finished_get_props(SUCCESS, add_logs=True)
+        report = yield self.build_message(g, build)
+
+        self.assertEqual(report['logs'][0]['logid'], 60)
+        self.assertIn("log with", report['logs'][0]['content']['content'])
+
+    @defer.inlineCallbacks
+    def test_build_message_want_logs_content(self):
+        g = yield self.setup_generator(want_logs_content=True)
+        build = yield self.insert_build_finished_get_props(SUCCESS, want_logs_content=True)
         report = yield self.build_message(g, build)
 
         self.assertEqual(report['logs'][0]['logid'], 60)
