@@ -25,14 +25,13 @@ from buildbot.test.util.logging import LoggingMixin
 from buildbot.test.util.reporter import ReporterTestMixin
 
 
-class TestZulipStatusPush(unittest.TestCase, ReporterTestMixin, LoggingMixin, ConfigErrorsMixin,
-                          TestReactorMixin):
-
+class TestZulipStatusPush(
+    unittest.TestCase, ReporterTestMixin, LoggingMixin, ConfigErrorsMixin, TestReactorMixin
+):
     def setUp(self):
         self.setup_test_reactor()
         self.setup_reporter_test()
-        self.master = fakemaster.make_master(
-            testcase=self, wantData=True, wantDb=True, wantMq=True)
+        self.master = fakemaster.make_master(testcase=self, wantData=True, wantDb=True, wantMq=True)
 
     @defer.inlineCallbacks
     def tearDown(self):
@@ -41,10 +40,10 @@ class TestZulipStatusPush(unittest.TestCase, ReporterTestMixin, LoggingMixin, Co
 
     @defer.inlineCallbacks
     def setupZulipStatusPush(self, endpoint="http://example.com", token="123", stream=None):
-        self.sp = ZulipStatusPush(
-            endpoint=endpoint, token=token, stream=stream)
+        self.sp = ZulipStatusPush(endpoint=endpoint, token=token, stream=stream)
         self._http = yield fakehttpclientservice.HTTPClientService.getService(
-            self.master, self, endpoint, debug=None, verify=None)
+            self.master, self, endpoint, debug=None, verify=None
+        )
         yield self.sp.setServiceParent(self.master)
         yield self.master.startService()
 
@@ -61,8 +60,9 @@ class TestZulipStatusPush(unittest.TestCase, ReporterTestMixin, LoggingMixin, Co
                 "buildername": "Builder0",
                 "url": "http://localhost:8080/#/builders/79/builds/0",
                 "project": "testProject",
-                "timestamp": 10000001
-            })
+                "timestamp": 10000001,
+            },
+        )
         yield self.sp._got_event(('builds', 20, 'new'), build)
 
     @defer.inlineCallbacks
@@ -79,8 +79,9 @@ class TestZulipStatusPush(unittest.TestCase, ReporterTestMixin, LoggingMixin, Co
                 "url": "http://localhost:8080/#/builders/79/builds/0",
                 "project": "testProject",
                 "timestamp": 10000005,
-                "results": 0
-            })
+                "results": 0,
+            },
+        )
         yield self.sp._got_event(('builds', 20, 'finished'), build)
 
     @defer.inlineCallbacks
@@ -97,18 +98,17 @@ class TestZulipStatusPush(unittest.TestCase, ReporterTestMixin, LoggingMixin, Co
                 "url": "http://localhost:8080/#/builders/79/builds/0",
                 "project": "testProject",
                 "timestamp": 10000005,
-                "results": 0
-            })
+                "results": 0,
+            },
+        )
         yield self.sp._got_event(('builds', 20, 'finished'), build)
 
     def test_endpoint_string(self):
-        with self.assertRaisesConfigError(
-                "Endpoint must be a string"):
+        with self.assertRaisesConfigError("Endpoint must be a string"):
             ZulipStatusPush(endpoint=1234, token="abcd")
 
     def test_token_string(self):
-        with self.assertRaisesConfigError(
-                "Token must be a string"):
+        with self.assertRaisesConfigError("Token must be a string"):
             ZulipStatusPush(endpoint="http://example.com", token=1234)
 
     @defer.inlineCallbacks
@@ -124,8 +124,10 @@ class TestZulipStatusPush(unittest.TestCase, ReporterTestMixin, LoggingMixin, Co
                 "buildername": "Builder0",
                 "url": "http://localhost:8080/#/builders/79/builds/0",
                 "project": "testProject",
-                "timestamp": 10000001
-            }, code=500)
+                "timestamp": 10000001,
+            },
+            code=500,
+        )
         self.setUpLogging()
         yield self.sp._got_event(('builds', 20, 'new'), build)
         self.assertLogged('500: Error pushing build status to Zulip')
@@ -143,8 +145,10 @@ class TestZulipStatusPush(unittest.TestCase, ReporterTestMixin, LoggingMixin, Co
                 "buildername": "Builder0",
                 "url": "http://localhost:8080/#/builders/79/builds/0",
                 "project": "testProject",
-                "timestamp": 10000001
-            }, code=404)
+                "timestamp": 10000001,
+            },
+            code=404,
+        )
         self.setUpLogging()
         yield self.sp._got_event(('builds', 20, 'new'), build)
         self.assertLogged('404: Error pushing build status to Zulip')
@@ -162,9 +166,11 @@ class TestZulipStatusPush(unittest.TestCase, ReporterTestMixin, LoggingMixin, Co
                 "buildername": "Builder0",
                 "url": "http://localhost:8080/#/builders/79/builds/0",
                 "project": "testProject",
-                "timestamp": 10000001
-            }, code=401, content_json={"result": "error", "msg": "Invalid API key",
-                                       "code": "INVALID_API_KEY"})
+                "timestamp": 10000001,
+            },
+            code=401,
+            content_json={"result": "error", "msg": "Invalid API key", "code": "INVALID_API_KEY"},
+        )
         self.setUpLogging()
         yield self.sp._got_event(('builds', 20, 'new'), build)
         self.assertLogged('401: Error pushing build status to Zulip')
