@@ -26,7 +26,6 @@ from buildbot.test.steps import TestBuildStepMixin
 
 
 class TestMock(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
-
     def setUp(self):
         self.setup_test_reactor()
         return self.setup_test_build_step()
@@ -45,60 +44,69 @@ class TestMock(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
     def test_success(self):
         self.setup_step(mock.Mock(root='TESTROOT'))
         self.expect_commands(
-            ExpectRmdir(dir=['build/build.log', 'build/root.log', 'build/state.log'],
-                        log_environ=False)
-            .exit(0),
-            ExpectShell(workdir='wkdir',
-                        command=['mock', '--root', 'TESTROOT'],
-                        logfiles={'build.log': 'build.log',
-                                  'root.log': 'root.log',
-                                  'state.log': 'state.log'})
-            .exit(0))
+            ExpectRmdir(
+                dir=['build/build.log', 'build/root.log', 'build/state.log'], log_environ=False
+            ).exit(0),
+            ExpectShell(
+                workdir='wkdir',
+                command=['mock', '--root', 'TESTROOT'],
+                logfiles={
+                    'build.log': 'build.log',
+                    'root.log': 'root.log',
+                    'state.log': 'state.log',
+                },
+            ).exit(0),
+        )
         self.expect_outcome(result=SUCCESS, state_string="'mock --root ...'")
         return self.run_step()
 
     def test_resultdir_success(self):
         self.setup_step(mock.Mock(root='TESTROOT', resultdir='RESULT'))
         self.expect_commands(
-            ExpectRmdir(dir=['build/RESULT/build.log',
-                             'build/RESULT/root.log',
-                             'build/RESULT/state.log'],
-                        log_environ=False)
-            .exit(0),
-            ExpectShell(workdir='wkdir',
-                        command=['mock', '--root', 'TESTROOT',
-                                 '--resultdir', 'RESULT'],
-                        logfiles={'build.log': 'RESULT/build.log',
-                                  'root.log': 'RESULT/root.log',
-                                  'state.log': 'RESULT/state.log'})
-            .exit(0))
+            ExpectRmdir(
+                dir=['build/RESULT/build.log', 'build/RESULT/root.log', 'build/RESULT/state.log'],
+                log_environ=False,
+            ).exit(0),
+            ExpectShell(
+                workdir='wkdir',
+                command=['mock', '--root', 'TESTROOT', '--resultdir', 'RESULT'],
+                logfiles={
+                    'build.log': 'RESULT/build.log',
+                    'root.log': 'RESULT/root.log',
+                    'state.log': 'RESULT/state.log',
+                },
+            ).exit(0),
+        )
         self.expect_outcome(result=SUCCESS)
         return self.run_step()
 
     def test_resultdir_renderable(self):
         resultdir_text = "RESULT"
-        self.setup_step(mock.Mock(root='TESTROOT', resultdir=Interpolate(
-            '%(kw:resultdir)s', resultdir=resultdir_text)))
+        self.setup_step(
+            mock.Mock(
+                root='TESTROOT', resultdir=Interpolate('%(kw:resultdir)s', resultdir=resultdir_text)
+            )
+        )
         self.expect_commands(
-            ExpectRmdir(dir=['build/RESULT/build.log',
-                             'build/RESULT/root.log',
-                             'build/RESULT/state.log'],
-                        log_environ=False)
-            .exit(0),
-            ExpectShell(workdir='wkdir',
-                        command=['mock', '--root', 'TESTROOT',
-                                 '--resultdir', 'RESULT'],
-                        logfiles={'build.log': 'RESULT/build.log',
-                                  'root.log': 'RESULT/root.log',
-                                  'state.log': 'RESULT/state.log'})
-            .exit(0))
+            ExpectRmdir(
+                dir=['build/RESULT/build.log', 'build/RESULT/root.log', 'build/RESULT/state.log'],
+                log_environ=False,
+            ).exit(0),
+            ExpectShell(
+                workdir='wkdir',
+                command=['mock', '--root', 'TESTROOT', '--resultdir', 'RESULT'],
+                logfiles={
+                    'build.log': 'RESULT/build.log',
+                    'root.log': 'RESULT/root.log',
+                    'state.log': 'RESULT/state.log',
+                },
+            ).exit(0),
+        )
         self.expect_outcome(result=SUCCESS, state_string="'mock --root ...'")
         return self.run_step()
 
 
-class TestMockBuildSRPM(TestBuildStepMixin, TestReactorMixin,
-                        unittest.TestCase):
-
+class TestMockBuildSRPM(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
     def setUp(self):
         self.setup_test_reactor()
         return self.setup_test_build_step()
@@ -113,24 +121,33 @@ class TestMockBuildSRPM(TestBuildStepMixin, TestReactorMixin,
     def test_success(self):
         self.setup_step(mock.MockBuildSRPM(root='TESTROOT', spec="foo.spec"))
         self.expect_commands(
-            ExpectRmdir(dir=['build/build.log', 'build/root.log', 'build/state.log'],
-                        log_environ=False)
-            .exit(0),
-            ExpectShell(workdir='wkdir',
-                        command=['mock', '--root', 'TESTROOT',
-                                 '--buildsrpm', '--spec', 'foo.spec',
-                                 '--sources', '.'],
-                        logfiles={'build.log': 'build.log',
-                                  'root.log': 'root.log',
-                                  'state.log': 'state.log'},)
-            .exit(0))
+            ExpectRmdir(
+                dir=['build/build.log', 'build/root.log', 'build/state.log'], log_environ=False
+            ).exit(0),
+            ExpectShell(
+                workdir='wkdir',
+                command=[
+                    'mock',
+                    '--root',
+                    'TESTROOT',
+                    '--buildsrpm',
+                    '--spec',
+                    'foo.spec',
+                    '--sources',
+                    '.',
+                ],
+                logfiles={
+                    'build.log': 'build.log',
+                    'root.log': 'root.log',
+                    'state.log': 'state.log',
+                },
+            ).exit(0),
+        )
         self.expect_outcome(result=SUCCESS, state_string='mock buildsrpm')
         return self.run_step()
 
 
-class TestMockRebuild(TestBuildStepMixin, TestReactorMixin,
-                      unittest.TestCase):
-
+class TestMockRebuild(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
     def setUp(self):
         self.setup_test_reactor()
         return self.setup_test_build_step()
@@ -145,15 +162,18 @@ class TestMockRebuild(TestBuildStepMixin, TestReactorMixin,
     def test_success(self):
         self.setup_step(mock.MockRebuild(root='TESTROOT', srpm="foo.src.rpm"))
         self.expect_commands(
-            ExpectRmdir(dir=['build/build.log', 'build/root.log', 'build/state.log'],
-                        log_environ=False)
-            .exit(0),
-            ExpectShell(workdir='wkdir',
-                        command=['mock', '--root', 'TESTROOT',
-                                 '--rebuild', 'foo.src.rpm'],
-                        logfiles={'build.log': 'build.log',
-                                  'root.log': 'root.log',
-                                  'state.log': 'state.log'},)
-            .exit(0))
+            ExpectRmdir(
+                dir=['build/build.log', 'build/root.log', 'build/state.log'], log_environ=False
+            ).exit(0),
+            ExpectShell(
+                workdir='wkdir',
+                command=['mock', '--root', 'TESTROOT', '--rebuild', 'foo.src.rpm'],
+                logfiles={
+                    'build.log': 'build.log',
+                    'root.log': 'root.log',
+                    'state.log': 'state.log',
+                },
+            ).exit(0),
+        )
         self.expect_outcome(result=SUCCESS, state_string='mock rebuild srpm')
         return self.run_step()
