@@ -50,7 +50,7 @@ real_log = r"""
 2>Build log was saved at "file://c:\another\similar\path\to\debug\BuildLog.htm"
 2>product - 1 error(s), 0 warning(s)
 ========== Build: 1 succeeded, 1 failed, 6 up-to-date, 0 skipped ==========
-"""  # noqa pylint: disable=line-too-long
+"""
 
 
 class TestAddEnvPath(unittest.TestCase):
@@ -193,16 +193,16 @@ class MSLogLineObserver(unittest.TestCase):
             (
                 'e',
                 '2>LINK : fatal error LNK1168: cannot open ../../debug/directory/dllname.dll for writing',
-            ),  # noqa pylint: disable=line-too-long
+            ),
         ]
         warnings = [
             '1>------ Build started: Project: lib1, Configuration: debug Win32 ------',
-            "1>c:\\absolute\\path\\to\\systemlog.cpp(7) : warning C4100: 'op' : unreferenced formal parameter",  # noqa pylint: disable=line-too-long
-            "1>c:\\absolute\\path\\to\\systemlog.cpp(12) : warning C4100: 'statusword' : unreferenced formal parameter",  # noqa pylint: disable=line-too-long
-            "1>c:\\absolute\\path\\to\\systemlog.cpp(12) : warning C4100: 'op' : unreferenced formal parameter",  # noqa pylint: disable=line-too-long
-            "1>c:\\absolute\\path\\to\\systemlog.cpp(17) : warning C4100: 'retryCounter' : unreferenced formal parameter",  # noqa pylint: disable=line-too-long
-            "1>c:\\absolute\\path\\to\\systemlog.cpp(17) : warning C4100: 'op' : unreferenced formal parameter",  # noqa pylint: disable=line-too-long
-            "1>c:\\absolute\\path\\to\\systemlog.cpp(22) : warning C4100: 'op' : unreferenced formal parameter",  # noqa pylint: disable=line-too-long
+            "1>c:\\absolute\\path\\to\\systemlog.cpp(7) : warning C4100: 'op' : unreferenced formal parameter",
+            "1>c:\\absolute\\path\\to\\systemlog.cpp(12) : warning C4100: 'statusword' : unreferenced formal parameter",
+            "1>c:\\absolute\\path\\to\\systemlog.cpp(12) : warning C4100: 'op' : unreferenced formal parameter",
+            "1>c:\\absolute\\path\\to\\systemlog.cpp(17) : warning C4100: 'retryCounter' : unreferenced formal parameter",
+            "1>c:\\absolute\\path\\to\\systemlog.cpp(17) : warning C4100: 'op' : unreferenced formal parameter",
+            "1>c:\\absolute\\path\\to\\systemlog.cpp(22) : warning C4100: 'op' : unreferenced formal parameter",
             '2>------ Build started: Project: product, Configuration: debug Win32 ------',
         ]
         self.assertResult(
@@ -253,11 +253,11 @@ class VisualStudio(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
     @defer.inlineCallbacks
     def test_installdir(self):
         self.setup_step(VCx(installdir=r'C:\I'))
-        self.step.exp_installdir = r'C:\I'
+        self.get_nth_step(0).exp_installdir = r'C:\I'
         self.expect_commands(ExpectShell(workdir='wkdir', command=['command', 'here']).exit(0))
         self.expect_outcome(result=SUCCESS, state_string="compile 0 projects 0 files")
         yield self.run_step()
-        self.assertEqual(self.step.installdir, r'C:\I')
+        self.assertEqual(self.get_nth_step(0).installdir, r'C:\I')
 
     def test_evaluate_result_failure(self):
         self.setup_step(VCx())
@@ -343,9 +343,8 @@ class VisualStudio(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.expect_outcome(result=SUCCESS, state_string="compile 0 projects 0 files")
         yield self.run_step()
 
-        self.assertEqual(
-            [self.step.projectfile, self.step.config, self.step.project], ['aa', 'bb', 'cc']
-        )
+        step = self.get_nth_step(0)
+        self.assertEqual([step.projectfile, step.config, step.project], ['aa', 'bb', 'cc'])
 
 
 class TestVC6(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
@@ -639,7 +638,7 @@ class TestVC8(VC8ExpectedEnvMixin, TestBuildStepMixin, TestReactorMixin, unittes
         self.expect_outcome(result=SUCCESS, state_string="compile 0 projects 0 files")
         yield self.run_step()
 
-        self.assertEqual(self.step.arch, 'x64')
+        self.assertEqual(self.get_nth_step(0).arch, 'x64')
 
 
 class TestVCExpress9(VC8ExpectedEnvMixin, TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
@@ -788,7 +787,7 @@ class TestMsBuild(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.expect_commands(
             ExpectShell(
                 workdir='wkdir',
-                command='"%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj"',  # noqa pylint: disable=line-too-long
+                command='"%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj"',
                 env={'VCENV_BAT': r'${VS110COMNTOOLS}..\..\VC\vcvarsall.bat'},
             ).exit(0)
         )
@@ -805,7 +804,7 @@ class TestMsBuild(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.expect_commands(
             ExpectShell(
                 workdir='wkdir',
-                command='"%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj:Build"',  # noqa pylint: disable=line-too-long
+                command='"%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj:Build"',
                 env={'VCENV_BAT': r'${VS110COMNTOOLS}..\..\VC\vcvarsall.bat'},
             ).exit(0)
         )
@@ -822,7 +821,7 @@ class TestMsBuild(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.expect_commands(
             ExpectShell(
                 workdir='wkdir',
-                command='"%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj:Clean"',  # noqa pylint: disable=line-too-long
+                command='"%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj:Clean"',
                 env={'VCENV_BAT': r'${VS110COMNTOOLS}..\..\VC\vcvarsall.bat'},
             ).exit(0)
         )
@@ -843,7 +842,7 @@ class TestMsBuild(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.expect_commands(
             ExpectShell(
                 workdir='wkdir',
-                command='"%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj" /p:DefineConstants="Define1;Define2=42"',  # noqa pylint: disable=line-too-long
+                command='"%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj" /p:DefineConstants="Define1;Define2=42"',
                 env={'VCENV_BAT': r'${VS110COMNTOOLS}..\..\VC\vcvarsall.bat'},
             ).exit(0)
         )
@@ -856,7 +855,7 @@ class TestMsBuild(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.expect_commands(
             ExpectShell(
                 workdir='wkdir',
-                command='"%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="x64" /maxcpucount /t:Rebuild',  # noqa pylint: disable=line-too-long
+                command='"%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="x64" /maxcpucount /t:Rebuild',
                 env={'VCENV_BAT': r'${VS110COMNTOOLS}..\..\VC\vcvarsall.bat'},
             ).exit(0)
         )
@@ -890,12 +889,12 @@ class TestMsBuild141(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.expect_commands(
             ExpectShell(
                 workdir='wkdir',
-                command='FOR /F "tokens=*" %%I in (\'vswhere.exe -version "[15.0,16.0)" -products * -property installationPath\')  do "%%I\\%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj"',  # noqa pylint: disable=line-too-long
+                command='FOR /F "tokens=*" %%I in (\'vswhere.exe -version "[15.0,16.0)" -products * -property installationPath\')  do "%%I\\%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj"',
                 env={
                     'VCENV_BAT': r'\VC\Auxiliary\Build\vcvarsall.bat',
                     'PATH': 'C:\\Program Files (x86)\\Microsoft Visual Studio\\Installer\\;C:\\Program Files\\Microsoft Visual Studio\\Installer\\;${PATH};',
                 },
-            ).exit(0)  # noqa pylint: disable=line-too-long
+            ).exit(0)
         )
         self.expect_outcome(result=SUCCESS, state_string="compile 0 projects 0 files")
         return self.run_step()
@@ -910,12 +909,12 @@ class TestMsBuild141(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.expect_commands(
             ExpectShell(
                 workdir='wkdir',
-                command='FOR /F "tokens=*" %%I in (\'vswhere.exe -version "[15.0,16.0)" -products * -property installationPath\')  do "%%I\\%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj:Build"',  # noqa pylint: disable=line-too-long
+                command='FOR /F "tokens=*" %%I in (\'vswhere.exe -version "[15.0,16.0)" -products * -property installationPath\')  do "%%I\\%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj:Build"',
                 env={
                     'VCENV_BAT': r'\VC\Auxiliary\Build\vcvarsall.bat',
                     'PATH': 'C:\\Program Files (x86)\\Microsoft Visual Studio\\Installer\\;C:\\Program Files\\Microsoft Visual Studio\\Installer\\;${PATH};',
                 },
-            ).exit(0)  # noqa pylint: disable=line-too-long
+            ).exit(0)
         )
         self.expect_outcome(result=SUCCESS, state_string="compile 0 projects 0 files")
         return self.run_step()
@@ -930,12 +929,12 @@ class TestMsBuild141(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.expect_commands(
             ExpectShell(
                 workdir='wkdir',
-                command='FOR /F "tokens=*" %%I in (\'vswhere.exe -version "[15.0,16.0)" -products * -property installationPath\')  do "%%I\\%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj:Clean"',  # noqa pylint: disable=line-too-long
+                command='FOR /F "tokens=*" %%I in (\'vswhere.exe -version "[15.0,16.0)" -products * -property installationPath\')  do "%%I\\%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj:Clean"',
                 env={
                     'VCENV_BAT': r'\VC\Auxiliary\Build\vcvarsall.bat',
                     'PATH': 'C:\\Program Files (x86)\\Microsoft Visual Studio\\Installer\\;C:\\Program Files\\Microsoft Visual Studio\\Installer\\;${PATH};',
                 },
-            ).exit(0)  # noqa pylint: disable=line-too-long
+            ).exit(0)
         )
         self.expect_outcome(result=SUCCESS, state_string="compile 0 projects 0 files")
         return self.run_step()
@@ -954,12 +953,12 @@ class TestMsBuild141(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.expect_commands(
             ExpectShell(
                 workdir='wkdir',
-                command='FOR /F "tokens=*" %%I in (\'vswhere.exe -version "[15.0,16.0)" -products * -property installationPath\')  do "%%I\\%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj" /p:DefineConstants="Define1;Define2=42"',  # noqa pylint: disable=line-too-long
+                command='FOR /F "tokens=*" %%I in (\'vswhere.exe -version "[15.0,16.0)" -products * -property installationPath\')  do "%%I\\%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj" /p:DefineConstants="Define1;Define2=42"',
                 env={
                     'VCENV_BAT': r'\VC\Auxiliary\Build\vcvarsall.bat',
                     'PATH': 'C:\\Program Files (x86)\\Microsoft Visual Studio\\Installer\\;C:\\Program Files\\Microsoft Visual Studio\\Installer\\;${PATH};',
                 },
-            ).exit(0)  # noqa pylint: disable=line-too-long
+            ).exit(0)
         )
         self.expect_outcome(result=SUCCESS, state_string="compile 0 projects 0 files")
         return self.run_step()
@@ -970,12 +969,12 @@ class TestMsBuild141(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.expect_commands(
             ExpectShell(
                 workdir='wkdir',
-                command='FOR /F "tokens=*" %%I in (\'vswhere.exe -version "[15.0,16.0)" -products * -property installationPath\')  do "%%I\\%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="x64" /maxcpucount /t:Rebuild',  # noqa pylint: disable=line-too-long
+                command='FOR /F "tokens=*" %%I in (\'vswhere.exe -version "[15.0,16.0)" -products * -property installationPath\')  do "%%I\\%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="x64" /maxcpucount /t:Rebuild',
                 env={
                     'VCENV_BAT': r'\VC\Auxiliary\Build\vcvarsall.bat',
                     'PATH': 'C:\\Program Files (x86)\\Microsoft Visual Studio\\Installer\\;C:\\Program Files\\Microsoft Visual Studio\\Installer\\;${PATH};',
                 },
-            ).exit(0)  # noqa pylint: disable=line-too-long
+            ).exit(0)
         )
         self.expect_outcome(result=SUCCESS, state_string="compile 0 projects 0 files")
         return self.run_step()
@@ -1000,12 +999,12 @@ class TestMsBuild16(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.expect_commands(
             ExpectShell(
                 workdir='wkdir',
-                command='FOR /F "tokens=*" %%I in (\'vswhere.exe -version "[16.0,17.0)" -products * -property installationPath\')  do "%%I\\%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj"',  # noqa pylint: disable=line-too-long
+                command='FOR /F "tokens=*" %%I in (\'vswhere.exe -version "[16.0,17.0)" -products * -property installationPath\')  do "%%I\\%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj"',
                 env={
                     'VCENV_BAT': r'\VC\Auxiliary\Build\vcvarsall.bat',
                     'PATH': 'C:\\Program Files (x86)\\Microsoft Visual Studio\\Installer\\;C:\\Program Files\\Microsoft Visual Studio\\Installer\\;${PATH};',
                 },
-            ).exit(0)  # noqa pylint: disable=line-too-long
+            ).exit(0)
         )
         self.expect_outcome(result=SUCCESS, state_string="compile 0 projects 0 files")
         return self.run_step()
@@ -1027,12 +1026,12 @@ class TestMsBuild17(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.expect_commands(
             ExpectShell(
                 workdir='wkdir',
-                command='FOR /F "tokens=*" %%I in (\'vswhere.exe -version "[17.0,18.0)" -products * -property installationPath\')  do "%%I\\%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj"',  # noqa pylint: disable=line-too-long
+                command='FOR /F "tokens=*" %%I in (\'vswhere.exe -version "[17.0,18.0)" -products * -property installationPath\')  do "%%I\\%VCENV_BAT%" x86 && msbuild "pf" /p:Configuration="cfg" /p:Platform="Win32" /maxcpucount /t:"pj"',
                 env={
                     'VCENV_BAT': r'\VC\Auxiliary\Build\vcvarsall.bat',
                     'PATH': 'C:\\Program Files (x86)\\Microsoft Visual Studio\\Installer\\;C:\\Program Files\\Microsoft Visual Studio\\Installer\\;${PATH};',
                 },
-            ).exit(0)  # noqa pylint: disable=line-too-long
+            ).exit(0)
         )
         self.expect_outcome(result=SUCCESS, state_string="compile 0 projects 0 files")
         return self.run_step()
