@@ -41,9 +41,9 @@ bitbucketPRproperties = {
     'bitbucket.fromRef.commit.hash': 'a87e21f7433d8c16ac7be7413483fbb76c72a8ba',
     'bitbucket.fromRef.commit.message': None,
     'bitbucket.fromRef.repository.fullName': 'CI/py-repo',
-    'bitbucket.fromRef.repository.links.self': [{
-        'href': 'http://localhost:7990/projects/CI/repos/py-repo/browse'
-    }],
+    'bitbucket.fromRef.repository.links.self': [
+        {'href': 'http://localhost:7990/projects/CI/repos/py-repo/browse'}
+    ],
     'bitbucket.fromRef.repository.owner.displayName': 'CI',
     'bitbucket.fromRef.repository.owner.username': 'CI',
     'bitbucket.fromRef.repository.ownerName': 'CI',
@@ -59,9 +59,9 @@ bitbucketPRproperties = {
     'bitbucket.toRef.commit.hash': '7aebbb0089c40fce138a6d0b36d2281ea34f37f5',
     'bitbucket.toRef.commit.message': None,
     'bitbucket.toRef.repository.fullName': 'CI/py-repo',
-    'bitbucket.toRef.repository.links.self': [{
-        'href': 'http://localhost:7990/projects/CI/repos/py-repo/browse'
-    }],
+    'bitbucket.toRef.repository.links.self': [
+        {'href': 'http://localhost:7990/projects/CI/repos/py-repo/browse'}
+    ],
     'bitbucket.toRef.repository.owner.displayName': 'CI',
     'bitbucket.toRef.repository.owner.username': 'CI',
     'bitbucket.toRef.repository.ownerName': 'CI',
@@ -69,7 +69,7 @@ bitbucketPRproperties = {
     'bitbucket.toRef.repository.project.name': 'Continuous Integration',
     'bitbucket.toRef.repository.public': False,
     'bitbucket.toRef.repository.scmId': 'git',
-    'bitbucket.toRef.repository.slug': 'py-repo'
+    'bitbucket.toRef.repository.slug': 'py-repo',
 }
 
 
@@ -706,16 +706,16 @@ def _prepare_request(payload, headers=None, change_dict=None):
     return request
 
 
-class TestChangeHookConfiguredWithGitChange(unittest.TestCase,
-                                            TestReactorMixin):
-
+class TestChangeHookConfiguredWithGitChange(unittest.TestCase, TestReactorMixin):
     def setUp(self):
         self.setup_test_reactor()
         self.change_hook = change_hook.ChangeHookResource(
-            dialects={'bitbucketserver': {
+            dialects={
+                'bitbucketserver': {
                     'bitbucket_property_whitelist': ["bitbucket.*"],
-            }},
-            master=fakeMasterForHooks(self)
+                }
+            },
+            master=fakeMasterForHooks(self),
         )
 
     def assertDictSubset(self, expected_dict, response_dict):
@@ -726,26 +726,23 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase,
         self.assertDictEqual(expected_dict, expected)
 
     def _checkPush(self, change):
-        self.assertEqual(
-            change['repository'],
-            'http://localhost:7990/projects/CI/repos/py-repo/')
+        self.assertEqual(change['repository'], 'http://localhost:7990/projects/CI/repos/py-repo/')
         self.assertEqual(change['author'], 'John Smith <John>')
         self.assertEqual(change['project'], 'Continuous Integration')
-        self.assertEqual(change['revision'],
-                         '793d4754230023d85532f9a38dba3290f959beb4')
+        self.assertEqual(change['revision'], '793d4754230023d85532f9a38dba3290f959beb4')
         self.assertEqual(
-            change['comments'], 'Bitbucket Server commit '
-                                '793d4754230023d85532f9a38dba3290f959beb4')
+            change['comments'],
+            'Bitbucket Server commit 793d4754230023d85532f9a38dba3290f959beb4',
+        )
         self.assertEqual(
             change['revlink'],
             'http://localhost:7990/projects/CI/repos/py-repo/commits/'
-            '793d4754230023d85532f9a38dba3290f959beb4')
+            '793d4754230023d85532f9a38dba3290f959beb4',
+        )
 
     @defer.inlineCallbacks
     def testHookWithChangeOnRefsChangedEvent(self):
-
-        request = _prepare_request(
-            pushJsonPayload, headers={_HEADER_EVENT: 'repo:refs_changed'})
+        request = _prepare_request(pushJsonPayload, headers={_HEADER_EVENT: 'repo:refs_changed'})
 
         yield request.test_render(self.change_hook)
 
@@ -757,9 +754,7 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase,
 
     @defer.inlineCallbacks
     def testHookWithChangeOnPushEvent(self):
-
-        request = _prepare_request(
-            pushJsonPayload, headers={_HEADER_EVENT: 'repo:push'})
+        request = _prepare_request(pushJsonPayload, headers={_HEADER_EVENT: 'repo:push'})
 
         yield request.test_render(self.change_hook)
 
@@ -775,25 +770,21 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase,
         yield self.testHookWithChangeOnPushEvent()
 
     def _checkPullRequest(self, change):
-        self.assertEqual(
-            change['repository'],
-            'http://localhost:7990/projects/CI/repos/py-repo/')
+        self.assertEqual(change['repository'], 'http://localhost:7990/projects/CI/repos/py-repo/')
         self.assertEqual(change['author'], 'John Smith <John>')
         self.assertEqual(change['project'], 'Continuous Integration')
-        self.assertEqual(change['comments'],
-                         'Bitbucket Server Pull Request #21')
-        self.assertEqual(change['revlink'],
-                         'http://localhost:7990/projects/'
-                         'CI/repos/py-repo/pull-requests/21')
-        self.assertEqual(change['revision'],
-                         'a87e21f7433d8c16ac7be7413483fbb76c72a8ba')
+        self.assertEqual(change['comments'], 'Bitbucket Server Pull Request #21')
+        self.assertEqual(
+            change['revlink'], 'http://localhost:7990/projects/CI/repos/py-repo/pull-requests/21'
+        )
+        self.assertEqual(change['revision'], 'a87e21f7433d8c16ac7be7413483fbb76c72a8ba')
         self.assertDictSubset(bitbucketPRproperties, change["properties"])
 
     @defer.inlineCallbacks
     def testHookWithChangeOnPullRequestCreated(self):
         request = _prepare_request(
-            pullRequestCreatedJsonPayload,
-            headers={_HEADER_EVENT: 'pullrequest:created'})
+            pullRequestCreatedJsonPayload, headers={_HEADER_EVENT: 'pullrequest:created'}
+        )
 
         yield request.test_render(self.change_hook)
 
@@ -806,8 +797,8 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase,
     @defer.inlineCallbacks
     def testHookWithChangeOnPullRequestUpdated(self):
         request = _prepare_request(
-            pullRequestUpdatedJsonPayload,
-            headers={_HEADER_EVENT: 'pullrequest:updated'})
+            pullRequestUpdatedJsonPayload, headers={_HEADER_EVENT: 'pullrequest:updated'}
+        )
 
         yield request.test_render(self.change_hook)
 
@@ -820,8 +811,8 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase,
     @defer.inlineCallbacks
     def testHookWithChangeOnPullRequestRejected(self):
         request = _prepare_request(
-            pullRequestRejectedJsonPayload,
-            headers={_HEADER_EVENT: 'pullrequest:rejected'})
+            pullRequestRejectedJsonPayload, headers={_HEADER_EVENT: 'pullrequest:rejected'}
+        )
 
         yield request.test_render(self.change_hook)
 
@@ -834,8 +825,8 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase,
     @defer.inlineCallbacks
     def testHookWithChangeOnPullRequestFulfilled(self):
         request = _prepare_request(
-            pullRequestFulfilledJsonPayload,
-            headers={_HEADER_EVENT: 'pullrequest:fulfilled'})
+            pullRequestFulfilledJsonPayload, headers={_HEADER_EVENT: 'pullrequest:fulfilled'}
+        )
 
         yield request.test_render(self.change_hook)
 
@@ -849,9 +840,9 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase,
     def _checkCodebase(self, event_type, expected_codebase):
         payloads = {
             'repo:refs_changed': pushJsonPayload,
-            'pullrequest:updated': pullRequestUpdatedJsonPayload}
-        request = _prepare_request(
-            payloads[event_type], headers={_HEADER_EVENT: event_type})
+            'pullrequest:updated': pullRequestUpdatedJsonPayload,
+        }
+        request = _prepare_request(payloads[event_type], headers={_HEADER_EVENT: event_type})
         yield request.test_render(self.change_hook)
         self.assertEqual(len(self.change_hook.master.data.updates.changesAdded), 1)
         change = self.change_hook.master.data.updates.changesAdded[0]
@@ -859,44 +850,38 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase,
 
     @defer.inlineCallbacks
     def testHookWithCodebaseValueOnPushEvent(self):
-        self.change_hook.dialects = {
-            'bitbucketserver': {'codebase': 'super-codebase'}}
+        self.change_hook.dialects = {'bitbucketserver': {'codebase': 'super-codebase'}}
         yield self._checkCodebase('repo:refs_changed', 'super-codebase')
 
     @defer.inlineCallbacks
     def testHookWithCodebaseFunctionOnPushEvent(self):
         self.change_hook.dialects = {
-            'bitbucketserver': {
-                'codebase':
-                    lambda payload: payload['repository']['project']['key']}}
+            'bitbucketserver': {'codebase': lambda payload: payload['repository']['project']['key']}
+        }
         yield self._checkCodebase('repo:refs_changed', 'CI')
 
     @defer.inlineCallbacks
     def testHookWithCodebaseValueOnPullEvent(self):
-        self.change_hook.dialects = {
-            'bitbucketserver': {'codebase': 'super-codebase'}}
+        self.change_hook.dialects = {'bitbucketserver': {'codebase': 'super-codebase'}}
         yield self._checkCodebase('pullrequest:updated', 'super-codebase')
 
     @defer.inlineCallbacks
     def testHookWithCodebaseFunctionOnPullEvent(self):
         self.change_hook.dialects = {
-            'bitbucketserver': {
-                'codebase':
-                    lambda payload: payload['repository']['project']['key']}}
+            'bitbucketserver': {'codebase': lambda payload: payload['repository']['project']['key']}
+        }
         yield self._checkCodebase('pullrequest:updated', 'CI')
 
     @defer.inlineCallbacks
     def testHookWithUnhandledEvent(self):
-        request = _prepare_request(
-            pushJsonPayload, headers={_HEADER_EVENT: 'invented:event'})
+        request = _prepare_request(pushJsonPayload, headers={_HEADER_EVENT: 'invented:event'})
         yield request.test_render(self.change_hook)
         self.assertEqual(len(self.change_hook.master.data.updates.changesAdded), 0)
         self.assertEqual(request.written, b"Unknown event: invented_event")
 
     @defer.inlineCallbacks
     def testHookWithChangeOnCreateTag(self):
-        request = _prepare_request(
-            newTagJsonPayload, headers={_HEADER_EVENT: 'repo:refs_changed'})
+        request = _prepare_request(newTagJsonPayload, headers={_HEADER_EVENT: 'repo:refs_changed'})
         yield request.test_render(self.change_hook)
         self.assertEqual(len(self.change_hook.master.data.updates.changesAdded), 1)
         change = self.change_hook.master.data.updates.changesAdded[0]
@@ -907,7 +892,8 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase,
     @defer.inlineCallbacks
     def testHookWithChangeOnDeleteTag(self):
         request = _prepare_request(
-            deleteTagJsonPayload, headers={_HEADER_EVENT: 'repo:refs_changed'})
+            deleteTagJsonPayload, headers={_HEADER_EVENT: 'repo:refs_changed'}
+        )
         yield request.test_render(self.change_hook)
         self.assertEqual(len(self.change_hook.master.data.updates.changesAdded), 1)
         change = self.change_hook.master.data.updates.changesAdded[0]
@@ -918,8 +904,8 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase,
     @defer.inlineCallbacks
     def testHookWithChangeOnDeleteBranch(self):
         request = _prepare_request(
-            deleteBranchJsonPayload,
-            headers={_HEADER_EVENT: 'repo:refs_changed'})
+            deleteBranchJsonPayload, headers={_HEADER_EVENT: 'repo:refs_changed'}
+        )
         yield request.test_render(self.change_hook)
         self.assertEqual(len(self.change_hook.master.data.updates.changesAdded), 1)
         change = self.change_hook.master.data.updates.changesAdded[0]
@@ -929,10 +915,8 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase,
 
     @defer.inlineCallbacks
     def testHookWithInvalidContentType(self):
-        request = _prepare_request(
-            pushJsonPayload, headers={_HEADER_EVENT: b'repo:refs_changed'})
+        request = _prepare_request(pushJsonPayload, headers={_HEADER_EVENT: b'repo:refs_changed'})
         request.received_headers[b'Content-Type'] = b'invalid/content'
         yield request.test_render(self.change_hook)
         self.assertEqual(len(self.change_hook.master.data.updates.changesAdded), 0)
-        self.assertEqual(request.written,
-                         b"Unknown content type: invalid/content")
+        self.assertEqual(request.written, b"Unknown content type: invalid/content")
