@@ -13,9 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-
 from twisted.internet import defer
 from twisted.trial import unittest
 
@@ -27,7 +24,6 @@ from buildbot_worker.test.util.command import CommandTestMixin
 
 
 class DummyCommand(Command):
-
     def setup(self, args):
         self.setup_done = True
         self.interrupted = False
@@ -58,12 +54,10 @@ class DummyCommand(Command):
 
 
 class DummyArgsCommand(DummyCommand):
-
     requiredArgs = ['workdir']
 
 
 class TestDummyCommand(CommandTestMixin, unittest.TestCase):
-
     def setUp(self):
         self.setUpCommand()
 
@@ -77,76 +71,75 @@ class TestDummyCommand(CommandTestMixin, unittest.TestCase):
                 'running': self.cmd.running,
                 'started': self.cmd.started,
                 'interrupted': self.cmd.interrupted,
-            }, {
+            },
+            {
                 'setup_done': setup_done,
                 'running': running,
                 'started': started,
                 'interrupted': interrupted,
-            }, msg)
+            },
+            msg,
+        )
 
     def test_run(self):
         cmd = self.make_command(DummyCommand, {'stdout': 'yay'})
-        self.assertState(
-            True, False, False, False, "setup called by constructor")
+        self.assertState(True, False, False, False, "setup called by constructor")
 
         # start the command
         d = self.run_command()
-        self.assertState(
-            True, True, True, False, "started and running both set")
+        self.assertState(True, True, True, False, "started and running both set")
 
         # allow the command to finish and check the result
         cmd.finishCommand()
 
         def check(_):
-            self.assertState(
-                True, False, True, False, "started and not running when done")
+            self.assertState(True, False, True, False, "started and not running when done")
+
         d.addCallback(check)
 
         def checkresult(_):
             self.assertUpdates([('stdout', 'yay')], "updates processed")
+
         d.addCallback(checkresult)
         return d
 
     def test_run_failure(self):
         cmd = self.make_command(DummyCommand, {})
-        self.assertState(
-            True, False, False, False, "setup called by constructor")
+        self.assertState(True, False, False, False, "setup called by constructor")
 
         # start the command
         d = self.run_command()
-        self.assertState(
-            True, True, True, False, "started and running both set")
+        self.assertState(True, True, True, False, "started and running both set")
 
         # fail the command with an exception, and check the result
         cmd.failCommand()
 
         def check(_):
-            self.assertState(
-                True, False, True, False, "started and not running when done")
+            self.assertState(True, False, True, False, "started and not running when done")
+
         d.addErrback(check)
 
         def checkresult(_):
             self.assertUpdates([], "updates processed")
+
         d.addCallback(checkresult)
         return d
 
     def test_run_interrupt(self):
         cmd = self.make_command(DummyCommand, {})
-        self.assertState(
-            True, False, False, False, "setup called by constructor")
+        self.assertState(True, False, False, False, "setup called by constructor")
 
         # start the command
         d = self.run_command()
-        self.assertState(
-            True, True, True, False, "started and running both set")
+        self.assertState(True, True, True, False, "started and running both set")
 
         # interrupt the command
         cmd.doInterrupt()
         self.assertTrue(cmd.interrupted)
 
         def check(_):
-            self.assertState(
-                True, False, True, True, "finishes with interrupted set")
+            self.assertState(True, False, True, True, "finishes with interrupted set")
+
         d.addCallback(check)
         return d
 
